@@ -46,14 +46,16 @@ static OsmoCreditEntry credits_graphics[] = {
 
 static OsmoCreditEntry credits_contributors[] = {
     { NULL, "Markus Dahms", "mad@automagically.de" },
-    { NULL, "Nacho Alonso González", "nacho.alonso.gonzalez@gmail.com" }
+    { NULL, "Nacho Alonso González", "nacho.alonso.gonzalez@gmail.com" },
+    { NULL, "Maxim Gordienko", "mgordienko@users.sourceforge.net" }
 };
 
 static OsmoCreditEntry credits_translators[] = {
     { "bg",     "Borislav Totev", "btotev@hotmail.com" },
     { "ca",     "Roger Adell", "roger.adell@gmail.com" },
     { "cs",     "Jaroslav Lichtblau", "dragonlord@seznam.cz" },
-    { "da",     "Joakim Seeberg", "joak@users.sourceforge.net" },
+    { "da",     "Joakim Seeberg", "joak@users.sourceforge.net" },       /* da */
+    { NULL,     "Joe Hansen", "joedalton2@yahoo.dk" },                  /* da */
     { "de",     "Markus Dahms", "mad@automagically.de" },               /* de */
     { NULL,     "Mario Blättermann", "mariobl@gnome.org" },             /* de */
     { NULL,     "Roland Siegbert", "roland.siegbert@gmail.com" },       /* de */
@@ -68,11 +70,13 @@ static OsmoCreditEntry credits_translators[] = {
     { NULL,     "xesusmosquera", "xesusmosquera@gmail.com"},            /* gl */
     { "gl_ES",  "Miguel Anxo Bouzada", "mbouzada@gmail.com"},           /* gl_ES */
     { NULL,     "xesusmosquera", "xesusmosquera@gmail.com"},            /* gl_ES */
+	{ "he",     "Hebrew", "Hebrew@transifex"},
     { "hu",     "Peter Polonkai", "polesz@nedudu.hu" },
     { "it",     "Bautz", "bautz@email.com" },                           /* it */
     { NULL,     "Calogero Bonasia", "kbonasia@gmail.com" },             /* it */
     { "ja",     "Norihiro Yoneda", "aoba@avis.ne.jp" },
-    { "lt",     "Vaidotas Kazla", "joshas@gmail.com" },
+    { "lt",     "Vaidotas Kazla", "joshas@gmail.com" },                 /* lt */
+	{ NULL,     "Moo", "Moo@transifex" },                               /* lt */
     { "nl",     "Tiger!P", "tigerp@tigerp.net" },
     { "pl",     "Piotr Mąka", "silloz@users.sourceforge.net" },
     { "pt",     "Bruno Miguel", "brunoalexandremiguel@gmail.com" },
@@ -83,6 +87,7 @@ static OsmoCreditEntry credits_translators[] = {
     { NULL,     "Alexander Vozhennikov", "vodka_ploho@mail.ru" },       /* ru */
     { NULL,     "Sergey Panasenko", "nitay@users.sourceforge.net" },    /* ru */
     { NULL,     "Dmitry Korzhevin", "dkorzhevin@lsupport.net" },        /* ru */
+	{ "sr",     "Саша Петровић", "salepetronije@gmail.com" },           /* sr */
     { "sv",     "Niklas Grahn", "terra.unknown@yahoo.com" },
     { "te",     "Praveen Illa", "mail2ipn@gmail.com" },
     { "tr",     "Hasan Yılmaz", "hasanyilmaz@users.sourceforge.net" },
@@ -150,7 +155,7 @@ opt_create_about_window (GUI *appGUI)
     gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
     gtk_box_set_spacing (GTK_BOX (hbuttonbox), HBOX_SPACING);
 
-    button_close = utl_gui_create_button (GTK_STOCK_CLOSE, OSMO_STOCK_BUTTON_CLOSE, _("Close"));
+    button_close = utl_gui_create_labeled_button (GTK_STOCK_CLOSE, OSMO_STOCK_BUTTON_CLOSE, _("Close"));
     gtk_container_add (GTK_CONTAINER (hbuttonbox), button_close);
     GTK_WIDGET_SET_FLAGS (button_close, GTK_CAN_DEFAULT);
     g_signal_connect (G_OBJECT (button_close), "clicked", G_CALLBACK (close_window), window);
@@ -406,7 +411,7 @@ const gchar *notes_editor_keys_text[] = {
 static void
 add_credits_section (const gchar *section_title, OsmoCreditEntry *credits, guint32 n_credits, GUI *appGUI)
 {
-    gint32 i;
+    gint32 i, j, d;
     gchar *s;
 
     s = g_strdup_printf ("\n %s:\n", section_title);
@@ -434,9 +439,17 @@ add_credits_section (const gchar *section_title, OsmoCreditEntry *credits, guint
         gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, s, -1);
         g_free (s);
 
-        utl_gui_url_insert_link (&appGUI->about_links_list,
-                                 &appGUI->about_link_index, appGUI->about_textview,
-                                 &appGUI->about_entry_iter, config.link_color, NULL, credits[i].email, FALSE, appGUI);
+		j = d = 0;
+		while (credits[i].email[j] != '\0')
+			if (credits[i].email[j++] == '.') d++;
+
+		if (d == 0) {
+            gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, credits[i].email, -1);
+		} else {
+			utl_gui_url_insert_link (&appGUI->about_links_list,
+									 &appGUI->about_link_index, appGUI->about_textview,
+									 &appGUI->about_entry_iter, config.link_color, NULL, credits[i].email, FALSE, appGUI);
+		}
 
         gtk_text_buffer_insert (appGUI->about_entry_buffer, &appGUI->about_entry_iter, ">\n", -1);
     }
