@@ -23,20 +23,96 @@
 #include <stdio.h>
 #include <string.h>
 #include <sys/stat.h>
+#ifndef WIN32
 #include <sys/mman.h>
+#endif /* WIN32 */
 
 #include "i18n.h"
 #include "backup.h"
 #include "gui.h"
+#include "notes_preferences_gui.h"
 #include "utils.h"
 #include "utils_gui.h"
 #include "options_prefs.h"
-#include "options_gui_notes.h"
 
 #if defined(BACKUP_SUPPORT) && defined(HAVE_LIBGRINGOTTS)
 
 #include <libgringotts.h>
-#include <libtar.h>
+#include <archive.h>
+#include <archive_entry.h>
+
+/*------------------------------------------------------------------------------*/
+
+int
+tar_archive (const gchar *outname, GUI *appGUI)
+{
+	struct archive *archive;
+	struct archive_entry *entry;
+	struct stat st;
+	gchar buff[8192];
+	gint len;
+	gint fd;
+	gint i = 0;
+	gchar *filename = NULL;
+
+	archive = archive_write_new ();
+	archive_write_set_format_ustar (archive);
+	if (archive_write_open_filename (archive, outname) != ARCHIVE_OK)
+	{
+		g_printf ("%s\n", archive_error_string (archive));
+		return archive_errno (archive);
+	}
+
+	while ((filename = g_slist_nth_data (appGUI->file_list, i)) != NULL)
+	{
+		stat (filename, &st);
+		entry = archive_entry_new ();
+		archive_entry_copy_stat (entry, &st);
+		archive_entry_set_pathname (entry, filename);
+		archive_write_header (archive, entry);
+		fd = open (filename, O_RDONLY);
+		len = read (fd, buff, sizeof (buff));
+		while (len > 0)
+		{
+			archive_write_data (archive, buff, len);
+			len = read (fd, buff, sizeof (buff));
+		}
+		close (fd);
+		archive_entry_free (entry);
+		i++;
+	}
+
+	archive_write_free (archive);
+
+	return ARCHIVE_OK;
+}
+
+/*------------------------------------------------------------------------------*/
+
+int
+untar_archive (gchar *filename)
+{
+	struct archive_entry *entry;
+	struct archive *archive;
+
+	archive = archive_read_new ();
+
+	if ((archive_read_support_filter_all (archive) != ARCHIVE_OK) ||
+	    (archive_read_support_format_all (archive) != ARCHIVE_OK) ||
+	    (archive_read_open_filename (archive, filename, 8192) != ARCHIVE_OK))
+	{
+		archive_read_free (archive);
+		g_printf ("%s\n", archive_error_string (archive));
+		return archive_errno (archive);
+	}
+
+	while (archive_read_next_header (archive, &entry) == ARCHIVE_OK)
+		archive_read_extract (archive, entry, ARCHIVE_EXTRACT_OWNER | ARCHIVE_EXTRACT_PERM);
+
+	archive_read_free (archive);
+
+	return ARCHIVE_OK;
+}
 
 /*------------------------------------------------------------------------------*/
 
@@ -135,8 +211,7 @@ void
 backup_create (GUI *appGUI) {
 
 gchar *home_dirname = NULL;
-gchar *fitem = NULL;
-gint i, ret, p1len, p2len, tErr;
+gint ret, p1len, p2len, tErr;
 GRG_CTX context;
 GRG_KEY keyholder;
 gchar *filename, *password, *bpass1, *bpass2, *tmp_filename;
@@ -147,8 +222,6 @@ GtkWidget *dialog, *passwd_dialog;
 GtkWidget *vbox1, *alignment, *frame, *label;
 GtkWidget *bck_p1_entry, *bck_p2_entry;
 
-TAR *tArch;
-
 	/* select filename and password */
 
     dialog = gtk_file_chooser_dialog_new (_("Save backup"),
@@ -301,26 +374,12 @@ TAR *tArch;
 	g_chdir (prefs_get_config_dir(appGUI));     /* change directory to cfg home */
 	g_unlink (tmp_filename);
 
-	tErr = i = 0;
-
-	if (tar_open (&tArch, tmp_filename, NULL, O_WRONLY | O_CREAT | O_EXCL, 0644, TAR_GNU) != -1) {
-
-		while ((fitem = g_slist_nth_data (appGUI->file_list, i)) != NULL) {
-			if (tar_append_file (tArch, fitem, fitem) != 0) {
-				tErr = -1;
-				break;
-			}
-			i++;
-		}
-
-	} else {
-		tErr = -1;
-	}
+	tErr = tar_archive (tmp_filename, appGUI);
 
 	g_chdir (home_dirname);
 	g_free (home_dirname);
 
-	if (tErr == -1) {
+	if (tErr != ARCHIVE_OK) {
 		utl_gui_create_dialog (GTK_MESSAGE_ERROR, _("Cannot create backup!"), GTK_WINDOW(appGUI->main_window));
 		return;
 	}
@@ -563,8 +622,6 @@ gchar *tmp_filename, *home_dirname;
 const gchar *item_name = NULL;
 gchar *fitem = NULL, separator[2] = { G_DIR_SEPARATOR, '\0' };
 
-TAR *tArch;
-
 	/* is backup file available? */
 
 	tmp_filename = g_strdup (prefs_get_config_filename (BACKUP_TEMPLATE, appGUI));
@@ -574,10 +631,6 @@ TAR *tArch;
 		return;
 	}
 
-	/* is it a TAR archive? */
-
-	/* FIXME: How to check integrity of TAR archive? */
-
 	/* removing old files */
 
 	appGUI->file_list = NULL;
@@ -607,10 +660,7 @@ TAR *tArch;
 
 	/* untar files */
 
-	if (tar_open (&tArch, tmp_filename, NULL, O_RDONLY, 0, TAR_GNU) >= 0) {
-		tar_extract_all (tArch, ".");
-		tar_close (tArch);
-	}
+	untar_archive (tmp_filename);
 
 	/* clean up */
 
