@@ -259,7 +259,7 @@ void
 set_result_cb (GtkWidget *widget, GUI *appGUI)
 {
 	gint days, weeks;
-	guint64 hours, minutes, seconds;
+	long long unsigned int hours, minutes, seconds;
 	gchar tmpbuf[BUFFER_SIZE];
 	gchar tmpbuf2[BUFFER_SIZE];
 	gint P, E, I;
@@ -627,6 +627,9 @@ GtkWidget *hbox11;
 GtkWidget *hbox12;
 GtkWidget *hbox13;
 GtkWidget *hbox14;
+GtkWidget *hbox98;
+GtkWidget *hbox99;
+GtkWidget *vbox99;
 GtkWidget *hbox_bst;
 GtkWidget *hbox_bet;
 GtkWidget *hbox_b2st;
@@ -638,12 +641,14 @@ char      tmpbuf[BUFFER_SIZE];
     appGUI->cal->window_date_calculator = gtk_window_new (GTK_WINDOW_TOPLEVEL);
     gtk_window_set_title (GTK_WINDOW (appGUI->cal->window_date_calculator), _("Date calculator"));
     gtk_window_set_position (GTK_WINDOW (appGUI->cal->window_date_calculator), GTK_WIN_POS_CENTER_ON_PARENT);
-    gtk_window_set_modal (GTK_WINDOW (appGUI->cal->window_date_calculator), TRUE);
+	gtk_window_set_modal (GTK_WINDOW (appGUI->cal->window_date_calculator), TRUE);
     g_signal_connect (G_OBJECT (appGUI->cal->window_date_calculator), "delete_event",
                       G_CALLBACK (window_date_calculator_close_cb), appGUI);
     g_signal_connect (G_OBJECT (appGUI->cal->window_date_calculator), "key_press_event",
                         G_CALLBACK (date_calculator_key_press_cb), appGUI);
-    gtk_window_set_transient_for (GTK_WINDOW (appGUI->cal->window_date_calculator), GTK_WINDOW (appGUI->main_window));
+	if (config.fullscreen == FALSE) {
+        gtk_window_set_transient_for (GTK_WINDOW (appGUI->cal->window_date_calculator), GTK_WINDOW (appGUI->main_window));
+	}
     gtk_container_set_border_width (GTK_CONTAINER (appGUI->cal->window_date_calculator), 8);
     gtk_window_set_resizable (GTK_WINDOW (appGUI->cal->window_date_calculator), FALSE);
 
@@ -661,9 +666,21 @@ char      tmpbuf[BUFFER_SIZE];
     gtk_widget_show (vbox2);
     gtk_container_add (GTK_CONTAINER (notebook), vbox2);
 
+	hbox99 = gtk_hbox_new (FALSE, 0);
+    gtk_widget_show (hbox99);
+    gtk_box_pack_start (GTK_BOX (vbox2), hbox99, FALSE, FALSE, 0);
+
+	vbox99 = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (vbox99);
+    gtk_box_pack_start (GTK_BOX (hbox99), vbox99, FALSE, FALSE, 0);
+
     frame = gtk_frame_new (NULL);
     gtk_widget_show (frame);
-    gtk_box_pack_start (GTK_BOX (vbox2), frame, FALSE, FALSE, 0);
+	if (!config.gui_layout) {
+	    gtk_box_pack_start (GTK_BOX (vbox2), frame, FALSE, FALSE, 0);
+	} else {
+	    gtk_box_pack_start (GTK_BOX (vbox99), frame, FALSE, FALSE, 0);
+	}
     gtk_container_set_border_width (GTK_CONTAINER (frame), 4);
     gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 
@@ -811,11 +828,7 @@ char      tmpbuf[BUFFER_SIZE];
 	}
     g_signal_connect (button_start_now, "clicked", G_CALLBACK (set_current_time_start_cb), appGUI);
 
-    if (config.default_stock_icons) {
-        button_start_clear = utl_gui_stock_button (GTK_STOCK_CLEAR, FALSE);
-    } else {
-        button_start_clear = utl_gui_stock_button (OSMO_STOCK_BUTTON_CLEAR, FALSE);
-    }
+    button_start_clear = utl_gui_create_button (GTK_STOCK_CLEAR, OSMO_STOCK_BUTTON_CLEAR, FALSE);
 
     gtk_widget_show (button_start_clear);
     GTK_WIDGET_UNSET_FLAGS (button_start_clear, GTK_CAN_FOCUS);
@@ -834,7 +847,11 @@ char      tmpbuf[BUFFER_SIZE];
 
     frame = gtk_frame_new (NULL);
     gtk_widget_show (frame);
-    gtk_box_pack_start (GTK_BOX (vbox2), frame, FALSE, FALSE, 0);
+	if (!config.gui_layout) {
+	    gtk_box_pack_start (GTK_BOX (vbox2), frame, FALSE, FALSE, 0);
+	} else {
+	    gtk_box_pack_start (GTK_BOX (vbox99), frame, FALSE, FALSE, 0);
+	}
     gtk_container_set_border_width (GTK_CONTAINER (frame), 4);
     gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 
@@ -982,11 +999,7 @@ char      tmpbuf[BUFFER_SIZE];
 	}
     g_signal_connect (button_end_now, "clicked", G_CALLBACK (set_current_time_end_cb), appGUI);
 
-    if (config.default_stock_icons) {
-        button_end_clear = utl_gui_stock_button (GTK_STOCK_CLEAR, FALSE);
-    } else {
-        button_end_clear = utl_gui_stock_button (OSMO_STOCK_BUTTON_CLEAR, FALSE);
-    }
+    button_end_clear = utl_gui_create_button (GTK_STOCK_CLEAR, OSMO_STOCK_BUTTON_CLEAR, FALSE);
 
     gtk_widget_show (button_end_clear);
     GTK_WIDGET_UNSET_FLAGS (button_end_clear, GTK_CAN_FOCUS);
@@ -1003,13 +1016,23 @@ char      tmpbuf[BUFFER_SIZE];
     gtk_frame_set_label_widget (GTK_FRAME (frame), label);
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
-    hseparator = gtk_hseparator_new ();
-    gtk_widget_show (hseparator);
-    gtk_box_pack_start (GTK_BOX (vbox2), hseparator, FALSE, FALSE, 6);
+	if (!config.gui_layout) {
+		hseparator = gtk_hseparator_new ();
+		gtk_widget_show (hseparator);
+		gtk_box_pack_start (GTK_BOX (vbox2), hseparator, FALSE, FALSE, 6);
+	} else {
+		hseparator = gtk_vseparator_new ();
+		gtk_widget_show (hseparator);
+		gtk_box_pack_start (GTK_BOX (hbox99), hseparator, FALSE, FALSE, 6);
+	}
 
     frame = gtk_frame_new (NULL);
     gtk_widget_show (frame);
-    gtk_box_pack_start (GTK_BOX (vbox2), frame, FALSE, FALSE, 0);
+	if (!config.gui_layout) {
+        gtk_box_pack_start (GTK_BOX (vbox2), frame, FALSE, FALSE, 0);
+	} else {
+        gtk_box_pack_start (GTK_BOX (hbox99), frame, FALSE, FALSE, 0);
+	}
     gtk_container_set_border_width (GTK_CONTAINER (frame), 4);
     gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 
@@ -1065,9 +1088,17 @@ char      tmpbuf[BUFFER_SIZE];
     gtk_widget_show (vbox7);
     gtk_container_add (GTK_CONTAINER (notebook), vbox7);
 
+	hbox98 = gtk_hbox_new (FALSE, 0);
+    gtk_widget_show (hbox98);
+    gtk_box_pack_start (GTK_BOX (vbox7), hbox98, FALSE, FALSE, 0);
+
     frame = gtk_frame_new (NULL);
     gtk_widget_show (frame);
-    gtk_box_pack_start (GTK_BOX (vbox7), frame, FALSE, FALSE, 0);
+	if (!config.gui_layout) {
+	    gtk_box_pack_start (GTK_BOX (vbox7), frame, FALSE, FALSE, 0);
+	} else {
+	    gtk_box_pack_start (GTK_BOX (hbox98), frame, FALSE, FALSE, 0);
+	}
     gtk_container_set_border_width (GTK_CONTAINER (frame), 4);
     gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 
@@ -1219,11 +1250,7 @@ char      tmpbuf[BUFFER_SIZE];
 	}
     g_signal_connect (button2_start_now, "clicked", G_CALLBACK (set_current_time_start2_cb), appGUI);
 
-    if (config.default_stock_icons) {
-        button2_start_clear = utl_gui_stock_button (GTK_STOCK_CLEAR, FALSE);
-    } else {
-        button2_start_clear = utl_gui_stock_button (OSMO_STOCK_BUTTON_CLEAR, FALSE);
-    }
+    button2_start_clear = utl_gui_create_button (GTK_STOCK_CLEAR, OSMO_STOCK_BUTTON_CLEAR, FALSE);
 
     gtk_widget_show (button2_start_clear);
     GTK_WIDGET_UNSET_FLAGS (button2_start_clear, GTK_CAN_FOCUS);
@@ -1263,7 +1290,11 @@ char      tmpbuf[BUFFER_SIZE];
 
     frame = gtk_frame_new (NULL);
     gtk_widget_show (frame);
-    gtk_box_pack_start (GTK_BOX (vbox7), frame, FALSE, FALSE, 0);
+	if (!config.gui_layout) {
+	    gtk_box_pack_start (GTK_BOX (vbox7), frame, FALSE, FALSE, 0);
+	} else {
+	    gtk_box_pack_start (GTK_BOX (hbox98), frame, FALSE, FALSE, 0);
+	}
     gtk_container_set_border_width (GTK_CONTAINER (frame), 4);
     gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 
@@ -1400,11 +1431,7 @@ char      tmpbuf[BUFFER_SIZE];
 	gtk_box_pack_start (GTK_BOX (hbox10), appGUI->cal->ignore_weekend_days_checkbutton, FALSE, FALSE, 2);
 	gtk_widget_show (appGUI->cal->ignore_weekend_days_checkbutton);
 
-    if (config.default_stock_icons) {
-        button2_end_clear = utl_gui_stock_button (GTK_STOCK_CLEAR, FALSE);
-    } else {
-        button2_end_clear = utl_gui_stock_button (OSMO_STOCK_BUTTON_CLEAR, FALSE);
-    }
+    button2_end_clear = utl_gui_create_button (GTK_STOCK_CLEAR, OSMO_STOCK_BUTTON_CLEAR, FALSE);
 
     gtk_widget_show (button2_end_clear);
     GTK_WIDGET_UNSET_FLAGS (button2_end_clear, GTK_CAN_FOCUS);
@@ -1446,11 +1473,7 @@ char      tmpbuf[BUFFER_SIZE];
     gtk_widget_show (appGUI->cal->label2_result);
     gtk_box_pack_start (GTK_BOX (hbox12), appGUI->cal->label2_result, TRUE, TRUE, 4);
 
-    if (config.default_stock_icons) {
-        jumpto_button = gtk_button_new_from_stock (GTK_STOCK_JUMP_TO);
-    } else {
-        jumpto_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_JUMPTO);
-    }
+	jumpto_button = utl_gui_create_labeled_button (GTK_STOCK_JUMP_TO, OSMO_STOCK_BUTTON_JUMPTO, _("Jump to"));
     gtk_widget_show (jumpto_button);
     g_signal_connect(jumpto_button, "clicked", G_CALLBACK(jumpto_and_window_close_cb), appGUI);
     gtk_box_pack_end (GTK_BOX (hbox12), jumpto_button, FALSE, TRUE, 4);
@@ -1477,11 +1500,7 @@ char      tmpbuf[BUFFER_SIZE];
 
     /*---------------------------------------------------------------------------------*/
 
-    if (config.default_stock_icons) {
-        close_button = gtk_button_new_from_stock (GTK_STOCK_CLOSE);
-    } else {
-        close_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_CLOSE);
-    }
+	close_button = utl_gui_create_labeled_button (GTK_STOCK_CLOSE, OSMO_STOCK_BUTTON_CLOSE, _("Close"));
     gtk_widget_show (close_button);
     GTK_WIDGET_UNSET_FLAGS (close_button, GTK_CAN_FOCUS);
 
@@ -1526,6 +1545,5 @@ char      tmpbuf[BUFFER_SIZE];
     gtk_window_get_position (GTK_WINDOW (appGUI->cal->window_date_calculator), &win_xpos, &win_ypos);
     gtk_window_move (GTK_WINDOW (appGUI->cal->window_date_calculator), win_xpos-5, win_ypos-40);
     gtk_widget_show (appGUI->cal->window_date_calculator);
-
 }
 
