@@ -41,8 +41,10 @@ fullyear_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data
 
 	appGUI->cal->last_selected_year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->fy_spinbutton));
 
-	gtk_window_get_size (GTK_WINDOW (appGUI->cal->fullyear_window),
-	                     &config.fy_window_size_x, &config.fy_window_size_y);
+	if (config.fullscreen == FALSE) {
+		gtk_window_get_size (GTK_WINDOW (appGUI->cal->fullyear_window),
+							 &config.fy_window_size_x, &config.fy_window_size_y);
+	}
 	gtk_widget_destroy (appGUI->cal->fullyear_window);
 }
 
@@ -62,7 +64,7 @@ select_date_day_cb (GtkWidget *widget, gpointer user_data)
 GDate *date;
 
 	MESSAGE *msg = (MESSAGE *) user_data;
-	date = g_date_new_julian ((guint32) msg->data);
+	date = g_date_new_julian ((size_t) msg->data);
 	g_return_if_fail (date != NULL);
 
 	cal_jump_to_date (date, msg->appGUI);
@@ -135,7 +137,7 @@ gchar tmpbuf[BUFFER_SIZE], tmpbuf2[BUFFER_SIZE];
 
 				g_date_set_dmy (cdate, (GDateDay) day, month,
 				                (GDateYear) gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (appGUI->cal->fy_spinbutton)));
-				selected_date[idx].data = (gpointer) g_date_get_julian (cdate);
+				selected_date[idx].data = (gpointer) ((size_t)g_date_get_julian (cdate));
 				selected_date[idx].appGUI = appGUI;
 				g_signal_connect (G_OBJECT (appGUI->cal->calendar_buttons[idx]), "clicked",
 				                  G_CALLBACK (select_date_day_cb), &selected_date[idx]);
@@ -329,6 +331,7 @@ gchar       tmpbuf[BUFFER_SIZE], buffer[BUFFER_SIZE];
 gint        i, j, x, y, idx;
 GDate       *cdate;
 guint       month, year;
+gint rotate = FALSE;
 
 	cdate = g_date_new ();
 	g_return_if_fail (cdate != NULL);
@@ -341,7 +344,9 @@ guint       month, year;
 	gtk_window_set_modal (GTK_WINDOW (appGUI->cal->fullyear_window), TRUE);
 	g_signal_connect (G_OBJECT (appGUI->cal->fullyear_window), "delete_event",
 	                  G_CALLBACK (fullyear_window_close_cb), appGUI);
-	gtk_window_set_transient_for (GTK_WINDOW (appGUI->cal->fullyear_window), GTK_WINDOW (appGUI->main_window));
+	if (config.fullscreen == FALSE) {
+		gtk_window_set_transient_for (GTK_WINDOW (appGUI->cal->fullyear_window), GTK_WINDOW (appGUI->main_window));
+	}
 	gtk_container_set_border_width (GTK_CONTAINER (appGUI->cal->fullyear_window), 8);
 	g_signal_connect (G_OBJECT (appGUI->cal->fullyear_window), "key_press_event",
 	                  G_CALLBACK (fullyear_key_press_cb), appGUI);
@@ -370,11 +375,7 @@ guint       month, year;
 	gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (appGUI->cal->fy_spinbutton), TRUE);
 	gtk_spin_button_set_update_policy (GTK_SPIN_BUTTON (appGUI->cal->fy_spinbutton), GTK_UPDATE_IF_VALID);
 
-	if (config.default_stock_icons) {
-		info_button = utl_gui_stock_button (GTK_STOCK_INFO, FALSE);
-	} else {
-		info_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_INFO, FALSE);
-	}
+	info_button = utl_gui_create_button (GTK_STOCK_INFO, OSMO_STOCK_BUTTON_INFO, FALSE);
 	GTK_WIDGET_UNSET_FLAGS(info_button, GTK_CAN_FOCUS);
 	gtk_widget_show (info_button);
 	g_signal_connect (info_button, "clicked", G_CALLBACK (year_info_cb), appGUI);
@@ -388,11 +389,7 @@ guint       month, year;
 	gtk_widget_show (vseparator);
 	gtk_box_pack_start (GTK_BOX (hbox1), vseparator, FALSE, FALSE, 8);
 
-	if (config.default_stock_icons) {
-		prev_button = utl_gui_stock_button (GTK_STOCK_GO_BACK, FALSE);
-	} else {
-		prev_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_PREV_YEAR, FALSE);
-	}
+	prev_button = utl_gui_create_button (GTK_STOCK_GO_BACK, OSMO_STOCK_BUTTON_PREV_YEAR, FALSE);
 	GTK_WIDGET_UNSET_FLAGS (prev_button, GTK_CAN_FOCUS);
 	gtk_widget_show (prev_button);
 	g_signal_connect (prev_button, "clicked", G_CALLBACK (change_to_previous_year_cb), appGUI);
@@ -402,11 +399,7 @@ guint       month, year;
 	gtk_button_set_relief (GTK_BUTTON (prev_button), GTK_RELIEF_NONE);
 	gtk_box_pack_start (GTK_BOX (hbox1), prev_button, FALSE, FALSE, 2);
 
-	if (config.default_stock_icons) {
-		appGUI->cal->cyear_button = utl_gui_stock_button (GTK_STOCK_HOME, FALSE);
-	} else {
-		appGUI->cal->cyear_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_TODAY, FALSE);
-	}
+	appGUI->cal->cyear_button = utl_gui_create_button (GTK_STOCK_HOME, OSMO_STOCK_BUTTON_TODAY, FALSE);
 	GTK_WIDGET_UNSET_FLAGS (appGUI->cal->cyear_button, GTK_CAN_FOCUS);
 	gtk_widget_show (appGUI->cal->cyear_button);
 	g_signal_connect (appGUI->cal->cyear_button, "clicked", G_CALLBACK (change_to_current_year_cb), appGUI);
@@ -416,11 +409,7 @@ guint       month, year;
 	gtk_button_set_relief (GTK_BUTTON (appGUI->cal->cyear_button), GTK_RELIEF_NONE);
 	gtk_box_pack_start (GTK_BOX (hbox1), appGUI->cal->cyear_button, FALSE, FALSE, 2);
 
-	if (config.default_stock_icons) {
-		next_button = utl_gui_stock_button (GTK_STOCK_GO_FORWARD, FALSE);
-	} else {
-		next_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_NEXT_YEAR, FALSE);
-	}
+	next_button = utl_gui_create_button (GTK_STOCK_GO_FORWARD, OSMO_STOCK_BUTTON_NEXT_YEAR, FALSE);
 	GTK_WIDGET_UNSET_FLAGS(next_button, GTK_CAN_FOCUS);
 	gtk_widget_show (next_button);
 	g_signal_connect (next_button, "clicked", G_CALLBACK (change_to_next_year_cb), appGUI);
@@ -561,6 +550,7 @@ guint       month, year;
 
 		g_date_set_day (cdate, (i % DAYS_PER_WEEK) + 1);
 		g_date_strftime (buffer, BUFFER_SIZE, "%a", cdate);
+		if (g_utf8_strlen (buffer, -1) > 2) rotate = TRUE;
 
 		if (i % 7 + 1 == G_DATE_SATURDAY || i % 7 + 1 == G_DATE_SUNDAY) {
 			g_snprintf (tmpbuf, BUFFER_SIZE, "<span foreground='firebrick'>%s</span>", buffer);
@@ -574,7 +564,8 @@ guint       month, year;
 		                  (GtkAttachOptions) (GTK_FILL),
 		                  (GtkAttachOptions) (0), 0, 0);
 		gtk_misc_set_padding (GTK_MISC (label), 4, 0);
-		gtk_label_set_angle (GTK_LABEL (label), 90);
+		if (rotate)
+			gtk_label_set_angle (GTK_LABEL (label), 90);
 		gtk_label_set_markup (GTK_LABEL (label), tmpbuf);
 
 		if (config.fy_simple_view == FALSE) {
@@ -584,7 +575,8 @@ guint       month, year;
 			                  (GtkAttachOptions) (GTK_FILL),
 			                  (GtkAttachOptions) (0), 0, 0);
 			gtk_misc_set_padding (GTK_MISC (label), 4, 0);
-			gtk_label_set_angle (GTK_LABEL (label), 90);
+			if (rotate)
+				gtk_label_set_angle (GTK_LABEL (label), 90);
 			gtk_label_set_markup (GTK_LABEL (label), tmpbuf);
 		}
 	}
@@ -680,16 +672,13 @@ guint       month, year;
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
 	gtk_box_set_spacing (GTK_BOX (hbuttonbox), 4);
 
-	if (config.default_stock_icons) {
-		close_button = gtk_button_new_from_stock (GTK_STOCK_CLOSE);
-	} else {
-		close_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_CLOSE);
-	}
+	close_button = utl_gui_create_labeled_button (GTK_STOCK_CLOSE, OSMO_STOCK_BUTTON_CLOSE, _("Close"));
 	gtk_widget_show (close_button);
 	g_signal_connect (close_button, "clicked", G_CALLBACK (button_fullyear_window_close_cb), appGUI);
 	gtk_container_add (GTK_CONTAINER (hbuttonbox), close_button);
 
 	gtk_widget_show (appGUI->cal->fullyear_window);
+
 }
 
 /*------------------------------------------------------------------------*/
