@@ -167,6 +167,7 @@ cal_remove_note (guint32 julian, GUI *appGUI)
 		if (n->date == julian) {
 			g_free (n->color);
 			g_free (n->note);
+			g_slice_free (struct note, n);
 			appGUI->cal->notes_list = g_slist_remove (appGUI->cal->notes_list, n);
 			break;
 		}
@@ -185,6 +186,7 @@ cal_free_notes_list (GUI *appGUI)
 		n = (struct note *) node->data;
 		g_free (n->color);
 		g_free (n->note);
+		g_slice_free (struct note, n);
 	}
 
 	g_slist_free (appGUI->cal->notes_list);
@@ -332,7 +334,7 @@ xmlChar *escaped;
 	}
 
 	xmlSaveFormatFileEnc (prefs_get_config_filename (CALENDAR_NOTES_FILENAME, appGUI), doc, "utf-8", 1);
-	xmlFree (attr);
+	xmlFreeProp (attr);
 	xmlFreeDoc (doc);
 
 	appGUI->save_status &= ~WRT_CALENDAR_NOTES;
@@ -416,15 +418,15 @@ gint j, k;
 /*------------------------------------------------------------------------------*/
 
 void
-notes_display_items (guint32 julian_start, guint32 julian_end, gchar *search_string, GUI *appGUI)
+notes_display_items (guint32 julian_start, guint32 julian_end, const gchar *search_string, GUI *appGUI)
 {
 GSList          *lnode;
 struct note     *day_note;
 guint32         julian_day;
 GtkTreeIter     iter;
-gchar           *tmp_note, *stripped, *search_key_1, *search_key_2;
-gboolean        show_flag, case_state;
-gint            i, l, n, m, n_items;
+gchar           *tmp_note, *stripped;
+gboolean        show_flag;
+gint            i, n_items;
 gchar           tmpbuf[BUFFER_SIZE];
 
 	if (appGUI->cal->day_notes_list == NULL || appGUI->cal->day_notes_list_store == NULL) return;
@@ -443,47 +445,12 @@ gchar           tmpbuf[BUFFER_SIZE];
 
 		if (search_string == NULL) {
 			show_flag = TRUE;
-		} else {
-			if (strlen(search_string) != 0) {
-
-				show_flag = FALSE;
-
-				l = strlen (search_string);
-				m = strlen (stripped) - l;
-
-				if (m >= 0) {
-
-					case_state = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->cal->notes_search_checkbutton));
-
-					if (case_state == FALSE) {
-						search_key_1 = g_utf8_casefold (search_string, l);
-					} else {
-						search_key_1 = g_utf8_collate_key (search_string, l);
-					}
-
-					for (n = 0; n < m; n++) {
-
-						if (case_state == FALSE) {
-							search_key_2 = g_utf8_casefold (stripped+n, l);
-						} else {
-							search_key_2 = g_utf8_collate_key (stripped+n, l);
-						}
-
-						if (g_utf8_collate(search_key_1, search_key_2) == 0) {
-							show_flag = TRUE;
-							g_free(search_key_2);
-							break;
-						}
-
-						g_free(search_key_2);
-					}
-
-					g_free(search_key_1);
-				}
-
-			} else {
-				show_flag = TRUE;
-			}
+                } else {
+                    if(gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->cal->notes_search_checkbutton))) {
+                        show_flag = utl_text_strstr(stripped, search_string);
+                    } else {
+                        show_flag = utl_text_strcasestr(stripped, search_string);
+                    }
 		}
 
 		if (((julian_start == 0 && julian_end == 0) ||
@@ -522,10 +489,15 @@ gchar           tmpbuf[BUFFER_SIZE];
 /*------------------------------------------------------------------------------*/
 
 void
-refresh_notes_list (gint filter_mode, gchar *search_string, GUI *appGUI)
+refresh_notes_list (GUI *appGUI)
 {
 guint32 julian_start, julian_end;
 gint month, year;
+gint filter_mode;
+const gchar *search_string;
+
+    filter_mode = gtk_combo_box_get_active(GTK_COMBO_BOX(appGUI->cal->notes_filter_combobox));
+    search_string = gtk_entry_get_text(GTK_ENTRY(appGUI->cal->notes_search_entry));
 
 	gtk_widget_hide (appGUI->cal->notes_month_spinbutton);
 	gtk_widget_hide (appGUI->cal->notes_year_spinbutton);
@@ -574,10 +546,6 @@ gint month, year;
 	}
 
 	notes_display_items (julian_start, julian_end, search_string, appGUI);
-
-	if (appGUI->cal->day_notes_list != NULL) {
-		gtk_widget_grab_focus (appGUI->cal->day_notes_list);
-	}
 }
 
 /*------------------------------------------------------------------------------*/
@@ -587,24 +555,13 @@ notes_filter_changed_cb (GtkComboBox *widget, gpointer user_data)
 {
 	GUI *appGUI = (GUI *) user_data;
 	config.day_notes_browser_filter = gtk_combo_box_get_active (GTK_COMBO_BOX (appGUI->cal->notes_filter_combobox));
-	refresh_notes_list (config.day_notes_browser_filter, NULL, appGUI);
+	refresh_notes_list (appGUI);
 }
-
 /*------------------------------------------------------------------------------*/
 
-gint 
-search_entry_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data) {
-
-    GUI *appGUI = (GUI *)data;
-
-    if (event->keyval == GDK_Return) {
-        refresh_notes_list (gtk_combo_box_get_active (GTK_COMBO_BOX (appGUI->cal->notes_filter_combobox)), 
-                            (gchar *)gtk_entry_get_text(GTK_ENTRY(appGUI->cal->notes_search_entry)), appGUI);
-        gtk_widget_grab_focus (appGUI->cal->notes_search_entry);
-        return TRUE;
-    }
-
-    return FALSE;
+void
+search_entry_changed_cb(GtkEditable *editable, GUI *appGUI) {
+    refresh_notes_list(appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -644,12 +601,17 @@ GDate *date;
 }
 
 /*------------------------------------------------------------------------------*/
-
 void
-browser_past_notes_cb (GtkToggleButton *togglebutton, gpointer user_data)
+browser_case_sensitive_cb (GtkToggleButton *togglebutton, GUI *appGUI)
 {
-	GUI *appGUI = (GUI *)user_data;
-	refresh_notes_list (config.day_notes_browser_filter, NULL, appGUI);
+    refresh_notes_list(appGUI);
+}
+
+/*------------------------------------------------------------------------------*/
+void
+browser_past_notes_cb (GtkToggleButton *togglebutton, GUI *appGUI)
+{
+	refresh_notes_list (appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -681,7 +643,9 @@ gchar               tmpbuf[BUFFER_SIZE];
     gtk_window_set_modal (GTK_WINDOW (appGUI->cal->day_notes_window), TRUE);
     g_signal_connect (G_OBJECT (appGUI->cal->day_notes_window), "delete_event",
                       G_CALLBACK(day_notes_window_close_cb), appGUI);
-    gtk_window_set_transient_for(GTK_WINDOW(appGUI->cal->day_notes_window), GTK_WINDOW(appGUI->main_window));
+	if (config.fullscreen == FALSE) {
+        gtk_window_set_transient_for(GTK_WINDOW(appGUI->cal->day_notes_window), GTK_WINDOW(appGUI->main_window));
+	}
     gtk_container_set_border_width (GTK_CONTAINER (appGUI->cal->day_notes_window), 8);
     g_signal_connect (G_OBJECT (appGUI->cal->day_notes_window), "key_press_event",
                       G_CALLBACK (day_notes_key_press_cb), appGUI);
@@ -768,8 +732,6 @@ gchar               tmpbuf[BUFFER_SIZE];
     gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->cal->notes_filter_combobox), _("Selected month and year"));
     gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->cal->notes_filter_combobox), _("All notes"));
 
-    gtk_combo_box_set_active(GTK_COMBO_BOX(appGUI->cal->notes_filter_combobox), config.day_notes_browser_filter);
-
     appGUI->cal->n_items_label = gtk_label_new ("");
     gtk_widget_show (appGUI->cal->n_items_label);
     gtk_widget_set_size_request (appGUI->cal->n_items_label, 100, -1);
@@ -783,10 +745,12 @@ gchar               tmpbuf[BUFFER_SIZE];
     gtk_table_attach (GTK_TABLE (notes_tools_table), appGUI->cal->notes_search_entry, 1, 2, 2, 3,
                       (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
-    g_signal_connect (G_OBJECT (appGUI->cal->notes_search_entry), "key_press_event",
-                        G_CALLBACK (search_entry_key_press_cb), appGUI);
+    g_signal_connect (G_OBJECT (appGUI->cal->notes_search_entry), "changed",
+                        G_CALLBACK (search_entry_changed_cb), appGUI);
 
     appGUI->cal->notes_search_checkbutton = gtk_check_button_new_with_mnemonic (_("Case sensitive"));
+    g_signal_connect (G_OBJECT (appGUI->cal->notes_search_checkbutton), "toggled",
+                      G_CALLBACK (browser_case_sensitive_cb), appGUI);
     gtk_widget_show (appGUI->cal->notes_search_checkbutton);
     GTK_WIDGET_UNSET_FLAGS(appGUI->cal->notes_search_checkbutton, GTK_CAN_FOCUS);
     gtk_table_attach (GTK_TABLE (notes_tools_table), appGUI->cal->notes_search_checkbutton, 2, 3, 2, 3,
@@ -863,7 +827,7 @@ gchar               tmpbuf[BUFFER_SIZE];
     gtk_tree_view_column_set_visible (column, FALSE);
     gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->cal->day_notes_list), column);
 
-    refresh_notes_list (config.day_notes_browser_filter, NULL, appGUI);
+    gtk_combo_box_set_active(GTK_COMBO_BOX(appGUI->cal->notes_filter_combobox), config.day_notes_browser_filter);
    
     hseparator = gtk_hseparator_new ();
     gtk_widget_show (hseparator);
@@ -875,11 +839,7 @@ gchar               tmpbuf[BUFFER_SIZE];
     gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
     gtk_box_set_spacing (GTK_BOX (hbuttonbox), 4);
 
-    if (config.default_stock_icons) {
-        close_button = gtk_button_new_from_stock (GTK_STOCK_CLOSE);
-    } else {
-        close_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_CLOSE);
-    }
+	close_button = utl_gui_create_labeled_button (GTK_STOCK_CLOSE, OSMO_STOCK_BUTTON_CLOSE, _("Close"));
     gtk_widget_show (close_button);
     GTK_WIDGET_UNSET_FLAGS(close_button, GTK_CAN_FOCUS);
     g_signal_connect(close_button, "clicked", G_CALLBACK(button_day_notes_window_close_cb), appGUI);
