@@ -314,19 +314,13 @@ create_appearance_section (GtkWidget *appearance_vbox, GUI *appGUI)
 	gtk_table_attach (GTK_TABLE (table), b_hbox, 5, 7, i, i+1,
 	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (GTK_FILL), 0, 0);
 
-	if (config.default_stock_icons)
-		button = utl_gui_stock_button (GTK_STOCK_CLEAR, FALSE);
-	else
-		button = utl_gui_stock_button (OSMO_STOCK_BUTTON_CLEAR, FALSE);
+	button = utl_gui_create_button (GTK_STOCK_CLEAR, OSMO_STOCK_BUTTON_CLEAR, FALSE);
 	if (config.enable_tooltips)
 		gtk_widget_set_tooltip_text (button, _("Set default format"));
 	g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (dh_default_cb), appGUI);
 	gtk_box_pack_start (GTK_BOX (b_hbox), button, FALSE, FALSE, 0);
 
-	if (config.default_stock_icons)
-		button = utl_gui_stock_button (GTK_STOCK_HELP, FALSE);
-	else
-		button = utl_gui_stock_button (OSMO_STOCK_HELP, FALSE);
+	button = utl_gui_create_button (GTK_STOCK_HELP, OSMO_STOCK_HELP, FALSE);
 	if (config.enable_tooltips)
 		gtk_widget_set_tooltip_text (button, _("Date format syntax"));
 	g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (dh_help_cb), appGUI);
@@ -468,10 +462,7 @@ create_appearance_section (GtkWidget *appearance_vbox, GUI *appGUI)
 	sel1.font = &appGUI->cal->fd_day_name_font;
 	sel1.widget = appGUI->cal->date_label;
 
-	if (config.default_stock_icons)
-		button = utl_gui_stock_button (GTK_STOCK_SELECT_FONT, FALSE);
-	else
-		button = utl_gui_stock_button (OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
+	button = utl_gui_create_button (GTK_STOCK_SELECT_FONT, OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
 	gtk_table_attach (GTK_TABLE (table), button, 6, 7, i, i+1,
 	                  (GtkAttachOptions) (0), (GtkAttachOptions) (0), 0, 0);
 	g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (utl_gui_font_select_cb), &sel1);
@@ -492,10 +483,7 @@ create_appearance_section (GtkWidget *appearance_vbox, GUI *appGUI)
 	sel2.font = &appGUI->cal->fd_cal_font;
 	sel2.widget = appGUI->cal->calendar;
 
-	if (config.default_stock_icons)
-		button = utl_gui_stock_button (GTK_STOCK_SELECT_FONT, FALSE);
-	else
-		button = utl_gui_stock_button (OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
+	button = utl_gui_create_button (GTK_STOCK_SELECT_FONT, OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
 	gtk_table_attach (GTK_TABLE (table), button, 6, 7, i, i+1,
 	                  (GtkAttachOptions) (0), (GtkAttachOptions) (0), 0, 0);
 	g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (utl_gui_font_select_cb), &sel2);
@@ -516,10 +504,7 @@ create_appearance_section (GtkWidget *appearance_vbox, GUI *appGUI)
 	sel3.font = &appGUI->cal->fd_notes_font;
 	sel3.widget = appGUI->cal->calendar_note_textview;
 
-	if (config.default_stock_icons)
-		button = utl_gui_stock_button (GTK_STOCK_SELECT_FONT, FALSE);
-	else
-		button = utl_gui_stock_button (OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
+	button = utl_gui_create_button (GTK_STOCK_SELECT_FONT, OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
 	g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (utl_gui_font_select_cb), &sel3);
 	gtk_table_attach (GTK_TABLE (table), button, 6, 7, i, i+1,
 	                  (GtkAttachOptions) (0), (GtkAttachOptions) (0), 0, 0);
@@ -696,11 +681,11 @@ gui_color_edit_action (GtkTreeIter *iter, GtkTreeModel *model, GUI *appGUI)
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
 	gtk_box_set_spacing (GTK_BOX (hbuttonbox), 4);
 
-	cancel_button = utl_gui_create_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
+	cancel_button = utl_gui_create_labeled_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
 	gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
 	g_signal_connect (G_OBJECT (cancel_button), "clicked", G_CALLBACK (close_window), appGUI->opt->color_edit_window);
 
-	appGUI->opt->color_edit_ok_button = utl_gui_create_button (GTK_STOCK_OK, OSMO_STOCK_BUTTON_OK, _("OK"));
+	appGUI->opt->color_edit_ok_button = utl_gui_create_labeled_button (GTK_STOCK_OK, OSMO_STOCK_BUTTON_OK, _("OK"));
 	gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->opt->color_edit_ok_button);
 	g_signal_connect (G_OBJECT (appGUI->opt->color_edit_ok_button), "clicked", G_CALLBACK (color_edit_action_cb), appGUI);
 
@@ -906,30 +891,21 @@ create_day_categories_section (GtkWidget *day_categories_vbox, GUI *appGUI)
 	column = gtk_tree_view_column_new_with_attributes (NULL, renderer, "text", 2, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 
-	if (config.default_stock_icons)
-		button = utl_gui_stock_button (GTK_STOCK_ADD, FALSE);
-	else
-		button = utl_gui_stock_button (OSMO_STOCK_BUTTON_ADD, FALSE);
+	button = utl_gui_create_button (GTK_STOCK_ADD, OSMO_STOCK_BUTTON_ADD, FALSE);
 	gtk_widget_set_sensitive (button, FALSE);
 	gtk_table_attach (GTK_TABLE (table), button, 2, 3, 3, 4,
 	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 	g_signal_connect (button, "clicked", G_CALLBACK (calendar_category_add_cb), appGUI);
 	appGUI->opt->calendar_category_add_button = button;
 
-	if (config.default_stock_icons)
-		button = utl_gui_stock_button (GTK_STOCK_EDIT, FALSE);
-	else
-		button = utl_gui_stock_button (OSMO_STOCK_BUTTON_EDIT, FALSE);
+	button = utl_gui_create_button (GTK_STOCK_EDIT, OSMO_STOCK_BUTTON_EDIT, FALSE);
 	gtk_widget_set_sensitive (button, FALSE);
 	gtk_table_attach (GTK_TABLE (table), button, 3, 4, 3, 4,
 	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 	g_signal_connect (button, "clicked", G_CALLBACK (calendar_category_edit_cb), appGUI);
 	appGUI->opt->calendar_category_edit_button = button;
 
-	if (config.default_stock_icons)
-		button = utl_gui_stock_button (GTK_STOCK_REMOVE, FALSE);
-	else
-		button = utl_gui_stock_button (OSMO_STOCK_BUTTON_REMOVE, FALSE);
+	button = utl_gui_create_button (GTK_STOCK_REMOVE, OSMO_STOCK_BUTTON_REMOVE, FALSE);
 	gtk_widget_set_sensitive (button, FALSE);
 	gtk_table_attach (GTK_TABLE (table), button, 4, 5, 3, 4,
 	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
@@ -1258,11 +1234,7 @@ gui_ical_entry_edit_action (GtkTreeIter *iter, GtkTreeModel *model, GUI *appGUI)
 	GTK_WIDGET_UNSET_FLAGS (appGUI->opt->ical_edit_filename_entry, GTK_CAN_FOCUS);
 	gtk_editable_set_editable (GTK_EDITABLE (appGUI->opt->ical_edit_filename_entry), FALSE);
 
-	if (config.default_stock_icons)
-		appGUI->opt->ical_edit_filename_browse_button = utl_gui_stock_button (GTK_STOCK_DIRECTORY, FALSE);
-	else
-		appGUI->opt->ical_edit_filename_browse_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_OPEN, FALSE);
-
+	appGUI->opt->ical_edit_filename_browse_button = utl_gui_create_button (GTK_STOCK_DIRECTORY, OSMO_STOCK_BUTTON_OPEN, FALSE);
 	gtk_box_pack_start (GTK_BOX (hbox), appGUI->opt->ical_edit_filename_browse_button, FALSE, TRUE, 0);
 	g_signal_connect (appGUI->opt->ical_edit_filename_browse_button, "clicked", G_CALLBACK (ical_edit_filename_browse_cb), appGUI);
 
@@ -1289,11 +1261,11 @@ gui_ical_entry_edit_action (GtkTreeIter *iter, GtkTreeModel *model, GUI *appGUI)
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
 	gtk_box_set_spacing (GTK_BOX (hbuttonbox), 4);
 
-	cancel_button = utl_gui_create_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
+	cancel_button = utl_gui_create_labeled_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
 	gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
 	g_signal_connect (G_OBJECT (cancel_button), "clicked", G_CALLBACK (close_window), (gpointer) window);
 
-	appGUI->opt->ical_edit_ok_button = utl_gui_create_button (GTK_STOCK_OK, OSMO_STOCK_BUTTON_OK, _("OK"));
+	appGUI->opt->ical_edit_ok_button = utl_gui_create_labeled_button (GTK_STOCK_OK, OSMO_STOCK_BUTTON_OK, _("OK"));
 	GTK_WIDGET_UNSET_FLAGS (appGUI->opt->ical_edit_ok_button, GTK_CAN_FOCUS);
 	gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->opt->ical_edit_ok_button);
 	g_signal_connect (G_OBJECT (appGUI->opt->ical_edit_ok_button), "clicked",
@@ -1417,10 +1389,7 @@ create_icalendar_files_section (GtkWidget *icalendar_files_vbox, GUI *appGUI)
 	gtk_table_attach (GTK_TABLE (table), appGUI->opt->calendar_ical_files_filename_entry, 1, 4, 3, 4,
 	                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 
-	if (config.default_stock_icons)
-		button = utl_gui_stock_button (GTK_STOCK_DIRECTORY, FALSE);
-	else
-		button = utl_gui_stock_button (OSMO_STOCK_BUTTON_OPEN, FALSE);
+	button = utl_gui_create_button (GTK_STOCK_DIRECTORY, OSMO_STOCK_BUTTON_OPEN, FALSE);
 	gtk_table_attach (GTK_TABLE (table), button, 4, 5, 3, 4,
 	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 	g_signal_connect (button, "clicked", G_CALLBACK (calendar_ical_files_browse_cb), appGUI);
@@ -1432,30 +1401,21 @@ create_icalendar_files_section (GtkWidget *icalendar_files_vbox, GUI *appGUI)
 	g_signal_connect (G_OBJECT (appGUI->opt->calendar_ical_files_name_entry), "key_release_event",
 	                  G_CALLBACK (calendar_ical_files_entry_key_release_cb), appGUI);
 
-	if (config.default_stock_icons)
-		button = utl_gui_stock_button (GTK_STOCK_ADD, FALSE);
-	else
-		button = utl_gui_stock_button (OSMO_STOCK_BUTTON_ADD, FALSE);
+	button = utl_gui_create_button (GTK_STOCK_ADD, OSMO_STOCK_BUTTON_ADD, FALSE);
 	gtk_widget_set_sensitive (button, FALSE);
 	gtk_table_attach (GTK_TABLE (table), button, 2, 3, 4, 5,
 	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 	g_signal_connect (button, "clicked", G_CALLBACK (calendar_ical_files_add_cb), appGUI);
 	appGUI->opt->calendar_ical_files_add_button = button;
 
-	if (config.default_stock_icons)
-		button = utl_gui_stock_button (GTK_STOCK_EDIT, FALSE);
-	else
-		button = utl_gui_stock_button (OSMO_STOCK_BUTTON_EDIT, FALSE);
+	button = utl_gui_create_button (GTK_STOCK_EDIT, OSMO_STOCK_BUTTON_EDIT, FALSE);
 	gtk_widget_set_sensitive (button, FALSE);
 	gtk_table_attach (GTK_TABLE (table), button, 3, 4, 4, 5,
 	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 	g_signal_connect (button, "clicked", G_CALLBACK (calendar_ical_files_edit_cb), appGUI);
 	appGUI->opt->calendar_ical_files_edit_button = button;
 
-	if (config.default_stock_icons)
-		button = utl_gui_stock_button (GTK_STOCK_REMOVE, FALSE);
-	else
-		button = utl_gui_stock_button (OSMO_STOCK_BUTTON_REMOVE, FALSE);
+	button = utl_gui_create_button (GTK_STOCK_REMOVE, OSMO_STOCK_BUTTON_REMOVE, FALSE);
 	gtk_widget_set_sensitive (button, FALSE);
 	gtk_table_attach (GTK_TABLE (table), button, 4, 5, 4, 5,
 	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
@@ -1711,6 +1671,7 @@ static void
 day_info_panel_options_cb (GtkToggleButton *togglebutton, GUI *appGUI)
 {
 	config.di_show_current_time = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->di_show_current_time_checkbutton));
+	config.di_show_current_time_seconds = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->di_show_current_time_seconds_checkbutton));
 	config.di_show_day_number = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->di_show_day_number_checkbutton));
 	config.di_show_current_day_distance = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->di_show_current_day_distance_checkbutton));
 	config.di_show_marked_days = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->di_show_marked_days_checkbutton));
@@ -1720,6 +1681,8 @@ day_info_panel_options_cb (GtkToggleButton *togglebutton, GUI *appGUI)
 	config.di_show_moon_phase = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->di_show_moon_phase_checkbutton));
 	config.di_show_notes = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->di_show_notes_checkbutton));
 	config.di_show_zodiac_sign = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->opt->di_show_zodiac_sign_checkbutton));
+        
+	gtk_widget_set_sensitive (appGUI->opt->di_show_current_time_seconds_checkbutton, config.di_show_current_time);
 
 	g_signal_emit_by_name (G_OBJECT (appGUI->cal->calendar), "day-selected");
 }
@@ -1729,7 +1692,7 @@ day_info_panel_options_cb (GtkToggleButton *togglebutton, GUI *appGUI)
 static void
 create_day_info_panel_section (GtkWidget *day_info_panel_vbox, GUI *appGUI)
 {
-	GtkWidget *table, *checkbutton;
+	GtkWidget *table, *checkbutton, *alignment;
 	gint i;
 
 	table = gtk_table_new (9, 1, FALSE);
@@ -1744,6 +1707,18 @@ create_day_info_panel_section (GtkWidget *day_info_panel_vbox, GUI *appGUI)
 	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (day_info_panel_options_cb), appGUI);
 	appGUI->opt->di_show_current_time_checkbutton = checkbutton;
 
+	i++;
+	alignment = gtk_alignment_new (0.5, 0.5, 1, 1);
+	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 16, 0);
+	gtk_table_attach (GTK_TABLE (table), alignment, 0, 1, i, i+1,
+	                  (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), (GtkAttachOptions) (0), 0, 0);
+	checkbutton = gtk_check_button_new_with_mnemonic (_("Show seconds"));
+	gtk_container_add (GTK_CONTAINER (alignment), checkbutton);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.di_show_current_time_seconds);
+	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (day_info_panel_options_cb), appGUI);
+	gtk_widget_set_sensitive (checkbutton, config.di_show_current_time);
+	appGUI->opt->di_show_current_time_seconds_checkbutton = checkbutton;
+
 	i++;
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Day number"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.di_show_day_number);
