@@ -608,11 +608,7 @@ calendar_create_print_window (GUI *appGUI)
 	sel1.config = config.cal_print_month_name_font;
 	sel1.entry = appGUI->cal->print_month_name_font_entry;
 
-	if (config.default_stock_icons) {
-		month_name_font_button = utl_gui_stock_button (GTK_STOCK_SELECT_FONT, FALSE);
-	} else {
-		month_name_font_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
-	}
+	month_name_font_button = utl_gui_create_button (GTK_STOCK_SELECT_FONT, OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
 	GTK_WIDGET_UNSET_FLAGS (month_name_font_button, GTK_CAN_FOCUS);
 	gtk_widget_show (month_name_font_button);
 	g_signal_connect (G_OBJECT (month_name_font_button), "clicked",
@@ -638,11 +634,7 @@ calendar_create_print_window (GUI *appGUI)
 	sel2.config = config.cal_print_day_name_font;
 	sel2.entry = appGUI->cal->print_day_name_font_entry;
 
-	if (config.default_stock_icons) {
-		day_name_font_button = utl_gui_stock_button (GTK_STOCK_SELECT_FONT, FALSE);
-	} else {
-		day_name_font_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
-	}
+	day_name_font_button = utl_gui_create_button (GTK_STOCK_SELECT_FONT, OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
 	GTK_WIDGET_UNSET_FLAGS (day_name_font_button, GTK_CAN_FOCUS);
 	gtk_widget_show (day_name_font_button);
 	g_signal_connect (G_OBJECT (day_name_font_button), "clicked",
@@ -668,11 +660,7 @@ calendar_create_print_window (GUI *appGUI)
 	sel3.config = config.cal_print_day_num_font;
 	sel3.entry = appGUI->cal->print_day_num_font_entry;
 
-	if (config.default_stock_icons) {
-		day_number_font_button = utl_gui_stock_button (GTK_STOCK_SELECT_FONT, FALSE);
-	} else {
-		day_number_font_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
-	}
+	day_number_font_button = utl_gui_create_button (GTK_STOCK_SELECT_FONT, OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
 	GTK_WIDGET_UNSET_FLAGS (day_number_font_button, GTK_CAN_FOCUS);
 	gtk_widget_show (day_number_font_button);
 	g_signal_connect (G_OBJECT (day_number_font_button), "clicked",
@@ -698,11 +686,7 @@ calendar_create_print_window (GUI *appGUI)
 	sel4.config = config.cal_print_event_font;
 	sel4.entry = appGUI->cal->print_event_font_entry;
 
-	if (config.default_stock_icons) {
-		event_font_button = utl_gui_stock_button (GTK_STOCK_SELECT_FONT, FALSE);
-	} else {
-		event_font_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
-	}
+	event_font_button = utl_gui_create_button (GTK_STOCK_SELECT_FONT, OSMO_STOCK_BUTTON_SELECT_FONT, FALSE);
 	GTK_WIDGET_UNSET_FLAGS (event_font_button, GTK_CAN_FOCUS);
 	gtk_widget_show (event_font_button);
 	g_signal_connect (G_OBJECT (event_font_button), "clicked",
@@ -870,12 +854,12 @@ calendar_create_print_window (GUI *appGUI)
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
 	gtk_box_set_spacing (GTK_BOX (hbuttonbox), 16);
 
-	cancel_button = utl_gui_create_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
+	cancel_button = utl_gui_create_labeled_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
 	gtk_widget_show (cancel_button);
 	g_signal_connect (cancel_button, "clicked", G_CALLBACK (window_button_cal_print_opt_close_cb), appGUI);
 	gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
 
-	ok_button = utl_gui_create_button (GTK_STOCK_OK, OSMO_STOCK_BUTTON_OK, _("OK"));
+	ok_button = utl_gui_create_labeled_button (GTK_STOCK_OK, OSMO_STOCK_BUTTON_OK, _("OK"));
 	gtk_widget_show (ok_button);
 	g_signal_connect (ok_button, "clicked", G_CALLBACK (calendar_print_start_cb), appGUI);
 	gtk_container_add (GTK_CONTAINER (hbuttonbox), ok_button);
