@@ -197,7 +197,7 @@ char tmpbuf[BUFFER_SIZE];
                      (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
-    tl_start_h_spinbutton_adj = gtk_adjustment_new (1, 0, 24, 1, 10, 10);
+    tl_start_h_spinbutton_adj = gtk_adjustment_new (1, 0, 24, 1, 10, 0);
     appGUI->cal->tl_start_h_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (tl_start_h_spinbutton_adj), 1, 0);
     gtk_widget_show (appGUI->cal->tl_start_h_spinbutton);
     gtk_table_attach (GTK_TABLE (timeline_table), appGUI->cal->tl_start_h_spinbutton, 1, 2, 0, 1,
@@ -213,7 +213,7 @@ char tmpbuf[BUFFER_SIZE];
                      (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
-    tl_step_spinbutton_adj = gtk_adjustment_new (1, 1, 120, 1, 10, 10);
+    tl_step_spinbutton_adj = gtk_adjustment_new (1, 1, 120, 1, 10, 0);
     appGUI->cal->tl_step_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (tl_step_spinbutton_adj), 1, 0);
     gtk_widget_show (appGUI->cal->tl_step_spinbutton);
     gtk_table_attach (GTK_TABLE (timeline_table), appGUI->cal->tl_step_spinbutton, 1, 2, 2, 3,
@@ -229,7 +229,7 @@ char tmpbuf[BUFFER_SIZE];
                       (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
-    tl_end_h_spinbutton_adj = gtk_adjustment_new (1, 1, 23, 1, 10, 10);
+    tl_end_h_spinbutton_adj = gtk_adjustment_new (1, 1, 23, 1, 10, 0);
     appGUI->cal->tl_end_h_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (tl_end_h_spinbutton_adj), 1, 0);
     gtk_widget_show (appGUI->cal->tl_end_h_spinbutton);
     gtk_table_attach (GTK_TABLE (timeline_table), appGUI->cal->tl_end_h_spinbutton, 1, 2, 1, 2,
@@ -249,7 +249,7 @@ char tmpbuf[BUFFER_SIZE];
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
 
-    tl_start_m_spinbutton_adj = gtk_adjustment_new (0, 0, 59, 1, 10, 10);
+    tl_start_m_spinbutton_adj = gtk_adjustment_new (0, 0, 59, 1, 10, 0);
     appGUI->cal->tl_start_m_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (tl_start_m_spinbutton_adj), 1, 0);
     gtk_widget_show (appGUI->cal->tl_start_m_spinbutton);
     gtk_table_attach (GTK_TABLE (timeline_table), appGUI->cal->tl_start_m_spinbutton, 3, 4, 0, 1,
@@ -257,7 +257,7 @@ char tmpbuf[BUFFER_SIZE];
                       (GtkAttachOptions) (0), 0, 0);
     gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (appGUI->cal->tl_start_m_spinbutton), TRUE);
 
-    tl_end_m_spinbutton_adj = gtk_adjustment_new (0, 0, 59, 1, 10, 10);
+    tl_end_m_spinbutton_adj = gtk_adjustment_new (0, 0, 59, 1, 10, 0);
     appGUI->cal->tl_end_m_spinbutton = gtk_spin_button_new (GTK_ADJUSTMENT (tl_end_m_spinbutton_adj), 1, 0);
     gtk_widget_show (appGUI->cal->tl_end_m_spinbutton);
     gtk_table_attach (GTK_TABLE (timeline_table), appGUI->cal->tl_end_m_spinbutton, 3, 4, 1, 2,
@@ -288,20 +288,12 @@ char tmpbuf[BUFFER_SIZE];
     gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
     gtk_box_set_spacing (GTK_BOX (hbuttonbox), 4);
 
-    if (config.default_stock_icons) {
-        appGUI->cal->cancel_button = gtk_button_new_from_stock (GTK_STOCK_CANCEL); 
-    } else {
-        appGUI->cal->cancel_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_CANCEL); 
-    }
+    appGUI->cal->cancel_button = utl_gui_create_labeled_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel")); 
     gtk_widget_show (appGUI->cal->cancel_button);
     g_signal_connect(appGUI->cal->cancel_button, "clicked", G_CALLBACK(button_insert_timeline_window_close_cb), appGUI);
     gtk_container_add(GTK_CONTAINER(hbuttonbox), appGUI->cal->cancel_button);   
 
-    if (config.default_stock_icons) {
-        appGUI->cal->insert_timeline_button = gtk_button_new_from_stock (GTK_STOCK_PASTE); 
-    } else {
-        appGUI->cal->insert_timeline_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_INSERT_TIMELINE); 
-    }
+    appGUI->cal->insert_timeline_button = utl_gui_create_labeled_button (GTK_STOCK_PASTE, OSMO_STOCK_BUTTON_INSERT_TIMELINE, _("Insert")); 
     gtk_widget_show (appGUI->cal->insert_timeline_button);
     g_signal_connect(appGUI->cal->insert_timeline_button, "clicked", G_CALLBACK(insert_timeline_action_cb), appGUI);
     gtk_container_add(GTK_CONTAINER(hbuttonbox), appGUI->cal->insert_timeline_button);   
