@@ -40,9 +40,34 @@
 /* Not needed, retained for compatibility -Yosh */
 #include <gtk/gtksignal.h>
 
-
 G_BEGIN_DECLS
 
+/* Spacing around day/week headers and main area, inside those windows */
+#define CALENDAR_MARGIN      0
+/* Spacing around day/week headers and main area, outside those windows */
+#define INNER_BORDER         1
+/* Separation between day headers and main area */
+#define CALENDAR_YSEP        4
+/* Separation between week headers and main area */
+#define CALENDAR_XSEP        4
+
+#define DAY_XSEP             0  /* not really good for small calendar */
+#define DAY_YSEP             0  /* not really good for small calendar */
+
+#define SCROLL_DELAY_FACTOR  5
+
+/* Color usage */
+#define HEADER_FG_COLOR(widget)      (& (widget)->style->fg[GTK_WIDGET_STATE (widget)])
+#define HEADER_BG_COLOR(widget)      (& (widget)->style->bg[GTK_WIDGET_STATE (widget)])
+#define SELECTED_BG_COLOR(widget)    (& (widget)->style->base[GTK_WIDGET_HAS_FOCUS (widget) ? GTK_STATE_SELECTED : GTK_STATE_ACTIVE])
+#define SELECTED_FG_COLOR(widget)    (& (widget)->style->text[GTK_WIDGET_HAS_FOCUS (widget) ? GTK_STATE_SELECTED : GTK_STATE_ACTIVE])
+#define NORMAL_DAY_COLOR(widget)     (& (widget)->style->fg[GTK_WIDGET_STATE (widget)])
+#define PREV_MONTH_COLOR(widget)     (& (widget)->style->mid[GTK_WIDGET_STATE (widget)])
+#define NEXT_MONTH_COLOR(widget)     (& (widget)->style->mid[GTK_WIDGET_STATE (widget)])
+#define MARKED_COLOR(widget)         (& (widget)->style->fg[GTK_WIDGET_STATE (widget)])
+#define BACKGROUND_COLOR(widget)     (& (widget)->style->base[GTK_WIDGET_STATE (widget)])
+#define HIGHLIGHT_BACK_COLOR(widget) (& (widget)->style->mid[GTK_WIDGET_STATE (widget)])
+
 #define GUI_TYPE_CALENDAR                  (gui_calendar_get_type ())
 #define GUI_CALENDAR(obj)                  (G_TYPE_CHECK_INSTANCE_CAST ((obj), GUI_TYPE_CALENDAR, GuiCalendar))
 #define GUI_CALENDAR_CLASS(klass)          (G_TYPE_CHECK_CLASS_CAST ((klass), GUI_TYPE_CALENDAR, GuiCalendarClass))
@@ -50,7 +75,6 @@ G_BEGIN_DECLS
 #define GUI_IS_CALENDAR_CLASS(klass)       (G_TYPE_CHECK_CLASS_TYPE ((klass), GUI_TYPE_CALENDAR))
 #define GUI_CALENDAR_GET_CLASS(obj)        (G_TYPE_INSTANCE_GET_CLASS ((obj), GUI_TYPE_CALENDAR, GuiCalendarClass))
 
-
 typedef struct _GuiCalendar             GuiCalendar;
 typedef struct _GuiCalendarClass       GuiCalendarClass;
 
@@ -64,6 +88,43 @@ typedef enum {
     GUI_CALENDAR_WEEK_START_MONDAY  = 1 << 4
 } GuiCalendarDisplayOptions;
 
+enum {
+    ARROW_YEAR_LEFT,
+    ARROW_YEAR_RIGHT,
+    ARROW_MONTH_LEFT,
+    ARROW_MONTH_RIGHT
+};
+
+enum {
+    MONTH_PREV,
+    MONTH_CURRENT,
+    MONTH_NEXT
+};
+
+enum {
+    MONTH_CHANGED_SIGNAL,
+    DAY_SELECTED_SIGNAL,
+    DAY_SELECTED_DOUBLE_CLICK_SIGNAL,
+    PREV_MONTH_SIGNAL,
+    NEXT_MONTH_SIGNAL,
+    PREV_YEAR_SIGNAL,
+    NEXT_YEAR_SIGNAL,
+    LAST_SIGNAL
+};
+
+enum {
+    PROP_0,
+    PROP_YEAR,
+    PROP_MONTH,
+    PROP_DAY,
+    PROP_SHOW_HEADING,
+    PROP_SHOW_DAY_NAMES,
+    PROP_NO_MONTH_CHANGE,
+    PROP_SHOW_WEEK_NUMBERS,
+    PROP_WEEK_START_MONDAY,
+    PROP_LAST
+};
+
 enum {
     CURSOR_BLOCK = 0,
     CURSOR_FRAME
@@ -79,6 +140,70 @@ enum {
 	TODAY_MARKER_ARROW = 0,
 	TODAY_MARKER_FREEHAND_CIRCLE
 };
+		
+enum {
+	TODAY_MARKER =0,
+	EVENT_MARKER
+};
+
+enum {
+	DAY_NOTE_MARK =0,
+	EVENT_MARK,
+	BIRTHDAY_MARK
+};
+
+enum {
+	HEADER_COLOR = 0,
+	WEEKEND_COLOR,
+	SELECTOR_COLOR,
+	EVENT_MARKER_COLOR,
+	TODAY_MARKER_COLOR,
+	BIRTHDAY_MARKER_COLOR
+};
+
+struct _GuiCalendarPrivate {
+    GdkWindow *header_win;
+    GdkWindow *day_name_win;
+    GdkWindow *main_win;
+    GdkWindow *week_win;
+    GdkWindow *arrow_win[4];
+
+    guint header_h;
+    guint day_name_h;
+    guint main_h;
+
+    guint arrow_state[4];
+    guint arrow_width;
+    guint max_month_width;
+    guint max_year_width;
+
+    guint day_width;
+    guint week_width;
+
+    guint min_day_width;
+    guint max_day_char_width;
+    guint max_day_char_ascent;
+    guint max_day_char_descent;
+    guint max_label_char_ascent;
+    guint max_label_char_descent;
+    guint max_week_char_width;
+
+    /* flags */
+	guint year_before : 1;
+	guint need_timer  : 1;
+	guint in_drag : 1;
+	guint drag_highlight : 1;
+
+    guint32 timer;
+    gint click_child;
+
+    gint week_start;
+
+    gint drag_start_x;
+    gint drag_start_y;
+};
+
+#define GUI_CALENDAR_GET_PRIVATE(widget)  (GUI_CALENDAR (widget)->priv)
 
 struct _GuiCalendar {
     GtkWidget widget;
@@ -93,11 +218,16 @@ struct _GuiCalendar {
     gint day_month[6][7];
     gint day[6][7];
 
-    gint tc_num_marked_dates;
-    gint tc_marked_date[31];
-
+	/* day notes */
     gint num_marked_dates;
     gint marked_date[31];
+	/* events */
+	gint event_num_marked_dates;
+    gint event_marked_date[31];
+	/* birthdays */
+	gint birthday_num_marked_dates;
+    gint birthday_marked_date[31];
+
     GuiCalendarDisplayOptions  display_flags;
     GdkColor marked_date_color[31];
 
@@ -106,6 +236,7 @@ struct _GuiCalendar {
     GdkColor selector_color;
     GdkColor event_marker_color;
     GdkColor today_marker_color;
+    GdkColor birthday_marker_color;
 	gint selector_alpha;
 	gint today_marker_alpha;
 
@@ -156,39 +287,26 @@ GtkWidget* gui_calendar_new                 (void);
 gboolean   gui_calendar_select_month        (GuiCalendar *calendar, guint month, guint year);
 void       gui_calendar_select_day          (GuiCalendar *calendar, guint day);
 
-gboolean   gui_calendar_mark_day            (GuiCalendar *calendar, guint day);
-gboolean   gui_calendar_tc_mark_day         (GuiCalendar *calendar, guint day);
-gboolean   gui_calendar_mark_day_color      (GuiCalendar *calendar, guint day, gchar *color_str);
-gboolean   gui_calendar_unmark_day          (GuiCalendar *calendar, guint day);
-gboolean   gui_calendar_tc_unmark_day       (GuiCalendar *calendar, guint day);
-void       gui_calendar_clear_marks         (GuiCalendar *calendar);
-void       gui_calendar_tc_clear_marks      (GuiCalendar *calendar);
-
+gboolean   gui_calendar_mark_day            (GuiCalendar *calendar, guint day, gint mark_type);
+gboolean   gui_calendar_unmark_day          (GuiCalendar *calendar, guint day, gint mark_type);
+void       gui_calendar_clear_marks         (GuiCalendar *calendar, gint mark_type);
+gboolean   gui_calendar_set_day_color       (GuiCalendar *calendar, guint day, gchar *color_str);
 
 void       gui_calendar_set_display_options (GuiCalendar *calendar, GuiCalendarDisplayOptions flags);
-GuiCalendarDisplayOptions       gui_calendar_get_display_options (GuiCalendar *calendar);
+GuiCalendarDisplayOptions
+		   gui_calendar_get_display_options (GuiCalendar *calendar);
 
 void       gui_calendar_get_date            (GuiCalendar *calendar, guint *year, guint *month, guint *day);
 void       gui_calendar_get_gdate           (GuiCalendar *calendar, GDate *cdate);
 
-void       gui_calendar_set_header_color    (GuiCalendar *calendar, const char *color);
-void       gui_calendar_set_weekend_color   (GuiCalendar *calendar, const char *color);
-void       gui_calendar_set_selector_color  (GuiCalendar *calendar, const char *color);
-void       gui_calendar_set_selector_alpha  (GuiCalendar *calendar, gint alpha_value);
-void       gui_calendar_set_event_marker_color (GuiCalendar *calendar, const gchar *color);
-void       gui_calendar_set_today_marker_color (GuiCalendar *calendar, const gchar *color);
-void       gui_calendar_set_today_marker_alpha (GuiCalendar *calendar, gint alpha_value);
+void       gui_calendar_set_marker                  (GuiCalendar *calendar, gint marker_type, gint marker);
+void       gui_calendar_set_day_note_marker_symbol  (GuiCalendar *calendar, gchar *symbol);
+void       gui_calendar_set_color                   (GuiCalendar *calendar, const gchar *color, 
+											         gint alpha_value, gint color_type);
 
 void       gui_calendar_enable_cursor              (GuiCalendar *calendar, gboolean state);
 void       gui_calendar_set_cursor_type            (GuiCalendar *calendar, gint cursor_type);
 void       gui_calendar_set_frame_cursor_thickness (GuiCalendar *calendar, gint thickness);
-void       gui_calendar_set_day_note_marker_type   (GuiCalendar *calendar, const gchar symbol);
-void       gui_calendar_set_event_marker_type      (GuiCalendar *calendar, gint marker_type);
-void       gui_calendar_set_today_marker_type      (GuiCalendar *calendar, gint marker_type);
-
-guint      weeks_in_year                    (guint year);
-guint      week_number                      (guint year, guint mm, guint dd);
-guint      day_of_week                      (guint year, guint mm, guint dd);
 
 G_END_DECLS
 
