@@ -136,9 +136,6 @@ tsk_done_cb (NotifyNotification *n, const char *action, GUI *appGUI)
 			}
 
 			tsk_status_icon_set_normal (appGUI);
-			notify_notification_close (a->notify, NULL);
-			appGUI->tsk->notifications = g_slist_remove (appGUI->tsk->notifications, a);
-			g_free (a);
 
 			break;
 		}
@@ -184,7 +181,7 @@ void
 tsk_show_task_cb (NotifyNotification *n, const char *action, GUI *appGUI)
 {
 	GtkTreeIter iter;
-	GSList *tnode;
+	GSList *node;
 	GtkTreePath *sort_path, *filter_path, *path;
 	GtkTreeModel *model;
 	TASK_NTF *a;
@@ -208,8 +205,8 @@ tsk_show_task_cb (NotifyNotification *n, const char *action, GUI *appGUI)
 	gtk_combo_box_set_active (GTK_COMBO_BOX (appGUI->tsk->cf_combobox), 0);
 
 	/* select task on list */
-	for (tnode = appGUI->tsk->notifications; tnode != NULL; tnode = tnode->next) {
-		a = (TASK_NTF *) tnode->data;
+	for (node = appGUI->tsk->notifications; node != NULL; node = node->next) {
+		a = (TASK_NTF *) node->data;
 
 		if (a->notify == n) {
 			tasks_selection_activate (FALSE, appGUI);
@@ -262,10 +259,11 @@ tsk_show_task_cb (NotifyNotification *n, const char *action, GUI *appGUI)
 
 			if (t->postpone_time > 0) {
 				notify_notification_add_action (a->notify, "postpone", _("Remind me later"),
-				                                (NotifyActionCallback) tsk_postpone_notify_cb, appGUI, NULL);
+												(NotifyActionCallback) tsk_postpone_notify_cb, appGUI, NULL);
 			}
 			notify_notification_add_action (a->notify, "done", _("Done"), (NotifyActionCallback) tsk_done_cb, appGUI, NULL);
-		    notify_notification_show (a->notify, NULL);
+			notify_notification_show (a->notify, NULL);
+
 			tsk_item_free (t);
 			break;
 		}
@@ -329,9 +327,11 @@ show_postponed_notification (GUI *appGUI)
 				sound_flag = FALSE;
 			}
 
-			tsk_item_free (t);
+			if (t->ndialog_enable == TRUE) {
+				notify_notification_show (a->notify, NULL);
+			}
 
-			notify_notification_show (a->notify, NULL);
+			tsk_item_free (t);
 		}
 	}
 }
@@ -343,7 +343,7 @@ show_postponed_notification (GUI *appGUI)
 /*------------------------------------------------------------------------------*/
 
 gboolean
-tsk_show_warning_notification (TASK_ITEM *item, GtkTreeIter *iter, GUI *appGUI)
+tsk_show_warning_notification (TASK_ITEM *item, GUI *appGUI)
 {
 guint32 current_date, warning_date;
 gint current_time, warning_time;
@@ -376,20 +376,12 @@ gint current_time, warning_time;
 /*------------------------------------------------------------------------------*/
 
 gboolean
-tsk_show_task_notification (TASK_ITEM *item, GtkTreeIter *iter, GUI *appGUI)
+tsk_show_task_notification (TASK_ITEM *item, GUI *appGUI)
 {
 	if (item->due_date_julian == 0 || tsk_check_notification_id (item->id, NOTIFY_ALARM, appGUI))
 		return FALSE;
 
 	if (utl_date_time_in_the_past_js (item->due_date_julian, item->due_time)) {
-
-		if (item->repeat == TRUE && item->offline_ignore == TRUE) {
-			if (utl_date_time_compare_js (item->due_date_julian, item->due_time, appGUI->run_date, appGUI->run_time) < 0) {
-				tasks_repeat_done (iter, item, appGUI);
-				return FALSE;
-			}
-		}
-
 		return TRUE;
 	}
 
@@ -399,203 +391,302 @@ tsk_show_task_notification (TASK_ITEM *item, GtkTreeIter *iter, GUI *appGUI)
 /*------------------------------------------------------------------------------*/
 
 gboolean
-notify_tasks (GUI *appGUI)
-{
-/*guint32 current_date;*/
-/*gint current_time;*/
+tsk_delete_ntask_notification(TASK_ITEM *item) {
+    if(item->done) {
+        return TRUE;
+    } else if(!utl_date_time_in_the_past_js(item->due_date_julian, item->due_time)) {
+        return TRUE;
+    }
+    return FALSE;
+}
 
-GtkTreeIter iter;
-TASK_ITEM *item;
-gint i;
-gboolean sound_flag = TRUE;
+/*------------------------------------------------------------------------------*/
 
+void
+notify_task(TASK_ITEM *item, GUI *appGUI) {
 #ifdef HAVE_LIBNOTIFY
-	TASK_NTF *a;
-	gchar *datestr, *text, *textdesc;
-
-	show_postponed_notification (appGUI);
+    TASK_NTF *a;
+    gchar *datestr, *text, *textdesc;
 #endif /* HAVE_LIBNOTIFY */
+    gboolean sound_flag = TRUE;
 
-/*	current_date = utl_date_get_current_julian ();*/
-/*	current_time = utl_time_get_current_seconds ();*/
+    if (!appGUI->tsk->notifications_enable) {
+        return;
+    }
 
-	i = 0;
+    if (item == NULL) {
+        return;
+    }
 
-	while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), &iter, NULL, i++)) {
+    if (tsk_delete_ntask_notification(item)) {
+        notify_task_delete(item->id, appGUI);
+    } else if (item->active == TRUE && item->done == FALSE) {
 
-		item = tsk_get_item (&iter, appGUI);
-		if (item != NULL) {
+        if (tsk_show_task_notification(item, appGUI) == TRUE) {
 
-			if (item->active == TRUE && item->done == FALSE) {
-
-				if (tsk_show_task_notification (item, &iter, appGUI) == TRUE) {
-
-					if (item->alarm_command != NULL) {
-						if (strlen (item->alarm_command)) {
-							gui_save_data_and_run_command (item->alarm_command, appGUI);
-						}
-					}
+            if (item->alarm_command != NULL) {
+                if (strlen(item->alarm_command)) {
+                    gui_save_data_and_run_command(item->alarm_command, appGUI);
+                }
+            }
 
 #ifdef HAVE_LIBNOTIFY
 
-					datestr = utl_date_time_print_default (item->due_date_julian, item->due_time, FALSE);
-					text = g_strdup_printf ("<i>%s</i>", datestr);
-					g_free (datestr);
+            datestr = utl_date_time_print_default(item->due_date_julian, item->due_time, FALSE);
+            text = g_strdup_printf("<i>%s</i>", datestr);
+            g_free(datestr);
 
-					textdesc = NULL;
-					if (item->desc != NULL && strlen (item->desc))
-						textdesc = g_strdup_printf ("%s\n%.100s", text, item->desc);
+            textdesc = NULL;
+            if (item->desc != NULL && strlen(item->desc))
+                textdesc = g_strdup_printf("%s\n%.100s", text, item->desc);
 
-					a = g_malloc (sizeof (TASK_NTF));
+            a = g_malloc(sizeof (TASK_NTF));
 
-					a->id = item->id;
-					a->type = NOTIFY_ALARM;
-					a->time = -1;
-					a->date = 0;
+            a->id = item->id;
+            a->type = NOTIFY_ALARM;
+            a->time = -1;
+            a->date = 0;
 
-					if (textdesc != NULL)
+            if (textdesc != NULL)
 #ifdef HAVE_LIBNOTIFY7
-						a->notify = notify_notification_new (item->summary, textdesc, GTK_STOCK_DIALOG_WARNING);
+                a->notify = notify_notification_new(item->summary, textdesc, GTK_STOCK_DIALOG_WARNING);
 #else
-						a->notify = notify_notification_new (item->summary, textdesc, GTK_STOCK_DIALOG_WARNING, NULL);
+                a->notify = notify_notification_new(item->summary, textdesc, GTK_STOCK_DIALOG_WARNING, NULL);
 #endif /* HAVE_LIBNOTIFY7 */
-					else
+            else
 #ifdef HAVE_LIBNOTIFY7
-						a->notify = notify_notification_new (item->summary, text, GTK_STOCK_DIALOG_WARNING);
+                a->notify = notify_notification_new(item->summary, text, GTK_STOCK_DIALOG_WARNING);
 #else
-						a->notify = notify_notification_new (item->summary, text, GTK_STOCK_DIALOG_WARNING, NULL);
+                a->notify = notify_notification_new(item->summary, text, GTK_STOCK_DIALOG_WARNING, NULL);
 #endif /* HAVE_LIBNOTIFY7 */
 
-					g_free (textdesc);
-					g_free (text);
+            g_free(textdesc);
+            g_free(text);
 
-					notify_notification_set_timeout (a->notify, NOTIFY_EXPIRES_NEVER);
-					switch (tsk_get_priority_index (item->priority)) {
-						case LOW_PRIORITY: notify_notification_set_urgency (a->notify, NOTIFY_URGENCY_LOW); break;
-						case MEDIUM_PRIORITY: notify_notification_set_urgency (a->notify, NOTIFY_URGENCY_NORMAL); break;
-						case HIGH_PRIORITY: notify_notification_set_urgency (a->notify, NOTIFY_URGENCY_CRITICAL); break;
-					}
+            notify_notification_set_timeout(a->notify, NOTIFY_EXPIRES_NEVER);
+            switch (tsk_get_priority_index(item->priority)) {
+                case LOW_PRIORITY: notify_notification_set_urgency(a->notify, NOTIFY_URGENCY_LOW);
+                    break;
+                case MEDIUM_PRIORITY: notify_notification_set_urgency(a->notify, NOTIFY_URGENCY_NORMAL);
+                    break;
+                case HIGH_PRIORITY: notify_notification_set_urgency(a->notify, NOTIFY_URGENCY_CRITICAL);
+                    break;
+            }
 
-					if (item->postpone_time > 0) {
-						notify_notification_add_action (a->notify, "postpone", _("Remind me later"),
-						                                (NotifyActionCallback) tsk_postpone_notify_cb, appGUI, NULL);
-					}
+            if (item->postpone_time > 0) {
+                notify_notification_add_action(a->notify, "postpone", _("Remind me later"),
+                        (NotifyActionCallback) tsk_postpone_notify_cb, appGUI, NULL);
+            }
 
-					if (tsk_get_category_state (item->category, STATE_TASKS, appGUI) == TRUE) {
-						notify_notification_add_action (a->notify, "show_task", _("Show task"),
-						                                (NotifyActionCallback) tsk_show_task_cb, appGUI, NULL);
-					}
+            if (tsk_get_category_state(item->category, STATE_TASKS, appGUI) == TRUE) {
+                notify_notification_add_action(a->notify, "show_task", _("Show task"),
+                        (NotifyActionCallback) tsk_show_task_cb, appGUI, NULL);
+            }
 
-					notify_notification_add_action (a->notify, "done", _("Done"),
-					                                (NotifyActionCallback) tsk_done_cb, appGUI, NULL);
+            notify_notification_add_action(a->notify, "done", _("Done"),
+                    (NotifyActionCallback) tsk_done_cb, appGUI, NULL);
 #endif /* HAVE_LIBNOTIFY */
 
-					if (gtk_status_icon_get_visible (appGUI->osmo_trayicon)) {
+            if (gtk_status_icon_get_visible(appGUI->osmo_trayicon)) {
 #ifdef HAVE_LIBNOTIFY 
 #ifndef HAVE_LIBNOTIFY7
-						notify_notification_attach_to_status_icon (a->notify, appGUI->osmo_trayicon);
+                notify_notification_attach_to_status_icon(a->notify, appGUI->osmo_trayicon);
 #endif /* HAVE_LIBNOTIFY7 */
 #endif /* HAVE_LIBNOTIFY */
-				        gtk_status_icon_set_from_stock (appGUI->osmo_trayicon, OSMO_STOCK_SYSTRAY_TASK);
+                gtk_status_icon_set_from_stock(appGUI->osmo_trayicon, OSMO_STOCK_SYSTRAY_TASK);
 
-						if (config.blink_on_events) {
-							gtk_status_icon_set_blinking (appGUI->osmo_trayicon, TRUE);
-						}
-					}
+                if (config.blink_on_events) {
+                    gtk_status_icon_set_blinking(appGUI->osmo_trayicon, TRUE);
+                }
+            }
 
-                    if (strlen (config.global_notification_command)) {
-                        gui_save_data_and_run_command (config.global_notification_command, appGUI);
-                    }
+            if (strlen(config.global_notification_command)) {
+                gui_save_data_and_run_command(config.global_notification_command, appGUI);
+            }
 
-					if (item->sound_enable && sound_flag) {
-						utl_play_alarm_sound (config.sound_alarm_repeat);
-						sound_flag = FALSE;
-					}
+            if (item->sound_enable && sound_flag) {
+                utl_play_alarm_sound(config.sound_alarm_repeat);
+                sound_flag = FALSE;
+            }
 
 #ifdef HAVE_LIBNOTIFY
-					/* Delete alarm warning */
-					tsk_delete_notify (item->id, appGUI);
+            /* Delete alarm warning */
+            notify_task_delete(item->id, appGUI);
 
-					if (!notify_notification_show (a->notify, NULL)) {
-						g_warning ("Failed to send notification");
-						return FALSE;
-					}
+			if (item->ndialog_enable == TRUE) {
+				if (!notify_notification_show(a->notify, NULL)) {
+					g_warning("Failed to send notification");
+					return;
+				}
+			}
 
-					appGUI->tsk->notifications = g_slist_prepend (appGUI->tsk->notifications, a);
+            appGUI->tsk->notifications = g_slist_prepend(appGUI->tsk->notifications, a);
 #endif /* HAVE_LIBNOTIFY */
 
-				} else if (tsk_show_warning_notification (item, &iter, appGUI)) {
+        } else if (tsk_show_warning_notification(item, appGUI)) {
 
 #ifdef HAVE_LIBNOTIFY
-					datestr = utl_date_time_print_default (item->due_date_julian, item->due_time, FALSE);
-					text = g_strdup_printf ("<b>%s</b>\n<i>%s</i>", item->summary, datestr);
-					g_free (datestr);
+            datestr = utl_date_time_print_default(item->due_date_julian, item->due_time, FALSE);
+            text = g_strdup_printf("<b>%s</b>\n<i>%s</i>", item->summary, datestr);
+            g_free(datestr);
 
-					textdesc = NULL;
-					if (item->desc != NULL && strlen (item->desc))
-						textdesc = g_strdup_printf ("%s\n%.100s", text, item->desc);
+            textdesc = NULL;
+            if (item->desc != NULL && strlen(item->desc))
+                textdesc = g_strdup_printf("%s\n%.100s", text, item->desc);
 
-					a = g_malloc (sizeof (TASK_NTF));
+            a = g_malloc(sizeof (TASK_NTF));
 
-					a->id = item->id;
-					a->type = NOTIFY_WARNING;
-					a->time = -1;
-					a->date = 0;
-					if (textdesc != NULL)
+            a->id = item->id;
+            a->type = NOTIFY_WARNING;
+            a->time = -1;
+            a->date = 0;
+            if (textdesc != NULL)
 #ifdef HAVE_LIBNOTIFY7
-						a->notify = notify_notification_new (_("Alarm warning!"), textdesc, GTK_STOCK_DIALOG_INFO);
+                a->notify = notify_notification_new(_("Alarm warning!"), textdesc, GTK_STOCK_DIALOG_INFO);
 #else
-						a->notify = notify_notification_new (_("Alarm warning!"), textdesc, GTK_STOCK_DIALOG_INFO, NULL);
+                a->notify = notify_notification_new(_("Alarm warning!"), textdesc, GTK_STOCK_DIALOG_INFO, NULL);
 #endif /* HAVE_LIBNOTIFY7 */
-					else
+            else
 #ifdef HAVE_LIBNOTIFY7
-						a->notify = notify_notification_new (_("Alarm warning!"), text, GTK_STOCK_DIALOG_INFO);
+                a->notify = notify_notification_new(_("Alarm warning!"), text, GTK_STOCK_DIALOG_INFO);
 #else
-						a->notify = notify_notification_new (_("Alarm warning!"), text, GTK_STOCK_DIALOG_INFO, NULL);
+                a->notify = notify_notification_new(_("Alarm warning!"), text, GTK_STOCK_DIALOG_INFO, NULL);
 #endif /* HAVE_LIBNOTIFY7 */
 
-					notify_notification_set_timeout (a->notify, NOTIFY_EXPIRES_NEVER);
-					notify_notification_set_urgency (a->notify, NOTIFY_URGENCY_NORMAL);
-					if (tsk_get_category_state (item->category, STATE_TASKS, appGUI) == TRUE)
-						notify_notification_add_action (a->notify, "show_task", _("Show task"),
-						                                (NotifyActionCallback)tsk_show_task_cb, appGUI, NULL);
+            notify_notification_set_timeout(a->notify, NOTIFY_EXPIRES_NEVER);
+            notify_notification_set_urgency(a->notify, NOTIFY_URGENCY_NORMAL);
+            if (tsk_get_category_state(item->category, STATE_TASKS, appGUI) == TRUE)
+                notify_notification_add_action(a->notify, "show_task", _("Show task"),
+                    (NotifyActionCallback) tsk_show_task_cb, appGUI, NULL);
 
 #endif /* HAVE_LIBNOTIFY */
 
-					if (gtk_status_icon_get_visible (appGUI->osmo_trayicon)) {
+            if (gtk_status_icon_get_visible(appGUI->osmo_trayicon)) {
 #ifdef HAVE_LIBNOTIFY
 #ifndef HAVE_LIBNOTIFY7
-						notify_notification_attach_to_status_icon (a->notify, appGUI->osmo_trayicon);
+                notify_notification_attach_to_status_icon(a->notify, appGUI->osmo_trayicon);
 #endif /* HAVE_LIBNOTIFY7 */
 #endif /* HAVE_LIBNOTIFY */
-				        gtk_status_icon_set_from_stock (appGUI->osmo_trayicon, OSMO_STOCK_SYSTRAY_TASK);
+                gtk_status_icon_set_from_stock(appGUI->osmo_trayicon, OSMO_STOCK_SYSTRAY_TASK);
 
-						if (config.blink_on_events) {
-							gtk_status_icon_set_blinking (appGUI->osmo_trayicon, TRUE);
-						}
-					}
+                if (config.blink_on_events) {
+                    gtk_status_icon_set_blinking(appGUI->osmo_trayicon, TRUE);
+                }
+            }
 
-					if (item->sound_enable && sound_flag) {
-						utl_play_alarm_sound (config.sound_alarm_repeat);
-						sound_flag = FALSE;
-					}
+            if (item->sound_enable && sound_flag) {
+                utl_play_alarm_sound(config.sound_alarm_repeat);
+                sound_flag = FALSE;
+            }
 
 #ifdef HAVE_LIBNOTIFY
-					if (!notify_notification_show (a->notify, NULL)) {
-						g_warning ("Failed to send notification");
-						return FALSE;
-					}
-
-					appGUI->tsk->notifications = g_slist_prepend (appGUI->tsk->notifications, a);
-#endif /* HAVE_LIBNOTIFY */
+			if (item->ndialog_enable == TRUE) {
+				if (!notify_notification_show(a->notify, NULL)) {
+					g_warning("Failed to send notification");
+					return;
 				}
-
 			}
-			tsk_item_free (item);
+
+            appGUI->tsk->notifications = g_slist_prepend(appGUI->tsk->notifications, a);
+#endif /* HAVE_LIBNOTIFY */
+        }
+    }
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+notify_tasks(GUI *appGUI) {
+    GtkTreeIter iter;
+    TASK_ITEM *item;
+    gint i, due_time;
+	guint32 julian_day;
+	gchar *priority;
+	gboolean done;
+
+    if (appGUI->tsk->notifications_enable == FALSE) {
+        return;
+    }
+
+#ifdef HAVE_LIBNOTIFY
+    show_postponed_notification(appGUI);
+#endif /* HAVE_LIBNOTIFY */
+
+    i = 0;
+
+    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, NULL, i++)) {
+        item = tsk_get_item(&iter, appGUI);
+        notify_task(item, appGUI);
+
+		if (item->ndialog_enable == FALSE) {
+			gtk_tree_model_get (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), &iter,
+								TA_COLUMN_DONE, &done,
+								TA_COLUMN_DUE_DATE_JULIAN, &julian_day,
+								TA_COLUMN_DUE_TIME, &due_time,
+								TA_COLUMN_PRIORITY, &priority, -1);
+
+			if (tsk_get_priority_index (priority) == HIGH_PRIORITY && config.tasks_high_in_bold == TRUE) /* high priority ? */
+			{
+				gtk_list_store_set (appGUI->tsk->tasks_list_store, &iter,
+									TA_COLUMN_DUE_DATE, get_date_time_full_str (julian_day, due_time),
+									TA_COLUMN_COLOR, get_date_color (julian_day, due_time, done, appGUI),
+									TA_COLUMN_BOLD, PANGO_WEIGHT_BOLD,-1);
+			}
+			else
+			{
+				gtk_list_store_set (appGUI->tsk->tasks_list_store, &iter,
+									TA_COLUMN_DUE_DATE, get_date_time_full_str (julian_day, due_time),
+									TA_COLUMN_COLOR, get_date_color (julian_day, due_time, done, appGUI),
+									TA_COLUMN_BOLD, PANGO_WEIGHT_NORMAL,-1);
+			}
+
+			g_free (priority);
+		}
+
+		tsk_item_free(item);
+    }
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+ignore_offline_tasks(GUI *appGUI) {
+    GtkTreeIter iter;
+    TASK_ITEM *item;
+    gint i;
+
+    i = 0;
+
+    while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, NULL, i++)) {
+        item = tsk_get_item(&iter, appGUI);
+        if (item->repeat == TRUE && item->offline_ignore == TRUE) {
+            if (utl_date_time_compare_js(item->due_date_julian, item->due_time, appGUI->run_date, appGUI->run_time) < 0) {
+                tasks_repeat_done(&iter, item, appGUI);
+            }
+        }
+        tsk_item_free(item);
+    }
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+notify_task_delete (guint id, GUI *appGUI)
+{
+#ifdef HAVE_LIBNOTIFY
+	GSList *node;
+	TASK_NTF *a;
+
+	for (node = appGUI->tsk->notifications; node != NULL; node = node->next) {
+		a = (TASK_NTF *) node->data;
+		if (a->id == id) {
+			notify_notification_close (a->notify, NULL);
+			appGUI->tsk->notifications = g_slist_remove (appGUI->tsk->notifications, a);
+			g_free (a);
+			break;
 		}
 	}
-
-	return TRUE;
+#endif /* HAVE_LIBNOTIFY */
 }
 
 #endif  /* TASKS_ENABLED */
@@ -606,41 +697,44 @@ gboolean
 time_handler (GUI *appGUI)
 {
 static gint minute = -1;
+static guint32 last_refresh_date = 0;
 gint current_minute;
+guint32 current_date;
 
 	if (config.di_show_current_time_seconds == TRUE) {
 		update_clock (appGUI);
 	}
 
     current_minute = get_current_minute ();
+    current_date = utl_date_get_current_julian ();
 
 	if (minute != current_minute) {
 
 #ifdef TASKS_ENABLED
+		/* TODO: would it be simplier to ignore all offline tasks at the program start? */
+		ignore_offline_tasks(appGUI);
 		notify_tasks (appGUI);
 #endif  /* TASKS_ENABLED */
 
 		minute = current_minute;
 
-		if (minute == 0) 
-			if (get_current_hour () == 0) {
-#ifdef TASKS_ENABLED
-				refresh_tasks (appGUI);
-#endif  /* TASKS_ENABLED */
-
-				/* update systray status */
-				gui_systray_update_icon (appGUI);
-
-				/* set calendar cursor */
-				calendar_set_today (appGUI);
-			}
-
 		if (config.di_show_current_time_seconds == FALSE) {
 			update_clock (appGUI);
 		}
 		gui_systray_tooltip_update (appGUI);
 	}
 
+	if (current_date != last_refresh_date) {
+#ifdef TASKS_ENABLED
+		refresh_tasks (appGUI);
+#endif  /* TASKS_ENABLED */
+
+		/* update systray status */
+		gui_systray_update_icon (appGUI);
+
+		last_refresh_date = current_date;
+	}
+
 	return TRUE;
 }
 
@@ -1186,11 +1280,7 @@ gchar               *first_name, *last_name;
     g_signal_connect(show_osmo_button, "clicked", G_CALLBACK(button_event_checker_show_osmo_window_cb), appGUI);
     gtk_container_add(GTK_CONTAINER(hbuttonbox), show_osmo_button);
 
-    if (config.default_stock_icons) {
-        close_button = gtk_button_new_from_stock (GTK_STOCK_CLOSE);
-    } else {
-        close_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_CLOSE);
-    }
+    close_button = utl_gui_create_labeled_button (GTK_STOCK_CLOSE, OSMO_STOCK_BUTTON_CLOSE, _("Close"));
     gtk_widget_show (close_button);
     GTK_WIDGET_UNSET_FLAGS(close_button, GTK_CAN_FOCUS);
     g_signal_connect(close_button, "clicked", G_CALLBACK(button_event_checker_window_close_cb), appGUI);
