@@ -28,9 +28,18 @@
 #include "calendar_utils.h"
 #include "stock_icons.h"
 #include "options_prefs.h"
+#include "vcf.h"
 
 #ifdef CONTACTS_ENABLED
 
+/*-------------------------------------------------------------------------------------*/
+gboolean
+is_export_column(gint column) {
+    if(config.export_fields[column] == '+') {
+        return TRUE;
+    }
+    return FALSE;
+}
 /*-------------------------------------------------------------------------------------*/
 
 void
@@ -43,7 +52,7 @@ const gchar *text;
         k = 0;
 
         for(i=0; i < CONTACTS_NUM_COLUMNS; i++) {
-            if(config.export_fields[i] == '+') k++;
+            if(is_export_column(i)) k++;
         }
 
         text = gtk_entry_get_text (GTK_ENTRY(appGUI->cnt->output_file_entry));
@@ -114,20 +123,454 @@ button_export_window_close_cb (GtkWidget *widget, gpointer data) {
     export_window_close_cb (widget, NULL, appGUI);
 
 }
+/*------------------------------------------------------------------------------*/
+
+struct contact_export_strategy {
+    void (*begin_file)(FILE * filehandle, GUI * appGUI);
+    void (*begin_contact)(gint number, FILE * filehandle, GUI * appGUI);
+    void (*handle_contact_value)(gint column, gchar const * value, FILE * filehandle, GtkTreeIter *iter, GUI * appGUI);
+    void (*end_contact)(gint number, FILE * filehandle, GUI * appGUI);
+    void (*end_file)(FILE * filehandle, GUI * appGUI);
+};
 
 /*------------------------------------------------------------------------------*/
 
+void
+xhtml_begin_file(FILE * filehandle, GUI * appGUI) {
+    gchar tmpbuf[BUFFER_SIZE];
+    gint i, a, b;
+    fprintf(filehandle, "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\n");
+    fprintf(filehandle, "<html xmlns=\"http://www.w3.org/1999/xhtml\">\n");
+    fprintf(filehandle, "<head>\n");
+    fprintf(filehandle, "\t<title>Contact List</title>\n");
+    fprintf(filehandle, "\t<meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\" />\n");
+    fprintf(filehandle, "\t<meta name=\"generator\" content=\"OSMO - http://clay.ll.pl/osmo\" />\n");
+    fprintf(filehandle, "\t<style type=\"text/css\">\n");
+    fprintf(filehandle, "\t\tbody { color:black; background-color:white; }\n");
+    fprintf(filehandle, "\t\ta { color:#0000ff; }\n");
+    fprintf(filehandle, "\t\ta:visited { color:#000055; }\n");
+    fprintf(filehandle, "\t\ttable { border-collapse:collapse; }\n");
+    fprintf(filehandle, "\t\ttr.header { background-color:#c0c0c0; }\n");
+    fprintf(filehandle, "\t\ttr.evenrow { background-color:#f0f0f0; }\n");
+    fprintf(filehandle, "\t\ttr.oddrow { background-color:#fafafa; }\n");
+    fprintf(filehandle, "\t\tth, td { border:1px solid #555555; padding:3px; }\n");
+    fprintf(filehandle, "\t</style>\n");
+    fprintf(filehandle, "</head>\n\n");
+    fprintf(filehandle, "<body>\n\n");
+    fprintf(filehandle, "<h1>Contact List</h1>\n\n");
+
+    fprintf(filehandle, "<table>\n");
+
+    fprintf(filehandle, "<tr class=\"header\">\n");
+
+    for (i = 0; i < CONTACTS_NUM_COLUMNS; i++) {
+        if (is_export_column(i)) {
+            fprintf(filehandle, "\t<th>");
+
+            if (appGUI->cnt->contact_fields_tags_name[i * 2] != NULL) {
+                for (a = b = 0; a < strlen(appGUI->cnt->contact_fields_tags_name[i * 2]); a++) {
+                    if (appGUI->cnt->contact_fields_tags_name[i * 2][a] == ' ') {
+                        tmpbuf[b] = '\0';
+                        strcat(tmpbuf, "&nbsp;");
+                        b += 6;
+                    } else {
+                        tmpbuf[b++] = appGUI->cnt->contact_fields_tags_name[i * 2][a];
+                    }
+                }
+                tmpbuf[b] = '\0';
+                fprintf(filehandle, "%s", tmpbuf);
+            }
+
+            fprintf(filehandle, "</th>\n");
+        }
+    }
+
+    fprintf(filehandle, "</tr>\n\n");
+}
+
+void
+xhtml_begin_contact(gint number, FILE * filehandle, GUI * appGUI) {
+    if (number & 1) {
+        fprintf(filehandle, "<tr class=\"evenrow\">\n");
+    } else {
+        fprintf(filehandle, "<tr class=\"oddrow\">\n");
+    }
+}
+
+void
+xhtml_end_contact(gint number, FILE * filehandle, GUI * appGUI) {
+    fprintf(filehandle, "</tr>\n\n");
+}
+
+void
+xhtml_handle_contact_value(gint column, gchar const * value, FILE * filehandle, GtkTreeIter *iter, GUI * appGUI) {
+    gint a, b;
+    gchar tmpbuf[BUFFER_SIZE];
+    
+    fprintf(filehandle, "\t<td>");
+
+    if (value != NULL) {
+
+        for (a = b = 0; a < strlen(value); a++) {
+            if (value[a] == ' ') {
+                tmpbuf[b] = '\0';
+                strcat(tmpbuf, "&nbsp;");
+                b += 6;
+            } else {
+                tmpbuf[b++] = value[a];
+            }
+        }
+        tmpbuf[b] = '\0';
+
+        switch (column) {
+            case COLUMN_EMAIL_1:
+            case COLUMN_EMAIL_2:
+            case COLUMN_EMAIL_3:
+            case COLUMN_EMAIL_4:
+                fprintf(filehandle, "<a href=\"mailto:%s\">%s</a>", tmpbuf, tmpbuf);
+                break;
+            case COLUMN_WWW_1:
+            case COLUMN_WWW_2:
+            case COLUMN_WWW_3:
+            case COLUMN_WWW_4:
+            case COLUMN_BLOG:
+                fprintf(filehandle, "<a href=\"%s\">%s</a>", tmpbuf, tmpbuf);
+                break;
+            default:
+                fprintf(filehandle, "%s", tmpbuf);
+        }
+     }
+
+    fprintf(filehandle, "</td>\n");
+}
+
+void xhtml_end_file(FILE * filehandle, GUI * appGUI) {
+    fprintf(filehandle, "</table>\n");
+    fprintf(filehandle, "</body>\n");
+    fprintf(filehandle, "</html>\n");
+}
+
+/*------------------------------------------------------------------------------*/
+
+void csv_begin_file(FILE * filehandle, GUI * appGUI) {
+}
+
+void
+csv_no_header_begin_contact(gint number, FILE * filehandle, GUI * appGUI) {
+}
+
+static gboolean csv_add_coma;
+
+void
+csv_header_begin_contact(gint number, FILE * filehandle, GUI * appGUI) {
+    if (number == 0) {
+        gint i;
+        gboolean add_coma = FALSE;
+
+        for (i = 0; i < CONTACTS_NUM_COLUMNS; i++) {
+            if (is_export_column(i)) {
+                if (add_coma) {
+                    fprintf(filehandle, ",");
+                }
+                add_coma = TRUE;
+                fprintf(filehandle, "%s", appGUI->cnt->contact_fields_tags_name[i * 2]);
+            }
+        }
+        fprintf(filehandle, "\r\n");
+    }
+    csv_add_coma = FALSE;
+}
+void
+csv_end_contact(gint number, FILE * filehandle, GUI * appGUI) {
+    fprintf(filehandle, "\r\n");
+}
+
+void
+csv_handle_contact_value(gint column, gchar const * value, FILE * filehandle, GtkTreeIter *iter, GUI * appGUI) {
+    if (csv_add_coma) {
+        fprintf(filehandle, ",");
+    }
+    csv_add_coma = TRUE;
+    if (value != NULL) {
+        gint i;
+        gboolean must_quote, leading_space, trailing_space;
+        gsize len;
+        len = strlen(value);
+        leading_space = TRUE;
+        trailing_space = FALSE;
+        for (i = 0, must_quote = FALSE; i < len; i++) {
+            if (value[i] == '"' || value[i] == ',' || value[i] == '\n') {
+                must_quote = TRUE;
+                break;
+            } else if (value[i] == ' ' || value[i] == '\t') {
+                trailing_space = TRUE;
+            } else {
+                trailing_space = FALSE;
+                if (i == 0) {
+                    leading_space = FALSE;
+                } else if (leading_space) {
+                    must_quote = TRUE;
+                    break;
+                }
+            }
+        }
+        if (!must_quote) {
+            /* do not trim whitespaces, RFC 4180 */
+            must_quote = (leading_space || trailing_space) ? TRUE : FALSE;
+        }
+
+        if (must_quote) {
+            gchar *buffer = g_new(gchar, len * 2 + 1);
+            gint j;
+            for (i = 0, j = 0; i < len; i++) {
+                if (value[i] == '"') {
+                    buffer[j++] = '"';
+                } else if (value[i] == '\n') {
+                    buffer[j++] = '\r';
+                }
+                buffer[j++] = value[i];
+            }
+            buffer[j] = '\0';
+            fprintf(filehandle, "\"%s\"", buffer);
+            g_free(buffer);
+        } else {
+            fprintf(filehandle, "%s", value);
+        }
+    }
+}
+
+void csv_end_file(FILE * filehandle, GUI * appGUI) {
+    
+}
+
+/*------------------------------------------------------------------------------*/
+static vcf_writer *vcf;
+
+void
+vcf_write_cb(gchar const *buffer, gsize buffer_size, void *user_data) {
+    FILE *filehandle = user_data;
+    
+    fwrite(buffer, sizeof(gchar), buffer_size, filehandle);
+}
+
+void
+vcf_begin_file(FILE *filehandle, GUI *appGUI) {
+    vcf = vcf_create_writer(vcf_write_cb, filehandle);
+}
+
+static gboolean vcf_write_required_properties;
+static gboolean vcf_write_home_address;
+static gboolean vcf_write_work_address;
+static gboolean vcf_write_org;
+
+void
+vcf_begin_contact(gint number, FILE * filehandle, GUI * appGUI) {
+    vcf_write_begin(vcf);
+    vcf_write_required_properties = TRUE;
+    vcf_write_home_address = TRUE;
+    vcf_write_work_address = TRUE;
+    vcf_write_org = TRUE;
+}
+
+void static
+write_address(gchar const* type, gint address_column, gint city_column, gint state_column, gint post_code_column, gint country_column,
+        GtkTreeIter *iter, GUI * appGUI) {
+    gchar *address, *city, *state, *post_code, *country;
+    gtk_tree_model_get(GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), iter,
+            address_column, &address,
+            city_column, &city,
+            state_column, &state,
+            post_code_column, &post_code,
+            country_column, &country,
+            -1);
+    vcf_write_ADR(vcf, type,
+            is_export_column(address_column)? address : NULL,
+            is_export_column(city_column) ? city : NULL,
+            is_export_column(state_column) ? state : NULL,
+            is_export_column(post_code_column) ? post_code : NULL,
+            is_export_column(country_column) ? country : NULL
+            );
+
+    g_free(address);
+    g_free(city);
+    g_free(state);
+    g_free(post_code);
+    g_free(country);
+}
+
+void
+vcf_handle_contact_value(gint column, gchar const * value, FILE * filehandle, GtkTreeIter *iter, GUI * appGUI) {
+    if (vcf_write_required_properties == TRUE) {
+        gchar *first_name, *last_name, *second_name;
+        gtk_tree_model_get(GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), iter,
+                COLUMN_FIRST_NAME, &first_name,
+                COLUMN_LAST_NAME, &last_name,
+                COLUMN_SECOND_NAME, &second_name,
+                -1);
+        vcf_write_FN(vcf, first_name, last_name);
+        vcf_write_N(vcf, last_name, first_name, second_name);
+        vcf_write_required_properties = FALSE;
+        g_free(first_name);
+        g_free(last_name);
+        g_free(second_name);
+        vcf_write_required_properties = FALSE;
+    }
+    if (value) {
+        switch (column) {
+            case COLUMN_NICK_NAME:
+                vcf_write_NICKNAME(vcf, value);
+                break;
+            case COLUMN_BIRTH_DAY_DATE:
+            {
+                guint32 julian_day;
+                gtk_tree_model_get(GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), iter,
+                        COLUMN_BIRTH_DAY_DATE, &julian_day,
+                        -1);
+                vcf_write_BDAY(vcf, julian_day);
+                break;
+            }
+            case COLUMN_HOME_ADDRESS:
+            case COLUMN_HOME_CITY:
+            case COLUMN_HOME_STATE:
+            case COLUMN_HOME_POST_CODE:
+            case COLUMN_HOME_COUNTRY:
+                if (vcf_write_home_address) {
+                    write_address(VCF_TYPE_HOME, COLUMN_HOME_ADDRESS, COLUMN_HOME_CITY, COLUMN_HOME_STATE, COLUMN_HOME_POST_CODE, COLUMN_HOME_COUNTRY, iter, appGUI);
+                    vcf_write_home_address = FALSE;
+                }
+                break;
+            case COLUMN_WORK_ADDRESS:
+            case COLUMN_WORK_CITY:
+            case COLUMN_WORK_STATE:
+            case COLUMN_WORK_POST_CODE:
+            case COLUMN_WORK_COUNTRY:
+                if (vcf_write_work_address) {
+                    write_address(VCF_TYPE_WORK, COLUMN_WORK_ADDRESS, COLUMN_WORK_CITY, COLUMN_WORK_STATE, COLUMN_WORK_POST_CODE, COLUMN_WORK_COUNTRY, iter, appGUI);
+                    vcf_write_work_address = FALSE;
+                }
+                break;
+            case COLUMN_WORK_ORGANIZATION:
+            case COLUMN_WORK_DEPARTMENT:
+                if (vcf_write_org) {
+                    gchar *organization, *department;
+                    gtk_tree_model_get(GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), iter,
+                            COLUMN_WORK_ORGANIZATION, &organization,
+                            COLUMN_WORK_DEPARTMENT, &department,
+                            -1);
+                    vcf_write_ORG(vcf,
+                            is_export_column(COLUMN_WORK_ORGANIZATION) ? organization : NULL,
+                            is_export_column(COLUMN_WORK_DEPARTMENT) ? department : NULL);
+
+                    g_free(organization);
+                    g_free(department);
+                    vcf_write_org = FALSE;
+                }
+                break;
+            case COLUMN_WORK_FAX:
+                vcf_write_TEL(vcf, value, 1, VCF_TYPE_TEL_FAX, VCF_TYPE_WORK);
+                break;
+            case COLUMN_WORK_PHONE_1:
+            case COLUMN_WORK_PHONE_2:
+            case COLUMN_WORK_PHONE_3:
+            case COLUMN_WORK_PHONE_4:
+            {
+                gint pref = column - COLUMN_WORK_PHONE_1 + 1;
+                vcf_write_TEL(vcf, value, pref, VCF_TYPE_TEL_VOICE, VCF_TYPE_WORK);
+                break;
+            }
+            case COLUMN_HOME_PHONE_1:
+            case COLUMN_HOME_PHONE_2:
+            case COLUMN_HOME_PHONE_3:
+            case COLUMN_HOME_PHONE_4:
+            {
+                gint pref = column - COLUMN_HOME_PHONE_1 + 1;
+                vcf_write_TEL(vcf, value, pref, VCF_TYPE_TEL_VOICE, VCF_TYPE_HOME);
+                break;
+            }
+            case COLUMN_CELL_PHONE_1:
+            case COLUMN_CELL_PHONE_2:
+            case COLUMN_CELL_PHONE_3:
+            case COLUMN_CELL_PHONE_4:
+            {
+                gint pref = column - COLUMN_CELL_PHONE_1 + 1;
+                vcf_write_TEL(vcf, value, pref, VCF_TYPE_TEL_CELL);
+                break;
+            }
+            case COLUMN_EMAIL_1:
+            case COLUMN_EMAIL_2:
+            case COLUMN_EMAIL_3:
+            case COLUMN_EMAIL_4:
+            {
+                gint pref = column - COLUMN_EMAIL_1 + 1;
+                vcf_write_EMAIL(vcf, value, pref);
+                break;
+            }
+            case COLUMN_WWW_1:
+            case COLUMN_WWW_2:
+            case COLUMN_WWW_3:
+            case COLUMN_WWW_4:
+            {
+                gint pref = column - COLUMN_WWW_1 + 1;
+                vcf_write_URL_pref(vcf, value, pref);
+                break;
+            }
+            case COLUMN_IM_AOL:
+                vcf_write_IMPP(vcf, value, "aol");
+                break;
+            case COLUMN_IM_GG:
+                vcf_write_IMPP(vcf, value, "gg");
+                break;
+            case COLUMN_IM_ICQ:
+                vcf_write_IMPP(vcf, value, "icq");
+                break;
+            case COLUMN_IM_JABBER:
+                vcf_write_IMPP(vcf, value, "xmpp");
+                break;
+            case COLUMN_IM_MSN:
+                vcf_write_IMPP(vcf, value, "msn");
+                break;
+            case COLUMN_IM_SKYPE:
+                vcf_write_IMPP(vcf, value, "skype");
+                break;
+            case COLUMN_IM_TLEN:
+                vcf_write_IMPP(vcf, value, "tlen");
+                break;
+            case COLUMN_IM_YAHOO:
+                vcf_write_IMPP(vcf, value, "ymsgr");
+                break;
+            case COLUMN_BLOG:
+                vcf_write_URL(vcf, value);
+                break;
+            case COLUMN_INFO:
+                vcf_write_NOTE(vcf, value);
+                break;
+            default:
+                break;
+        }
+    }
+}
+
+void
+vcf_end_contact(gint number, FILE * filehandle, GUI * appGUI) {
+    vcf_write_end(vcf);
+}
+
+void
+vcf_end_file(FILE * filehandle, GUI * appGUI) {
+    vcf_close_writer(vcf);
+    vcf = NULL;
+}
+/*------------------------------------------------------------------------------*/
+
 gint
-export_contacts_to_file(gchar *filename, gboolean header, GUI *appGUI) {
+export_contacts_to_file_with_strategy(gchar *filename, struct contact_export_strategy strategy, GUI *appGUI) {
 
 GtkTreePath *sort_path, *filter_path, *path;
-gint i, j, a, b, c, e, n, m, max_field, exported;
+gint i, exported;
 gchar *text;
 GtkTreeIter iter;
 FILE *filehandle;
 guint32 date;
-gchar tmpbuf[BUFFER_SIZE];
-gchar tmp_buffer_1[BUFFER_SIZE], tmp_buffer_2[BUFFER_SIZE];
 
     exported = 0;
 
@@ -135,67 +578,11 @@ gchar tmp_buffer_1[BUFFER_SIZE], tmp_buffer_2[BUFFER_SIZE];
         return -1;
     }
 
-    for(max_field = CONTACTS_NUM_COLUMNS-1; max_field >= 0; --max_field) {
-        if(config.export_fields[max_field] == '+') break;
-    }
-    if (max_field == -1) {
-        max_field = CONTACTS_NUM_COLUMNS-1;
-    }
 
     filehandle = g_fopen (filename, "w");
     if(filehandle) {
+        strategy.begin_file(filehandle, appGUI);
 
-        if (config.export_format == EXPORT_TO_XHTML) {
-            fprintf(filehandle, "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\n");
-            fprintf(filehandle, "<html xmlns=\"http://www.w3.org/1999/xhtml\">\n");
-            fprintf(filehandle, "<head>\n");
-            fprintf(filehandle, "\t<title>Contact List</title>\n");
-            fprintf(filehandle, "\t<meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\" />\n");
-            fprintf(filehandle, "\t<meta name=\"generator\" content=\"OSMO - http://clay.ll.pl/osmo\" />\n");
-            fprintf(filehandle, "\t<style type=\"text/css\">\n");
-            fprintf(filehandle, "\t\tbody { color:black; background-color:white; }\n");
-            fprintf(filehandle, "\t\ta { color:#0000ff; }\n");
-            fprintf(filehandle, "\t\ta:visited { color:#000055; }\n");
-            fprintf(filehandle, "\t\ttable { border-collapse:collapse; }\n");
-            fprintf(filehandle, "\t\ttr.header { background-color:#c0c0c0; }\n");
-            fprintf(filehandle, "\t\ttr.evenrow { background-color:#f0f0f0; }\n");
-            fprintf(filehandle, "\t\ttr.oddrow { background-color:#fafafa; }\n");
-            fprintf(filehandle, "\t\tth, td { border:1px solid #555555; padding:3px; }\n");
-            fprintf(filehandle, "\t</style>\n");
-            fprintf(filehandle, "</head>\n\n");
-            fprintf(filehandle, "<body>\n\n");
-            fprintf(filehandle, "<h1>Contact List</h1>\n\n");
-
-            fprintf(filehandle, "<table>\n");
-
-            fprintf(filehandle, "<tr class=\"header\">\n");
-
-            for(i=0; i < CONTACTS_NUM_COLUMNS; i++) {
-                if(config.export_fields[i] == '+') {
-                    fprintf(filehandle, "\t<th>");
-
-                    if (appGUI->cnt->contact_fields_tags_name[i*2] != NULL) {
-                        for(a=b=0; a < strlen(appGUI->cnt->contact_fields_tags_name[i*2]); a++) {
-                            if(appGUI->cnt->contact_fields_tags_name[i*2][a] == ' ') {
-                                tmpbuf[b] = '\0';
-                                strcat(tmpbuf, "&nbsp;");
-                                b += 6;
-                            } else {
-                                tmpbuf[b++] = appGUI->cnt->contact_fields_tags_name[i*2][a];
-                            }
-                        }
-                        tmpbuf[b] = '\0';
-                        fprintf(filehandle, "%s", tmpbuf);
-                    }
-
-                    fprintf(filehandle, "</th>\n");
-                }
-            }
-
-            fprintf(filehandle, "</tr>\n\n");
-        }
-
-        j = 0;
         sort_path = gtk_tree_path_new_first ();
 
         while (gtk_tree_model_get_iter (GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, sort_path) == TRUE) {
@@ -211,35 +598,12 @@ gchar tmp_buffer_1[BUFFER_SIZE], tmp_buffer_2[BUFFER_SIZE];
                     if (path != NULL) {
 
                         gtk_tree_model_get_iter (GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, path);
-
-                        if (config.export_format == EXPORT_TO_XHTML) {
-                            if(j & 1) {
-                                fprintf(filehandle, "<tr class=\"evenrow\">\n");
-                            } else {
-                                fprintf(filehandle, "<tr class=\"oddrow\">\n");
-                            }
-                        } else if (config.export_format == EXPORT_TO_CSV && header == TRUE && j == 0) {
-
-                            for(i=n=0; i < CONTACTS_NUM_COLUMNS; i++) {
-                                if (i != COLUMN_PHOTO && i != COLUMN_ID && config.export_fields[i] == '+') {
-                                    n++;
-                                }
-                            }
-                            for(i=m=0; i < CONTACTS_NUM_COLUMNS; i++) {
-                                if (i != COLUMN_PHOTO && i != COLUMN_ID && config.export_fields[i] == '+') {
-                                    fprintf(filehandle, "%s", appGUI->cnt->contact_fields_tags_name[i*2]);
-                                    if (m != n-1) {
-                                        fprintf(filehandle, ",");
-                                    }
-                                    m++;
-                                }
-                            }
-                            fprintf(filehandle, "\n");
-                        }
+                        
+                        strategy.begin_contact(exported, filehandle, appGUI);
 
                         for(i=0; i < CONTACTS_NUM_COLUMNS; i++) {
 
-                            if(config.export_fields[i] == '+') {
+                            if(is_export_column(i)) {
 
                                 if (i == COLUMN_BIRTH_DAY_DATE || i == COLUMN_NAME_DAY_DATE) {
                                     gtk_tree_model_get (GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, i, &date, -1);
@@ -256,129 +620,13 @@ gchar tmp_buffer_1[BUFFER_SIZE], tmp_buffer_2[BUFFER_SIZE];
                                     gtk_tree_model_get (GTK_TREE_MODEL(appGUI->cnt->contacts_list_store), &iter, i, &text, -1);
                                 }
 
-                                if (config.export_format == EXPORT_TO_XHTML) {
-                                    fprintf(filehandle, "\t<td>");
-
-                                    if (text != NULL) {
-
-                                        for(a=b=0; a < strlen(text); a++) {
-                                            if(text[a] == ' ') {
-                                                tmpbuf[b] = '\0';
-                                                strcat(tmpbuf, "&nbsp;");
-                                                b += 6;
-                                            } else {
-                                                tmpbuf[b++] = text[a];
-                                            }
-                                        }
-                                        tmpbuf[b] = '\0';
-
-                                        switch (i) {
-                                            case COLUMN_EMAIL_1:
-                                            case COLUMN_EMAIL_2:
-                                            case COLUMN_EMAIL_3:
-                                            case COLUMN_EMAIL_4:
-                                                fprintf(filehandle, "<a href=\"mailto:%s\">%s</a>", tmpbuf, tmpbuf);
-                                                break;
-                                            case COLUMN_WWW_1:
-                                            case COLUMN_WWW_2:
-                                            case COLUMN_WWW_3:
-                                            case COLUMN_WWW_4:
-                                            case COLUMN_BLOG:
-                                                fprintf(filehandle, "<a href=\"%s\">%s</a>", tmpbuf, tmpbuf);
-                                                break;
-                                            default:
-                                                fprintf(filehandle, "%s", tmpbuf);
-                                        }
-                                        g_free(text);
-                                    }
-
-                                    fprintf(filehandle, "</td>\n");
-
-                                } else {
-                                    /* CSV */
-
-                                    if (text != NULL) {
-
-                                        /* 1 */
-
-                                        for(a = b = e = 0; a < strlen(text); a++) {
-                                            if(text[a]=='"') {
-                                                b = 1;
-                                            }
-                                            if(text[a]=='\n') {
-                                                e = 1;              /* found new line */
-                                            }
-                                        }
-
-                                        c = a = 0;
-
-                                        if (b) {
-                                            tmp_buffer_1[c++] = '"';
-                                        }
-
-                                        do {
-                                            if(text[a]=='"') {
-                                                tmp_buffer_1[c++] = '"';
-                                            }
-                                            tmp_buffer_1[c++] = text[a];
-                                            a++;
-                                        } while (text[a]!='\0');
-
-                                        if(b) {
-                                            tmp_buffer_1[c++] = '"';
-                                        }
-                                        tmp_buffer_1[c] = '\0';
-
-                                        /* 2 */
-
-                                        for(a = b = 0; a < strlen(tmp_buffer_1); a++) {
-                                            if(tmp_buffer_1[a]==',') {
-                                                b = 1;
-                                            }
-                                        }
-
-                                        c = a = 0;
-
-                                        if (b) {
-                                            tmp_buffer_2[c++] = '"';
-                                        }
-
-                                        do {
-                                            tmp_buffer_2[c++] = tmp_buffer_1[a];
-                                            a++;
-                                        } while (tmp_buffer_1[a]!='\0');
-
-                                        if (b) {
-                                            tmp_buffer_2[c++] = '"';
-                                        }
-                                        tmp_buffer_2[c] = '\0';
-
-                                        if (e) {
-                                            fprintf(filehandle, "\"%s\"", tmp_buffer_2);
-                                        } else {
-                                            fprintf(filehandle, "%s", tmp_buffer_2);
-                                        }
-
-                                        g_free(text);
-                                    }
-
-                                    if (i != max_field) {
-                                        fprintf(filehandle, ",");
-                                    }
-
-                                }
-
+                                strategy.handle_contact_value(i, text, filehandle, &iter, appGUI);
+                                g_free(text);
                             }
                         }
+                        
+                        strategy.end_contact(exported, filehandle, appGUI);
 
-                        if (config.export_format == EXPORT_TO_XHTML) {
-                            fprintf(filehandle, "</tr>\n\n");
-                        } else {
-                            /* CSV */
-                            fprintf(filehandle, "\n");
-                        }
-
-                        j++;
                         exported++;
                         gtk_tree_path_free(path);
 
@@ -392,22 +640,43 @@ gchar tmp_buffer_1[BUFFER_SIZE], tmp_buffer_2[BUFFER_SIZE];
             gtk_tree_path_next (sort_path);
         }
 
-        if (config.export_format == EXPORT_TO_XHTML) {
-            fprintf(filehandle, "</table>\n");
-
-            fprintf(filehandle, "</body>\n");
-            fprintf(filehandle, "</html>\n");
-        }
+        strategy.end_file(filehandle, appGUI);
 
         fclose(filehandle);
-
+        return exported;
     } else {
-
         utl_gui_create_dialog(GTK_MESSAGE_ERROR, _("Cannot create file."), GTK_WINDOW(appGUI->cnt->export_window));
         return -1;
     }
+}
 
-    return exported;
+/*------------------------------------------------------------------------------*/
+
+gint
+export_contacts_to_file(gchar *filename, gboolean header, GUI *appGUI) {
+    if (config.export_format == EXPORT_TO_XHTML) {
+        struct contact_export_strategy strategy = {.begin_file=xhtml_begin_file,
+        .begin_contact=xhtml_begin_contact,
+        .handle_contact_value=xhtml_handle_contact_value,
+        .end_contact=xhtml_end_contact,
+        .end_file=xhtml_end_file};
+        return export_contacts_to_file_with_strategy(filename, strategy, appGUI);
+    } else if(config.export_format == EXPORT_TO_CSV) {
+        struct contact_export_strategy strategy = {.begin_file=csv_begin_file,
+        .begin_contact=header ? csv_header_begin_contact : csv_no_header_begin_contact,
+        .handle_contact_value=csv_handle_contact_value,
+        .end_contact=csv_end_contact,
+        .end_file=csv_end_file};
+        return export_contacts_to_file_with_strategy(filename, strategy, appGUI);
+    } else if(config.export_format == EXPORT_TO_VCF) {
+        struct contact_export_strategy strategy = {.begin_file=vcf_begin_file,
+        .begin_contact=vcf_begin_contact,
+        .handle_contact_value=vcf_handle_contact_value,
+        .end_contact=vcf_end_contact,
+        .end_file=vcf_end_file};
+        return export_contacts_to_file_with_strategy(filename, strategy, appGUI);
+    }
+    return -1;
 }
 
 /*------------------------------------------------------------------------------*/
@@ -440,11 +709,18 @@ gchar f_filename[PATH_MAX];
                     g_str_has_suffix (f_filename, ".HTML") == FALSE) {
                     g_strlcat(f_filename, ".html", PATH_MAX-1);
                 }
-            } else {
+            } else if(config.export_format == EXPORT_TO_CSV) {
                 if (g_str_has_suffix (f_filename, ".csv") == FALSE &&
                     g_str_has_suffix (f_filename, ".CSV") == FALSE) {
                     g_strlcat(f_filename, ".csv", PATH_MAX-1);
                 }
+            } else if(config.export_format == EXPORT_TO_VCF) {
+                if (g_str_has_suffix (f_filename, ".vcf") == FALSE &&
+                    g_str_has_suffix (f_filename, ".VCF") == FALSE &&
+                    g_str_has_suffix (f_filename, ".vcard") == FALSE &&
+                    g_str_has_suffix (f_filename, ".VCARD") == FALSE) {
+                    g_strlcat(f_filename, ".vcf", PATH_MAX-1);
+                }
             }
             gtk_entry_set_text (GTK_ENTRY(appGUI->cnt->output_file_entry), f_filename);
         }
@@ -493,14 +769,10 @@ gint i;
 /*------------------------------------------------------------------------------*/
 
 void
-format_changed_cb (GtkButton *button, gpointer user_data) {
-
-    GUI *appGUI = (GUI *)user_data;
-
-    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(appGUI->cnt->format_csv_radiobutton)) == TRUE) {
-        config.export_format = EXPORT_TO_CSV;
-    } else {
-        config.export_format = EXPORT_TO_XHTML;
+format_changed_cb(GtkToggleButton *button, gpointer user_data) {
+    gint format = GPOINTER_TO_INT(user_data);
+    if (button->active) {
+        config.export_format = format;
     }
 }
 
@@ -541,6 +813,23 @@ select_action_cb (GtkWidget *widget, gpointer user_data) {
 
 /*--------------------------------------------------------------------*/
 
+GSList *
+create_format_radiobutton(gchar * const label, gint format, GtkBox *parent, GSList *group) {
+    GtkWidget* radiobutton;
+    radiobutton = gtk_radio_button_new_with_mnemonic(NULL, label);
+    gtk_widget_show(radiobutton);
+    g_signal_connect(G_OBJECT(radiobutton), "toggled",
+            G_CALLBACK(format_changed_cb), GINT_TO_POINTER(format));
+    GTK_WIDGET_UNSET_FLAGS(radiobutton, GTK_CAN_FOCUS);
+    gtk_box_pack_start(GTK_BOX(parent), radiobutton, FALSE, FALSE, 0);
+    gtk_radio_button_set_group(GTK_RADIO_BUTTON(radiobutton), group);
+    if (config.export_format == format) {
+        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radiobutton), TRUE);
+    }
+    return gtk_radio_button_get_group(GTK_RADIO_BUTTON(radiobutton));
+}
+/*--------------------------------------------------------------------*/
+
 void
 contacts_create_export_window(GUI *appGUI) {
 
@@ -553,7 +842,6 @@ GtkWidget *frame;
 GtkWidget *alignment;
 GtkWidget *vbox4;
 GtkWidget *vbox5;
-GtkWidget *format_xhtml_radiobutton;
 GSList    *format_radiobutton_group = NULL;
 GtkWidget *label;
 GtkWidget *vseparator;
@@ -629,27 +917,9 @@ static MESSAGE msg_select[3]; /* select all, select none, select invert */
     gtk_container_add (GTK_CONTAINER (alignment), vbox4);
     gtk_container_set_border_width (GTK_CONTAINER (vbox4), 8);
 
-    appGUI->cnt->format_csv_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, "CSV");
-    gtk_widget_show (appGUI->cnt->format_csv_radiobutton);
-    g_signal_connect (G_OBJECT (appGUI->cnt->format_csv_radiobutton), "clicked",
-                      G_CALLBACK(format_changed_cb), appGUI);
-    GTK_WIDGET_UNSET_FLAGS(appGUI->cnt->format_csv_radiobutton, GTK_CAN_FOCUS);
-    gtk_box_pack_start (GTK_BOX (vbox4), appGUI->cnt->format_csv_radiobutton, FALSE, FALSE, 0);
-    gtk_radio_button_set_group (GTK_RADIO_BUTTON (appGUI->cnt->format_csv_radiobutton), format_radiobutton_group);
-    format_radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (appGUI->cnt->format_csv_radiobutton));
-
-    format_xhtml_radiobutton = gtk_radio_button_new_with_mnemonic (NULL, "XHTML");
-    gtk_widget_show (format_xhtml_radiobutton);
-    g_signal_connect (G_OBJECT (format_xhtml_radiobutton), "clicked",
-                      G_CALLBACK(format_changed_cb), appGUI);
-    GTK_WIDGET_UNSET_FLAGS(format_xhtml_radiobutton, GTK_CAN_FOCUS);
-    gtk_box_pack_start (GTK_BOX (vbox4), format_xhtml_radiobutton, FALSE, FALSE, 0);
-    gtk_radio_button_set_group (GTK_RADIO_BUTTON (format_xhtml_radiobutton), format_radiobutton_group);
-    format_radiobutton_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (format_xhtml_radiobutton));
-
-    if (config.export_format) {
-        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(format_xhtml_radiobutton), TRUE);
-    }
+    format_radiobutton_group = create_format_radiobutton("CSV", EXPORT_TO_CSV, GTK_BOX(vbox4), format_radiobutton_group);
+    format_radiobutton_group = create_format_radiobutton("XHTML", EXPORT_TO_XHTML, GTK_BOX(vbox4), format_radiobutton_group);
+    format_radiobutton_group = create_format_radiobutton("VCF", EXPORT_TO_VCF, GTK_BOX(vbox4), format_radiobutton_group);
 
     sprintf(tmpbuf, "<b>%s:</b>", _("Output format"));
     label = gtk_label_new (tmpbuf);
@@ -810,13 +1080,13 @@ static MESSAGE msg_select[3]; /* select all, select none, select invert */
                               (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                               (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
 
-            if(config.export_fields[i] == '+') {
+            if(is_export_column(i)) {
                 gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(appGUI->cnt->check_buttons[i]), TRUE);
             }
         }
     }
 
-	browse_dir_button = utl_gui_create_button (GTK_STOCK_OPEN, OSMO_STOCK_BUTTON_OPEN, _("Browse"));
+	browse_dir_button = utl_gui_create_labeled_button (GTK_STOCK_OPEN, OSMO_STOCK_BUTTON_OPEN, _("Browse"));
     gtk_widget_show (browse_dir_button);
     GTK_WIDGET_UNSET_FLAGS(browse_dir_button, GTK_CAN_FOCUS);
     g_signal_connect(browse_dir_button, "clicked", G_CALLBACK(browse_dir_cb), appGUI);
@@ -838,13 +1108,13 @@ static MESSAGE msg_select[3]; /* select all, select none, select invert */
     gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
     gtk_box_set_spacing (GTK_BOX (hbuttonbox), 8);
 
-	cancel_button = utl_gui_create_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
+	cancel_button = utl_gui_create_labeled_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
     gtk_widget_show (cancel_button);
     gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
     GTK_WIDGET_SET_FLAGS (cancel_button, GTK_CAN_DEFAULT);
     g_signal_connect(cancel_button, "clicked", G_CALLBACK(button_export_window_close_cb), appGUI);
 
-    appGUI->cnt->export_button = utl_gui_create_button (OSMO_STOCK_BUTTON_CONTACTS_EXPORT, OSMO_STOCK_BUTTON_CONTACTS_EXPORT, _("Export"));
+    appGUI->cnt->export_button = utl_gui_create_labeled_button (OSMO_STOCK_BUTTON_CONTACTS_EXPORT, OSMO_STOCK_BUTTON_CONTACTS_EXPORT, _("Export"));
     gtk_widget_show (appGUI->cnt->export_button);
     gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->cnt->export_button);
     GTK_WIDGET_SET_FLAGS (appGUI->cnt->export_button, GTK_CAN_DEFAULT);
