@@ -24,12 +24,10 @@
 
 #include "gui.h"
 
-#define EXPORT_WINDOW_SIZE_X    500
-#define EXPORT_WINDOW_SIZE_Y    400
-
 enum {
     EXPORT_TO_CSV = 0,
-    EXPORT_TO_XHTML
+    EXPORT_TO_XHTML,
+    EXPORT_TO_VCF
 };
 
 enum {
