@@ -279,7 +279,7 @@ gchar tmpbuf[BUFFER_SIZE];
     GTK_WIDGET_UNSET_FLAGS(appGUI->cnt->input_file_entry, GTK_CAN_FOCUS);
     gtk_editable_set_editable (GTK_EDITABLE(appGUI->cnt->input_file_entry), FALSE);
 
-	appGUI->cnt->contacts_browse_button = utl_gui_create_button (GTK_STOCK_OPEN, OSMO_STOCK_BUTTON_OPEN, _("Browse"));
+	appGUI->cnt->contacts_browse_button = utl_gui_create_labeled_button (GTK_STOCK_OPEN, OSMO_STOCK_BUTTON_OPEN, _("Browse"));
     GTK_WIDGET_UNSET_FLAGS(appGUI->cnt->contacts_browse_button, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->cnt->contacts_browse_button);
     gtk_box_pack_start (GTK_BOX (hbox4), appGUI->cnt->contacts_browse_button, FALSE, TRUE, 4);
@@ -322,13 +322,13 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
     gtk_box_set_spacing (GTK_BOX (hbuttonbox), 8);
 
-	cancel_button = utl_gui_create_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
+	cancel_button = utl_gui_create_labeled_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
     gtk_widget_show (cancel_button);
     gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
     g_signal_connect(cancel_button, "clicked", 
                      G_CALLBACK(button_import_sel_window_close_cb), appGUI);
 
-	appGUI->cnt->import_button = utl_gui_create_button (OSMO_STOCK_BUTTON_CONTACTS_IMPORT, OSMO_STOCK_BUTTON_CONTACTS_IMPORT, _("Import"));
+	appGUI->cnt->import_button = utl_gui_create_labeled_button (OSMO_STOCK_BUTTON_CONTACTS_IMPORT, OSMO_STOCK_BUTTON_CONTACTS_IMPORT, _("Import"));
     gtk_widget_show (appGUI->cnt->import_button);
     gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->cnt->import_button);
     g_signal_connect(appGUI->cnt->import_button, "clicked",
@@ -422,24 +422,9 @@ gchar *str, *field_str;
 
 void
 type_changed_cb (GtkComboBox *widget, gpointer user_data) {
-
-gint i, k, n;
-
-    MESSAGE *msg = (MESSAGE *)user_data;
-
-    n = (size_t)msg->data;
-
-    k = gtk_combo_box_get_active (GTK_COMBO_BOX(msg->appGUI->cnt->field_type_comboboxes[n]));
-    msg->appGUI->cnt->field_type[n] = k;
-
-    for(i=0; i < msg->appGUI->cnt->max_fields; i++) {
-        if (i != n) {
-            if (k == gtk_combo_box_get_active (GTK_COMBO_BOX(msg->appGUI->cnt->field_type_comboboxes[i]))) {
-                gtk_combo_box_set_active (GTK_COMBO_BOX (msg->appGUI->cnt->field_type_comboboxes[i]), 0);
-                msg->appGUI->cnt->field_type[i] = 0;
-            }
-        }
-    }
+    gint *field = (gint *)user_data;
+    gint value = gtk_combo_box_get_active (widget);
+    *field = value;
 }
 
 /*------------------------------------------------------------------------------*/
@@ -613,10 +598,11 @@ gchar tmpbuf[BUFFER_SIZE];
                 if ((field_str = csv_get_field(str, i+1)) != NULL) {
 
                     for(j=0; j < CONTACTS_NUM_COLUMNS; j++) {
-                        if (j != COLUMN_PHOTO) {
+                        if (j != COLUMN_PHOTO && j != COLUMN_ID) {
                             if (!strcmp(field_str, appGUI->cnt->contact_fields_tags_name[j*2])) {
                                 gtk_combo_box_set_active (GTK_COMBO_BOX (appGUI->cnt->field_type_comboboxes[i]), j+1);
                                 appGUI->cnt->field_type[i] = j+1;
+                                break;
                             }
                         }
                     }
@@ -656,7 +642,6 @@ GtkWidget *import_button;
 gchar *str, *field_str, *text;
 guint record, fields, n_records, i, j;
 gchar tmpbuf[BUFFER_SIZE];
-static MESSAGE msg_fields[CONTACTS_NUM_COLUMNS];
 
     if (g_access (filename, R_OK) != -1) {
 
@@ -806,11 +791,7 @@ static MESSAGE msg_fields[CONTACTS_NUM_COLUMNS];
                 gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
                 gtk_box_set_spacing (GTK_BOX (hbuttonbox), 8);
 
-                if (config.default_stock_icons) {
-                    cancel_button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
-                } else {
-                    cancel_button = gtk_button_new_from_stock (OSMO_STOCK_BUTTON_CANCEL);
-                }
+                cancel_button = utl_gui_create_labeled_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
                 gtk_widget_show (cancel_button);
                 gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
                 GTK_WIDGET_SET_FLAGS (cancel_button, GTK_CAN_DEFAULT);
@@ -869,7 +850,7 @@ static MESSAGE msg_fields[CONTACTS_NUM_COLUMNS];
                     gtk_widget_show (appGUI->cnt->field_type_comboboxes[i]);
                     gtk_table_attach (GTK_TABLE (fields_table), appGUI->cnt->field_type_comboboxes[i], 1, 2, i, i+1,
                                       (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-                                      (GtkAttachOptions) (GTK_FILL), 0, 0);
+                                      (GtkAttachOptions) (0), 0, 0);
                     gtk_container_set_border_width (GTK_CONTAINER (appGUI->cnt->field_type_comboboxes[i]), 4);
                     sprintf(tmpbuf, "[%s]", _("None"));
                     gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->cnt->field_type_comboboxes[i]), tmpbuf);
@@ -883,10 +864,8 @@ static MESSAGE msg_fields[CONTACTS_NUM_COLUMNS];
                     appGUI->cnt->field_type[i] = 0;
                     gtk_combo_box_set_wrap_width (GTK_COMBO_BOX (appGUI->cnt->field_type_comboboxes[i]), 4);
 
-                    msg_fields[i].data = (gpointer)((size_t)i);
-                    msg_fields[i].appGUI = appGUI;
                     g_signal_connect (G_OBJECT (appGUI->cnt->field_type_comboboxes[i]), "changed", 
-                                      G_CALLBACK(type_changed_cb), &msg_fields[i]);
+                                      G_CALLBACK(type_changed_cb), &(appGUI->cnt->field_type[i]));
 
                     if (str != NULL) {
                         if ((field_str = csv_get_field(str, i+1)) != NULL) {
