@@ -220,12 +220,6 @@ create_miscellaneous_section (GtkWidget *miscellaneous_vbox, GUI *appGUI)
 	GtkWidget *label;
 	GtkWidget *combobox;
 
-	checkbutton = gtk_check_button_new_with_mnemonic (_("Select and show first item after search"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.show_after_search);
-	gtk_box_pack_start (GTK_BOX (miscellaneous_vbox), checkbutton, TRUE, TRUE, 4);
-	g_signal_connect (G_OBJECT (checkbutton), "toggled", G_CALLBACK (checkbutton_clicked_cb), &(config.show_after_search));
-	appGUI->opt->contacts_select_first_entry_checkbutton = checkbutton;
-
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Hide group column"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.hide_group_column);
 	gtk_box_pack_start (GTK_BOX (miscellaneous_vbox), checkbutton, TRUE, TRUE, 4);
@@ -389,21 +383,13 @@ create_groups_section (GtkWidget *groups_vbox, GUI *appGUI)
 	column = gtk_tree_view_column_new_with_attributes (NULL, renderer, "text", 0, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 
-	if (config.default_stock_icons) {
-		appGUI->opt->contacts_group_add_button = utl_gui_stock_button (GTK_STOCK_ADD, FALSE);
-	} else {
-		appGUI->opt->contacts_group_add_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_ADD, FALSE);
-	}
+	appGUI->opt->contacts_group_add_button = utl_gui_create_button (GTK_STOCK_ADD, OSMO_STOCK_BUTTON_ADD, FALSE);
 	gtk_widget_set_sensitive (appGUI->opt->contacts_group_add_button, FALSE);
 	gtk_table_attach (GTK_TABLE (table), appGUI->opt->contacts_group_add_button, 1, 2, 3, 4,
 	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 	g_signal_connect (appGUI->opt->contacts_group_add_button, "clicked", G_CALLBACK (contacts_group_add_cb), appGUI);
 
-	if (config.default_stock_icons) {
-		appGUI->opt->contacts_group_remove_button = utl_gui_stock_button (GTK_STOCK_REMOVE, FALSE);
-	} else {
-		appGUI->opt->contacts_group_remove_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_REMOVE, FALSE);
-	}
+	appGUI->opt->contacts_group_remove_button = utl_gui_create_button (GTK_STOCK_REMOVE, OSMO_STOCK_BUTTON_REMOVE, FALSE);
 	gtk_widget_set_sensitive (appGUI->opt->contacts_group_remove_button, FALSE);
 	gtk_table_attach (GTK_TABLE (table), appGUI->opt->contacts_group_remove_button, 2, 3, 3, 4,
 	                  (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
@@ -412,94 +398,6 @@ create_groups_section (GtkWidget *groups_vbox, GUI *appGUI)
 
 /* ========================================================================== */
 
-static void
-contacts_sort_mode_changed_cb (GtkComboBox *widget, GUI *appGUI)
-{
-	config.contacts_sorting_mode = gtk_combo_box_get_active (widget);
-	gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable *) appGUI->cnt->contacts_sort,
-	                                      COLUMN_FIRST_NAME, config.contacts_sorting_order);
-	gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable *) appGUI->cnt->contacts_sort,
-	                                      COLUMN_LAST_NAME, config.contacts_sorting_order);
-	gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable *) appGUI->cnt->contacts_sort,
-	                                      COLUMN_GROUP, config.contacts_sorting_order);
-
-	gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER (appGUI->cnt->contacts_filter));
-}
-
-/* ========================================================================== */
-
-static void
-contacts_sort_order_changed_cb (GtkComboBox *widget, GUI *appGUI)
-{
-	config.contacts_sorting_order = gtk_combo_box_get_active (widget);
-	gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable *) appGUI->cnt->contacts_sort,
-	                                      COLUMN_FIRST_NAME, config.contacts_sorting_order);
-	gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable *) appGUI->cnt->contacts_sort,
-	                                      COLUMN_LAST_NAME, config.contacts_sorting_order);
-	gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable *) appGUI->cnt->contacts_sort,
-	                                      COLUMN_GROUP, config.contacts_sorting_order);
-
-	gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER (appGUI->cnt->contacts_filter));
-}
-
-/* ========================================================================== */
-
-static void
-create_sorting_section (GtkWidget *sorting_vbox, GUI *appGUI)
-{
-	GtkWidget *table, *label, *combobox;
-	gchar *str;
-
-	table = gtk_table_new (1, 5, FALSE);
-	gtk_box_pack_start (GTK_BOX (sorting_vbox), table, FALSE, FALSE, 0);
-	gtk_table_set_row_spacings (GTK_TABLE (table), 4);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 8);
-
-	label = utl_gui_create_label ("%s:", _("Order"));
-	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
-
-	label = utl_gui_create_label ("%s:", _("Mode"));
-	gtk_table_attach (GTK_TABLE (table), label, 2, 3, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
-
-	combobox = gtk_combo_box_new_text ();
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("Ascending"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), _("Descending"));
-	gtk_combo_box_set_active (GTK_COMBO_BOX (combobox), config.contacts_sorting_order);
-	gtk_table_attach (GTK_TABLE (table), combobox, 1, 2, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
-	g_signal_connect (G_OBJECT (combobox), "changed", G_CALLBACK (contacts_sort_order_changed_cb), appGUI);
-	appGUI->opt->contacts_sort_order_combobox = combobox;
-
-	combobox = gtk_combo_box_new_text ();
-	str = g_strdup_printf ("%s, %s, %s", _("Group"), _("First Name"), _("Last Name"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), str);
-	g_free (str);
-	str = g_strdup_printf ("%s, %s, %s", _("Group"), _("Last Name"), _("First Name"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), str);
-	g_free (str);
-	str = g_strdup_printf ("%s, %s, %s", _("Last Name"), _("First Name"), _("Group"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), str);
-	g_free (str);
-	str = g_strdup_printf ("%s, %s, %s", _("Last Name"), _("Group"), _("First Name"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), str);
-	g_free (str);
-	str = g_strdup_printf ("%s, %s, %s", _("First Name"), _("Last Name"), _("Group"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), str);
-	g_free (str);
-	str = g_strdup_printf ("%s, %s, %s", _("First Name"), _("Group"), _("Last Name"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combobox), str);
-	g_free (str);
-	gtk_combo_box_set_active (GTK_COMBO_BOX (combobox), config.contacts_sorting_mode);
-	gtk_table_attach (GTK_TABLE (table), combobox, 3, 4, 0, 1,
-	                  (GtkAttachOptions) (GTK_FILL | GTK_EXPAND), (GtkAttachOptions) (0), 0, 0);
-	g_signal_connect (G_OBJECT (combobox), "changed", G_CALLBACK (contacts_sort_mode_changed_cb), appGUI);
-	appGUI->opt->contacts_sort_mode_combobox = combobox;
-}
-
-/* ========================================================================== */
-
 static void
 create_visible_columns_section (GtkWidget *visible_columns_vbox, GUI *appGUI)
 {
@@ -554,9 +452,6 @@ cnt_create_preferences_page (GtkWidget *notebook, GUI *appGUI)
 	vbox = utl_gui_create_vbox_in_frame (vbox_top, _("Groups"));
 	create_groups_section (vbox, appGUI);
 
-	vbox = utl_gui_create_vbox_in_frame (vbox_top, _("Sorting"));
-	create_sorting_section (vbox, appGUI);
-
 	vbox = utl_gui_create_vbox_in_frame (vbox_top, _("Visible columns in birthday browser"));
 	create_visible_columns_section (vbox, appGUI);
 
