@@ -172,16 +172,10 @@ gui_quit_osmo (GUI *appGUI) {
 
 #ifdef CONTACTS_ENABLED
         config.find_mode = gtk_combo_box_get_active (GTK_COMBO_BOX(appGUI->cnt->contacts_find_combobox));
-		if (config.gui_layout) {
-            config.contacts_pane_pos = gtk_paned_get_position(GTK_PANED(appGUI->cnt->contacts_paned));
-		}
 #endif  /* CONTACTS_ENABLED */
 
 #ifdef TASKS_ENABLED
         config.current_category_in_tasks = gtk_combo_box_get_active (GTK_COMBO_BOX(appGUI->tsk->cf_combobox));
-		if (config.gui_layout) {
-	        config.tasks_pane_pos = gtk_paned_get_position(GTK_PANED(appGUI->tsk->tasks_paned));
-		}
 #endif  /* TASKS_ENABLED */
 
 #ifdef NOTES_ENABLED
@@ -617,34 +611,27 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, GUI *appGUI)
 
                 case GDK_Escape:
                     if(gtk_widget_is_focus(appGUI->tsk->tasks_find_entry) == FALSE) {
-						if(appGUI->tsk->tasks_panel_status == TRUE) {
-							show_tasks_desc_panel(FALSE, appGUI);
-						} else {
-							if (config.enable_systray == TRUE && appGUI->no_tray == FALSE && appGUI->calendar_only == FALSE) {
-								gui_toggle_window_visibility (appGUI);
-							}
-						}
+                        if (config.enable_systray == TRUE && appGUI->no_tray == FALSE && appGUI->calendar_only == FALSE) {
+                            gui_toggle_window_visibility (appGUI);
+                        }
 					} else {
                         if (strlen(gtk_entry_get_text(GTK_ENTRY(appGUI->tsk->tasks_find_entry)))) {
                             gtk_entry_set_text(GTK_ENTRY(appGUI->tsk->tasks_find_entry), "");
                         } else {
-							if (config.enable_systray == TRUE && appGUI->no_tray == FALSE && appGUI->calendar_only == FALSE) {
-								gui_toggle_window_visibility (appGUI);
-							}
-						}
-					}
+                            if (config.enable_systray == TRUE && appGUI->no_tray == FALSE && appGUI->calendar_only == FALSE) {
+                                gui_toggle_window_visibility (appGUI);
+                            }
+                        }
+                    }
                     return TRUE;
                 case GDK_Return:
                     if(gtk_widget_is_focus(appGUI->tsk->tasks_find_entry) == FALSE) {
 						if (event->state & GDK_CONTROL_MASK) {  /* CTRL + Enter */
-							if (gtk_tree_selection_get_selected (appGUI->tsk->tasks_list_selection, NULL, NULL)) {
+							if (gtk_tree_selection_count_selected_rows (appGUI->tsk->tasks_list_selection) == 1) {
 								tasks_add_edit_dialog_show (TRUE, 0, utl_time_get_current_seconds (), appGUI);
 								return TRUE;
 							}
 						}
-						if(appGUI->tsk->tasks_panel_status == FALSE) {
-							show_tasks_desc_panel(TRUE, appGUI);
-						}
 						return TRUE;
 					} else {
                         gtk_widget_grab_focus(GTK_WIDGET(appGUI->tsk->tasks_list));
@@ -661,17 +648,18 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, GUI *appGUI)
 						if (event->state & GDK_CONTROL_MASK) {  /* CTRL + h */
 							config.hide_completed = !config.hide_completed;
 							gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER(appGUI->tsk->tasks_filter));
-							update_tasks_number (appGUI);
 						}
 						return TRUE;
 					}
 					return FALSE;
                 case GDK_Delete:
-                    if(gtk_widget_is_focus(appGUI->tsk->tasks_find_entry) == FALSE) {
-                        tasks_remove_dialog_show(appGUI->tsk->tasks_list, appGUI->tsk->tasks_list_store, appGUI);
-	                    return TRUE;
-					}
-	                return FALSE;
+                    if (gtk_widget_is_focus(appGUI->tsk->tasks_find_entry) == FALSE) {
+                        if (gtk_tree_selection_count_selected_rows(appGUI->tsk->tasks_list_selection) > 0) {
+                            tasks_remove_dialog_show(appGUI);
+                            return TRUE;
+                        }
+                    }
+                    return FALSE;
                 case GDK_Insert:
                     if(gtk_widget_is_focus(appGUI->tsk->tasks_find_entry) == FALSE) {
                         tasks_add_edit_dialog_show (FALSE, 0, utl_time_get_current_seconds (), appGUI);
@@ -722,34 +710,28 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, GUI *appGUI)
 
                 case GDK_Escape:
                     if (gtk_widget_is_focus(appGUI->cnt->contacts_find_entry) == FALSE) {
-                        if(appGUI->cnt->contacts_panel_status == TRUE) {
-                            show_contacts_desc_panel(FALSE, appGUI);
-                        } else {
-							if (config.enable_systray == TRUE && appGUI->no_tray == FALSE && appGUI->calendar_only == FALSE) {
-								gui_toggle_window_visibility (appGUI);
-							}
-						}
+                        if (config.enable_systray == TRUE && appGUI->no_tray == FALSE && appGUI->calendar_only == FALSE) {
+                            gui_toggle_window_visibility (appGUI);
+                        }
                     } else {
                         if (strlen(gtk_entry_get_text(GTK_ENTRY(appGUI->cnt->contacts_find_entry)))) {
                             gtk_entry_set_text(GTK_ENTRY(appGUI->cnt->contacts_find_entry), "");
                         } else {
-							if (config.enable_systray == TRUE && appGUI->no_tray == FALSE && appGUI->calendar_only == FALSE) {
-								gui_toggle_window_visibility (appGUI);
-							}
-						}
+                            if (config.enable_systray == TRUE && appGUI->no_tray == FALSE && appGUI->calendar_only == FALSE) {
+                                    gui_toggle_window_visibility (appGUI);
+                            }
+                        }
                     }
                     return TRUE;
                 case GDK_Return:
                     if(gtk_widget_is_focus(appGUI->cnt->contacts_find_entry) == FALSE) {
 						if (event->state & GDK_CONTROL_MASK) {  /* CTRL + Enter */
-							if (gtk_tree_selection_get_selected (appGUI->cnt->contacts_list_selection, NULL, NULL)) {
+							if (gtk_tree_selection_count_selected_rows (appGUI->cnt->contacts_list_selection) == 1) {
 								contacts_add_edit_dialog_show (TRUE, appGUI);
 								return TRUE;
 							}
 						}
-						if(appGUI->cnt->contacts_panel_status == FALSE) {
-							show_contacts_desc_panel(TRUE, appGUI);
-						} else if (gtk_widget_is_focus(appGUI->cnt->contacts_find_entry) == FALSE) {
+						if (gtk_widget_is_focus(appGUI->cnt->contacts_find_entry) == FALSE) {
 							utl_gui_sw_vscrollbar_move_position (appGUI->cnt->contacts_panel_scrolledwindow, SW_MOVE_DOWN);
 							return TRUE;
 						}
@@ -761,15 +743,17 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, GUI *appGUI)
                     return FALSE;
 
                 case GDK_BackSpace:
-                    if(appGUI->cnt->contacts_panel_status == TRUE && gtk_widget_is_focus(appGUI->cnt->contacts_find_entry) == FALSE) {
+                    if(gtk_widget_is_focus(appGUI->cnt->contacts_find_entry) == FALSE) {
                         utl_gui_sw_vscrollbar_move_position (appGUI->cnt->contacts_panel_scrolledwindow, SW_MOVE_UP);
                         return TRUE;
                     }
                     return FALSE;
                 case GDK_Delete:
                     if(gtk_widget_is_focus(appGUI->cnt->contacts_find_entry) == FALSE) {
-                        contacts_remove_dialog_show(appGUI->cnt->contacts_list, appGUI->cnt->contacts_list_store, appGUI);
-                        return TRUE;
+                        if (gtk_tree_selection_count_selected_rows(appGUI->cnt->contacts_list_selection) > 0) {
+                            contacts_remove_dialog_show(appGUI);
+                            return TRUE;
+                        }
                     }
                     return FALSE;
                 case GDK_Insert:
@@ -820,7 +804,7 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, GUI *appGUI)
 
                 case GDK_Return:
                     if(gtk_widget_is_focus(appGUI->nte->notes_find_entry) == FALSE) {
-						if (gtk_tree_selection_get_selected (appGUI->nte->notes_list_selection, NULL, NULL)) {
+						if (gtk_tree_selection_count_selected_rows (appGUI->nte->notes_list_selection) == 1) {
 							if (event->state & GDK_CONTROL_MASK) {  /* CTRL + Enter */
 								notes_edit_dialog_show(appGUI->nte->notes_list, appGUI->nte->notes_filter, appGUI);
 							} else {
@@ -834,10 +818,12 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, GUI *appGUI)
 						return TRUE;
 					}
                 case GDK_Delete:
-                    if(gtk_widget_is_focus(appGUI->nte->notes_find_entry) == FALSE) {
-                        notes_remove_dialog_show (appGUI->nte->notes_list, appGUI->nte->notes_list_store, appGUI);
-                        return TRUE;
-					}
+                    if (gtk_widget_is_focus(appGUI->nte->notes_find_entry) == FALSE) {
+                        if (gtk_tree_selection_count_selected_rows(appGUI->nte->notes_list_selection) > 0) {
+                            notes_remove_dialog_show(appGUI);
+                            return TRUE;
+                        }
+                    }
                     return FALSE;
                 case GDK_Insert:
                     if(gtk_widget_is_focus(appGUI->nte->notes_find_entry) == FALSE) {
@@ -959,6 +945,20 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, GUI *appGUI)
 						clear_text_attributes_cb (NULL, appGUI);
                         return TRUE;
                     }
+                    return FALSE;
+
+				case GDK_o:
+                    if ((event->state & GDK_CONTROL_MASK) && !appGUI->nte->note_read_only) {  /* CTRL + o */
+						open_url_links_cb (NULL, appGUI);
+                        return TRUE;
+                    }
+                    return FALSE;
+
+				case GDK_period:
+                    if ((event->state & GDK_CONTROL_MASK)) {  /* CTRL + . */
+						text_info_cb (NULL, appGUI);
+                        return TRUE;
+                    }
                     return FALSE;
             }
         }
@@ -1149,31 +1149,6 @@ notebook_sw_cb (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, gp
 
 /*------------------------------------------------------------------------------*/
 
-gboolean            
-main_window_resized_cb (GtkWidget *widget, GdkEventConfigure *event, gpointer user_data) {
-
-    GUI *appGUI = (GUI *)user_data;
-
-    if (appGUI->calendar_only == FALSE) {
-
-#ifdef TASKS_ENABLED
-        if (appGUI->tsk->tasks_panel_status == FALSE && !config.gui_layout) {
-            gtk_paned_set_position(GTK_PANED(appGUI->tsk->tasks_paned), 99999);
-        }
-#endif  /* TASKS_ENABLED */
-
-#ifdef CONTACTS_ENABLED
-        if (appGUI->cnt->contacts_panel_status == FALSE && !config.gui_layout) {
-            gtk_paned_set_position(GTK_PANED(appGUI->cnt->contacts_paned), 99999);
-        }
-#endif  /* CONTACTS_ENABLED */
-    }
-
-    return FALSE;
-}
-
-/*------------------------------------------------------------------------------*/
-
 #if (GTK_CHECK_VERSION(2,16,0))
 gboolean
 trayicon_clicked_cb (GtkStatusIcon *status_icon, GdkEventButton *event, gpointer user_data) {
@@ -1492,11 +1467,15 @@ gui_create_window (GUI *appGUI)
 {
 	GdkScreen *screen;
 	gint sw, sh;
+	gint fdSTDERR, fdSTDERRn;
 	GdkPixbuf *icon;
 
-#ifdef CONTACTS_ENABLED
-    appGUI->cnt->contacts_filter_disabled = TRUE;
-#endif  /* CONTACTS_ENABLED */
+	/* disable STDERR temporary - to suppress messages from webkit */
+	fdSTDERR = dup (STDERR_FILENO);
+	fdSTDERRn = open("/dev/null", O_WRONLY);
+	dup2 (fdSTDERRn, STDERR_FILENO);
+	close (fdSTDERRn);
+
     appGUI->all_pages_added = FALSE;
 
     appGUI->cal->fd_day_name_font = pango_font_description_from_string(config.day_name_font);
@@ -1538,8 +1517,6 @@ gui_create_window (GUI *appGUI)
                       G_CALLBACK(gui_window_close_cb), appGUI);
     g_signal_connect (G_OBJECT (appGUI->main_window), "key_press_event",
                       G_CALLBACK (key_press_cb), appGUI);
-    g_signal_connect (G_OBJECT (appGUI->main_window), "configure_event",
-                      G_CALLBACK (main_window_resized_cb), appGUI);
 
     osmo_register_stock_icons ();
     utl_gui_url_initialize (appGUI);
@@ -1635,12 +1612,9 @@ gui_create_window (GUI *appGUI)
 
 #ifdef TASKS_ENABLED
         refresh_tasks (appGUI);
+        appGUI->tsk->notifications_enable = TRUE;
 #endif  /* TASKS_ENABLED */
 
-#ifdef CONTACTS_ENABLED
-        appGUI->cnt->contacts_filter_disabled = FALSE;
-#endif  /* CONTACTS_ENABLED */
-
         appGUI->number_of_tabs = NUMBER_OF_TABS;
 
         if(config.remember_latest_tab == TRUE) {
@@ -1689,6 +1663,10 @@ gui_create_window (GUI *appGUI)
 
     gtk_notebook_set_current_page(GTK_NOTEBOOK(appGUI->notebook), appGUI->current_tab);
 
+	/* enable STDERR */
+	dup2 (fdSTDERR, STDERR_FILENO);
+	close (fdSTDERR);
+
     return TRUE;
 }
 
