@@ -69,6 +69,10 @@
 #define     OPAQUE                  65535
 #define     BUFFER_SIZE             2048
 
+#ifdef NOTES_ENABLED
+#define     DEFAULT_NOTE_FONT       "Sans 12"
+#endif  /* NOTES_ENABLED */
+
 enum notebook_page {
     PAGE_CALENDAR = 0,
 #ifdef TASKS_ENABLED
@@ -102,6 +106,7 @@ enum {                  /* tasks columns */
 	TA_COLUMN_ACTIVE,
 	TA_COLUMN_OFFLINE_IGNORE,
 	TA_COLUMN_SOUND_ENABLE,
+	TA_COLUMN_NDIALOG_ENABLE,
 	TA_COLUMN_REPEAT,
 	TA_COLUMN_REPEAT_DAY,
 	TA_COLUMN_REPEAT_MONTH_INTERVAL,
@@ -164,6 +169,7 @@ enum {                  /* notes columns */
     N_COLUMN_EDITOR_READONLY,
     N_COLUMN_FILENAME,
     N_COLUMN_FONTNAME,
+    N_COLUMN_ENCRYPTED,
     NOTES_NUM_COLUMNS
 };
 
@@ -379,8 +385,9 @@ typedef struct {
 	GtkWidget *print_portrait_radiobutton;
 
 #ifdef HAVE_LIBWEBKIT
-    WebKitWebView *html_webkitview;
+	WebKitWebView *html_webkitview;
 	WebKitWebSettings *webkit_settings;
+	gdouble html_scroll_position;
 #endif  /* LIBWEBKIT */
 
 } CALENDAR;
@@ -405,7 +412,6 @@ typedef struct {
     GtkTreeSelection *tasks_list_selection;
 
 	GtkWidget *scrolled_win;
-    gboolean tasks_panel_status;
     GtkListStore *tasks_list_store;
     GtkWidget *panel_hbox;
     GtkWidget *panel_scrolledwindow;
@@ -419,7 +425,6 @@ typedef struct {
     GtkTextTag *font_tag_object;
     GtkCellRenderer *done_renderer;
     gint filter_index;
-    gboolean tasks_filter_disabled;
     GtkUIManager *tasks_uim_widget;
     guint next_id;
 
@@ -461,7 +466,9 @@ typedef struct {
     GtkWidget *rt_dp_month_spinbutton;
     GtkWidget *repeat_counter_spinbutton;
     GtkWidget *checkb_sound_enable;
+    GtkWidget *checkb_ndialog_enable;
     GSList *notifications;
+    gboolean notifications_enable;
 
 #ifdef HAVE_LIBWEBKIT
     WebKitWebView *html_webkitview;
@@ -503,8 +510,6 @@ typedef struct {
     gint contacts_email_link_index;
     gint contacts_blog_link_index;
     gboolean write_flag;
-    gboolean contacts_panel_status;
-    gboolean contacts_filter_disabled;
     GtkWidget *next_field_button[CONTACTS_NUM_COLUMNS];
     GtkTreeViewColumn *contacts_columns[CONTACTS_NUM_COLUMNS];
 
@@ -535,7 +540,6 @@ typedef struct {
     /* export contacts */
     GtkWidget *export_window;
     GtkWidget *export_button;
-    GtkWidget *format_csv_radiobutton;
     GtkWidget *output_file_entry;
     GtkWidget *first_row_header_check_button;
     GtkWidget *check_buttons[CONTACTS_NUM_COLUMNS];
@@ -660,6 +664,9 @@ typedef struct {
 	WebKitWebSettings *webkit_settings;
 #endif  /* LIBWEBKIT */
 
+	/* read-only: scrollbar position */
+	gdouble htmlViewPosition;
+
 } NOTES;
 #endif  /* NOTES_ENABLED */
 
@@ -744,8 +751,6 @@ typedef struct {
     GtkTreeSelection *tasks_category_select;
     GtkWidget *tasks_category_add_button;
     GtkWidget *tasks_category_remove_button;
-    GtkWidget *tasks_sort_order_combobox;
-    GtkWidget *tasks_sort_mode_combobox;
     GtkWidget *ct_bold_items_checkbutton;
     GtkWidget *ct_delete_items_checkbutton;
     GtkWidget *ct_hide_items_checkbutton;
@@ -764,7 +769,6 @@ typedef struct {
 #ifdef CONTACTS_ENABLED
     /* contacts */
     GtkWidget *contacts_vbox;
-    GtkWidget *contacts_select_first_entry_checkbutton;
     GtkWidget *contacts_hide_group_column_checkbutton;
     GtkWidget *contacts_group_entry;
     GtkListStore *contacts_group_store;
@@ -774,8 +778,6 @@ typedef struct {
     GtkTreeSelection *contacts_group_select;
     GtkWidget *contacts_group_add_button;
     GtkWidget *contacts_group_remove_button;
-    GtkWidget *contacts_sort_order_combobox;
-    GtkWidget *contacts_sort_mode_combobox;
     GtkWidget *contacts_photo_size_combobox;
     GtkWidget *contact_tag_color_picker;
     GtkWidget *contact_link_color_picker;
@@ -796,8 +798,6 @@ typedef struct {
     GtkListStore *notes_category_store;
     GtkWidget *notes_category_treeview;
     GtkTreeSelection *notes_category_select;
-    GtkWidget *notes_sort_order_combobox;
-    GtkWidget *notes_sort_mode_combobox;
     GtkWidget *notes_category_add_button;
     GtkWidget *notes_category_remove_button;
     GtkWidget *nvc_type_checkbutton;
