@@ -91,7 +91,9 @@ gchar tmpbuf[BUFFER_SIZE];
 		appGUI->nte->editor_active = FALSE;
 
 	} else if (mode == EDITOR) {
-    
+ 
+		appGUI->nte->htmlViewPosition = 0;
+
 		gtk_widget_hide (appGUI->nte->find_hbox);
 		gtk_widget_hide (appGUI->nte->vbox_selector);
 		gtk_widget_show (appGUI->nte->vbox_editor);
@@ -163,8 +165,7 @@ GtkTextBuffer *buffer;
 guchar *text;
 guint32 current_date;
 gint current_time;
-GtkTreeIter iter;
-GtkTreeIter sort_child_iter, filter_child_iter;
+GtkTreeIter iter, filter_iter, sort_iter;
 GtkTreeModel *model;
 
 	GUI *appGUI = (GUI *)user_data;
@@ -194,21 +195,19 @@ GtkTreeModel *model;
 	appGUI->nte->changed = FALSE;
 	gtk_widget_set_sensitive (gtk_ui_manager_get_widget (appGUI->nte->notes_uim_editor_widget, "/toolbar/save"), FALSE);
 
-	if (gtk_tree_selection_get_selected (appGUI->nte->notes_list_selection, &model, &iter)) {
+        sort_iter = utl_gui_get_first_selection_iter(appGUI->nte->notes_list_selection, &model);
+        gtk_tree_model_sort_convert_iter_to_child_iter(GTK_TREE_MODEL_SORT(appGUI->nte->notes_sort), &filter_iter, &sort_iter);
+        gtk_tree_model_filter_convert_iter_to_child_iter(GTK_TREE_MODEL_FILTER(appGUI->nte->notes_filter), &iter, &filter_iter);
 
-		current_date = utl_date_get_current_julian ();
-		current_time = utl_time_get_current_seconds ();
+        current_date = utl_date_get_current_julian();
+        current_time = utl_time_get_current_seconds();
 
-		gtk_tree_model_sort_convert_iter_to_child_iter (GTK_TREE_MODEL_SORT(appGUI->nte->notes_sort), 
-														  &sort_child_iter, &iter);
-		gtk_tree_model_filter_convert_iter_to_child_iter (GTK_TREE_MODEL_FILTER(appGUI->nte->notes_filter), 
-														  &filter_child_iter, &sort_child_iter);
 
-		gtk_list_store_set (appGUI->nte->notes_list_store, &filter_child_iter, 
-						    N_COLUMN_LAST_CHANGES_DATE, get_date_time_str (current_date, current_time),
-						    N_COLUMN_LAST_CHANGES_DATE_JULIAN, current_date,
-						    N_COLUMN_LAST_CHANGES_TIME, current_time, -1);
-	}
+
+        gtk_list_store_set(appGUI->nte->notes_list_store, &iter,
+                N_COLUMN_LAST_CHANGES_DATE, get_date_time_str(current_date, current_time),
+                N_COLUMN_LAST_CHANGES_DATE_JULIAN, current_date,
+                N_COLUMN_LAST_CHANGES_TIME, current_time, -1);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -360,6 +359,57 @@ GtkTextBuffer *buffer;
 
 /*------------------------------------------------------------------------------*/
 
+void
+open_url_links_cb (GtkButton *button, gpointer user_data) {
+
+GtkTextIter start, end;
+GtkTextBuffer *buffer;
+GtkWidget *info_dialog;
+gchar *text;
+gint n, response = -1;
+gchar tmpbuf[BUFFER_SIZE];
+
+	GUI *appGUI = (GUI *)user_data;
+
+	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
+	gtk_text_buffer_get_selection_bounds (buffer, &start, &end);
+    text = gtk_text_buffer_get_text (GTK_TEXT_BUFFER (buffer), &start, &end, FALSE);
+
+	n = utl_open_count_url_links (text, TRUE);
+
+	if (n == 0) {
+
+		utl_gui_create_dialog (GTK_MESSAGE_INFO, _("No URLs found in the selection..."), 
+							   GTK_WINDOW(appGUI->main_window));
+
+	} else if (n == 1) {
+
+		utl_open_count_url_links (text, FALSE);
+
+	} else {
+		
+		g_snprintf (tmpbuf, BUFFER_SIZE, "%d %s\n\n%s", n,
+					_("URLs will be opened in the default browser."),
+					_("Do you want to continue?"));
+
+		info_dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW(appGUI->main_window), GTK_DIALOG_MODAL,
+											  GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, tmpbuf, NULL);
+
+		gtk_window_set_title(GTK_WINDOW(info_dialog), _("Question"));
+		gtk_window_set_position(GTK_WINDOW(info_dialog), GTK_WIN_POS_CENTER_ON_PARENT);
+		gtk_widget_show (info_dialog);
+
+		response = gtk_dialog_run(GTK_DIALOG(info_dialog));
+		gtk_widget_destroy(info_dialog);
+
+		if (response == GTK_RESPONSE_YES) {
+			utl_open_count_url_links (text, FALSE);
+		}
+	}
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 add_notes_toolbar_selector_widget (GtkUIManager *notes_uim_widget, GtkWidget *widget, gpointer user_data) {
 
@@ -436,7 +486,7 @@ void
 notes_delete_item_cb (GtkWidget *widget, gpointer data) {
 
     GUI *appGUI = (GUI *)data;
-    notes_remove_dialog_show(appGUI->nte->notes_list, appGUI->nte->notes_list_store, appGUI);
+    notes_remove_dialog_show(appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -556,7 +606,7 @@ get_buffer_info_string (GtkTextBuffer *buffer, gboolean selection)
 /*------------------------------------------------------------------------------*/
 
 void
-text_info_cb (GtkWidget *widget, GUI *appGUI)
+text_info_cb (GtkWidget *widget, gpointer user_data)
 {
 	GtkTreePath *path, *sort_path, *filter_path;
 	GtkTreeIter n_iter;
@@ -568,6 +618,8 @@ text_info_cb (GtkWidget *widget, GUI *appGUI)
 	gchar *txtinfo_normal, *txtinfo_selection;
 	gchar tmpbuf[BUFFER_SIZE];
 
+	GUI *appGUI = (GUI *)user_data;
+
     buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
 
 	gtk_tree_view_get_cursor (GTK_TREE_VIEW (appGUI->nte->notes_list), &sort_path, NULL);
@@ -633,7 +685,7 @@ notes_list_dbclick_cb(GtkWidget * widget, GdkEventButton * event, gpointer func_
     GUI *appGUI = (GUI *)func_data;
 
     if ((event->type==GDK_2BUTTON_PRESS) && (event->button == 1)) {
-        if (gtk_tree_selection_get_selected (appGUI->nte->notes_list_selection, NULL, NULL)) {
+        if (gtk_tree_selection_count_selected_rows (appGUI->nte->notes_list_selection) == 1) {
             notes_enter_password (appGUI);
         }
         return TRUE;
@@ -662,14 +714,13 @@ text_buffer_modified_cb (GtkTextBuffer *textbuffer, gpointer user_data) {
 
 void
 notes_item_selected (GtkTreeSelection *selection, gpointer data) {
-
+    gint selection_size;
     GUI *appGUI = (GUI *)data;
 
-    gboolean state = gtk_tree_selection_get_selected (selection, NULL, NULL);
-
-    gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_selector_widget, "/toolbar/edit"), state);
-    gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_selector_widget, "/toolbar/delete"), state);
+    selection_size = gtk_tree_selection_count_selected_rows (selection);
 
+    gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_selector_widget, "/toolbar/edit"), selection_size == 1);
+    gtk_widget_set_sensitive(gtk_ui_manager_get_widget (appGUI->nte->notes_uim_selector_widget, "/toolbar/delete"), selection_size > 0);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -863,25 +914,30 @@ refresh_notes (GUI *appGUI) {
 
 GtkTreeIter iter;
 gint i;
-guint32 current_date, create_date;
-gint current_time, create_time;
+guint32 last_changes_date, create_date;
+gint last_changes_time, create_time;
+gchar *last_changes_time_str, *create_time_str;
 
-	i = 0;
+    i = 0;
 
     while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter, NULL, i++)) {
 
-		gtk_tree_model_get (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter, 
-							N_COLUMN_LAST_CHANGES_DATE_JULIAN, &current_date, 
-							N_COLUMN_LAST_CHANGES_TIME, &current_time,
-							N_COLUMN_CREATE_DATE_JULIAN, &create_date, 
-							N_COLUMN_CREATE_TIME, &create_time, -1);
+        gtk_tree_model_get(GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter,
+                N_COLUMN_LAST_CHANGES_DATE_JULIAN, &last_changes_date,
+                N_COLUMN_LAST_CHANGES_TIME, &last_changes_time,
+                N_COLUMN_CREATE_DATE_JULIAN, &create_date,
+                N_COLUMN_CREATE_TIME, &create_time, -1);
 
-		gtk_list_store_set (appGUI->nte->notes_list_store, &iter, 
-						    N_COLUMN_LAST_CHANGES_DATE, get_date_time_str (current_date, current_time),
-						    N_COLUMN_CREATE_DATE, get_date_time_str (create_date, create_time), -1);
-	}
+        last_changes_time_str = g_strdup(get_date_time_str(last_changes_date, last_changes_time));
+        create_time_str = g_strdup(get_date_time_str(create_date, create_time));
+        gtk_list_store_set(appGUI->nte->notes_list_store, &iter,
+                N_COLUMN_LAST_CHANGES_DATE, last_changes_time_str,
+                N_COLUMN_CREATE_DATE, create_time_str, -1);
+        g_free(last_changes_time_str);
+        g_free(create_time_str);
+    }
 
-	update_notes_items (appGUI);
+    update_notes_items(appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -905,201 +961,107 @@ gboolean
 notes_list_filter_cb (GtkTreeModel *model, GtkTreeIter *iter, gpointer data) {
 
 gchar *category;
-const gchar *text;
 gchar *value;
-gint text_len, len, j;
+gboolean result;
 
     GUI *appGUI = (GUI *)data;
 
-    text = gtk_entry_get_text(GTK_ENTRY(appGUI->nte->notes_find_entry));
+    gtk_tree_model_get(model, iter, N_COLUMN_NAME, &value, N_COLUMN_CATEGORY, &category, -1);
 
-    if (text == NULL) {
-        return TRUE;
+    if (appGUI->nte->filter_index && (utl_gui_list_store_get_text_index(appGUI->opt->notes_category_store, category) != appGUI->nte->filter_index)) {
+        result = FALSE;
+    } else if (value == NULL) {
+        result = FALSE;
+    } else {
+        const gchar *text = gtk_entry_get_text(GTK_ENTRY(appGUI->nte->notes_find_entry));
+
+        if (text == NULL) {
+            result = TRUE;
+        } else
+            if (!g_utf8_strlen(text, -1)) {
+            result = TRUE;
+        } else {
+            result = utl_text_strcasestr(value, text);
+        }
     }
 
-    text_len = strlen(text);
-
-	gtk_tree_model_get(model, iter, N_COLUMN_NAME, &value, N_COLUMN_CATEGORY, &category, -1);
-
-	if(appGUI->nte->filter_index) {
-
-		if (utl_gui_list_store_get_text_index (appGUI->opt->notes_category_store, category) == appGUI->nte->filter_index) {
-
-			if (value != NULL) {
-
-				len = strlen(value) - text_len;
-
-				if (len >= 0) {
-					for(j=0; j <= len; j++) {
-						if(!g_ascii_strncasecmp(g_utf8_casefold(text, -1), g_utf8_casefold(value+j, -1), text_len)) {
-							g_free (value);
-							g_free (category);
-							return TRUE;
-						}
-					}
-				}
-
-				g_free(value);
-			}
-
-			g_free (category);
-			return FALSE;
-		} else {
-			g_free (value);
-			g_free (category);
-			return FALSE;
-		}
-
-	} else {
-		/* all items */
-
-		if (value != NULL) {
-
-			len = strlen(value) - text_len;
-
-			if (len >= 0) {
-				for(j=0; j <= len; j++) {
-					if(!g_ascii_strncasecmp(g_utf8_casefold(text, -1), g_utf8_casefold(value+j, -1), text_len)) {
-						g_free (value);
-						g_free (category);
-						return TRUE;
-					}
-				}
-			}
-
-			g_free(value);
-		}
-	}
-
-	g_free (category);
-
-    return FALSE;
+    g_free(category);
+    g_free(value);
+    return result;
 }
 
 /*------------------------------------------------------------------------------*/
 
 gint 
-custom_notes_sort_function (GtkTreeModel *model, GtkTreeIter *iter_a, GtkTreeIter *iter_b, gpointer user_data) {
-
+notes_column_sort_function (GtkTreeModel *model, GtkTreeIter *iter_a, GtkTreeIter *iter_b, gpointer user_data) {
+gboolean type_a, type_b;
 gchar *name_a, *name_b;
 gchar *category_a, *category_b;
-guint32 last_changes_date_a, last_changes_date_b;
-gint category_s, name_s;
-guint32 last_changes_date_s;
+guint32 last_changes_date_a, last_changes_date_b, create_date_a, create_date_b;
+gint last_changes_time_a, last_changes_time_b, create_time_a, create_time_b;
+gint diff;
+gint sort_column = GPOINTER_TO_INT(user_data);
 
     if(iter_a == NULL || iter_b == NULL) {
         return 0;
     }
 
-    gtk_tree_model_get (model, iter_a, N_COLUMN_NAME, &name_a,
-                        N_COLUMN_LAST_CHANGES_DATE_JULIAN, &last_changes_date_a, N_COLUMN_CATEGORY, &category_a, -1);
-    gtk_tree_model_get (model, iter_b, N_COLUMN_NAME, &name_b,
-                        N_COLUMN_LAST_CHANGES_DATE_JULIAN, &last_changes_date_b, N_COLUMN_CATEGORY, &category_b, -1);
-
-
-    if (name_a == NULL) {
-        name_s = -1;
-    } else if (name_b == NULL) {
-        name_s = 1;
-    } else if (name_a != NULL && name_b != NULL) {
-        name_s = g_utf8_collate(name_a, name_b);
-    } else {
-        name_s = 0;
-    }
-    if (name_a != NULL) {
-        g_free(name_a);
-    }
-    if (name_b != NULL) {
-        g_free(name_b);
-    }
-
-    if (category_a == NULL) {
-        category_s = -1;
-    } else if (category_b == NULL) {
-        category_s = 1;
-    } else if (category_a != NULL && category_b != NULL) {
-        category_s = g_utf8_collate(category_a, category_b);
-    } else {
-        category_s = 0;
-    }
-    if (category_a != NULL) {
-        g_free(category_a);
-    }
-    if (category_b != NULL) {
-        g_free(category_b);
-    }
-
-    if (!last_changes_date_a) last_changes_date_a = 1 << 31;
-    if (!last_changes_date_b) last_changes_date_b = 1 << 31;
-    last_changes_date_s = last_changes_date_a - last_changes_date_b;
-
-    switch(config.notes_sorting_mode) {
-
-        /* Name, Last changes, Category */
-        case 0:
-            if (name_s != 0)
-                return name_s;
-            if (last_changes_date_s != 0)
-                return last_changes_date_s;
-            if (category_s != 0)
-                return category_s;
+    switch (sort_column) {
+        case N_COLUMN_TYPE:
+            gtk_tree_model_get(model, iter_a, N_COLUMN_ENCRYPTED, &type_a, -1);
+            gtk_tree_model_get(model, iter_b, N_COLUMN_ENCRYPTED, &type_b, -1);
+            if (type_a == type_b) {
+                diff = 0;
+            } else {
+                diff = type_a == TRUE ? 1 : -1;
+            }
             break;
-
-        /* Name, Category, Last changes */
-        case 1:
-            if (name_s != 0)
-                return name_s;
-            if (category_s != 0)
-                return category_s;
-            if (last_changes_date_s != 0)
-                return last_changes_date_s;
+        case N_COLUMN_NAME:
+            gtk_tree_model_get(model, iter_a, N_COLUMN_NAME, &name_a, -1);
+            gtk_tree_model_get(model, iter_b, N_COLUMN_NAME, &name_b, -1);
+            diff = utl_text_strcmp(name_a, name_b);
+            g_free(name_a);
+            g_free(name_b);
             break;
-
-        /* Category, Last changes, Name */
-        case 2:
-            if (category_s != 0)
-                return category_s;
-            if (last_changes_date_s != 0)
-                return last_changes_date_s;
-            if (name_s != 0)
-                return name_s;
+        case N_COLUMN_CATEGORY:
+            gtk_tree_model_get(model, iter_a, N_COLUMN_CATEGORY, &category_a, -1);
+            gtk_tree_model_get(model, iter_b, N_COLUMN_CATEGORY, &category_b, -1);
+            diff = utl_text_strcmp(category_a, category_b);
+            g_free(category_a);
+            g_free(category_b);
             break;
-
-        /* Category, Name, Last changes */
-        case 3:
-            if (category_s != 0)
-                return category_s;
-            if (name_s != 0)
-                return name_s;
-            if (last_changes_date_s != 0)
-                return last_changes_date_s;
+        case N_COLUMN_LAST_CHANGES_DATE:
+            gtk_tree_model_get(model, iter_a,
+                    N_COLUMN_LAST_CHANGES_DATE_JULIAN, &last_changes_date_a,
+                    N_COLUMN_LAST_CHANGES_TIME, &last_changes_time_a, -1);
+            gtk_tree_model_get(model, iter_b,
+                    N_COLUMN_LAST_CHANGES_DATE_JULIAN, &last_changes_date_b,
+                    N_COLUMN_LAST_CHANGES_TIME, &last_changes_time_b, -1);
+            diff = utl_date_time_compare_js(last_changes_date_a, last_changes_time_a, last_changes_date_b, last_changes_time_b);
             break;
-
-        /* Last changes, Category, Name */
-        case 4:
-            if (last_changes_date_s != 0)
-                return last_changes_date_s;
-            if (category_s != 0)
-                return category_s;
-            if (name_s != 0)
-                return name_s;
+        case N_COLUMN_CREATE_DATE:
+            gtk_tree_model_get(model, iter_a,
+                    N_COLUMN_CREATE_DATE_JULIAN, &create_date_a,
+                    N_COLUMN_CREATE_TIME, &create_time_a, -1);
+            gtk_tree_model_get(model, iter_b,
+                    N_COLUMN_CREATE_DATE_JULIAN, &create_date_b,
+                    N_COLUMN_CREATE_TIME, &create_time_b, -1);
+            diff = utl_date_time_compare_js(create_date_a, create_time_a, create_date_b, create_time_b);
             break;
-
-        /* Last changes, Name, Category */
-        case 5:
-            if (last_changes_date_s != 0)
-                return last_changes_date_s;
-            if (name_s != 0)
-                return name_s;
-            if (category_s != 0)
-                return category_s;
-            break;
-
         default:
-            break;
+            diff = 0;
     }
 
-    return 0;
+    return diff;
+}
+
+/*------------------------------------------------------------------------------*/
+void notes_sort_column_changed_cb (GtkTreeSortable *sortable, gpointer user_data)
+{
+    GtkSortType sort_order;
+
+    gtk_tree_sortable_get_sort_column_id(sortable, &config.notes_sorting_column, &sort_order);
+    config.notes_sorting_order = sort_order;
 }
 
 /*------------------------------------------------------------------------------*/
@@ -1257,10 +1219,12 @@ void
 readonly_toggle_cb (GtkToggleButton *togglebutton, gpointer data) {
 
     GUI *appGUI = (GUI *)data;
+	GtkAdjustment *vadj = NULL;
 
 	gchar *btnlist[] = {
 		"/toolbar/bold", "/toolbar/italic", "/toolbar/underline", "/toolbar/strike",
-		"/toolbar/insert_date_time", "/toolbar/insert_separator", "/toolbar/clear", "/toolbar/mark_color"
+		"/toolbar/insert_date_time", "/toolbar/insert_separator", "/toolbar/clear", 
+		"/toolbar/mark_color", "/toolbar/open_links"
 	};
 
 	guint nbtns = G_N_ELEMENTS (btnlist), i;
@@ -1271,7 +1235,8 @@ readonly_toggle_cb (GtkToggleButton *togglebutton, gpointer data) {
 	gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (appGUI->nte->editor_textview), !s);
 	gtk_widget_set_sensitive (appGUI->nte->font_picker, !s);
 
-	if (s == TRUE) {
+	if (s == TRUE) {    /* read-only */
+
 		update_readonly_view (appGUI);
 
 		gtk_label_set_text(GTK_LABEL(appGUI->nte->nrow_label), "-");
@@ -1280,14 +1245,26 @@ readonly_toggle_cb (GtkToggleButton *togglebutton, gpointer data) {
 		gtk_widget_hide(appGUI->nte->editor_viewport);
 		gtk_widget_show(appGUI->nte->ro_editor_viewport);
 #endif /* HAVE_LIBWEBKIT */
+
+		while (gtk_events_pending ()) gtk_main_iteration ();    /* FIXME: update drawing of scrolled window */
+                                                                /* probably use 'size-allocate' signal later */
+
+		vadj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW(appGUI->nte->ro_editor_scrolledwindow));
+		gtk_adjustment_set_value(GTK_ADJUSTMENT(vadj), appGUI->nte->htmlViewPosition);  
+		gtk_scrolled_window_set_vadjustment (GTK_SCROLLED_WINDOW(appGUI->nte->ro_editor_scrolledwindow), GTK_ADJUSTMENT(vadj));
+	
 	} else {
+		
+		vadj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW(appGUI->nte->ro_editor_scrolledwindow));
+		appGUI->nte->htmlViewPosition = gtk_adjustment_get_value(GTK_ADJUSTMENT(vadj));
+
 #ifdef HAVE_LIBWEBKIT
 		gtk_widget_show(appGUI->nte->editor_viewport);
 		gtk_widget_hide(appGUI->nte->ro_editor_viewport);
 #endif /* HAVE_LIBWEBKIT */
+
 		editor_cursor_move_cb (gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview)),
 							   NULL, NULL, appGUI);
-	
 		gtk_widget_grab_focus (appGUI->nte->editor_textview);
 	}
 
@@ -1463,6 +1440,8 @@ const gchar *ui_info_editor =
 "    <toolitem name=\"mark_color\" action=\"mark_color\" />\n"
 "    <toolitem name=\"clear\" action=\"clear\" />\n"
 "    <separator/>\n"
+"    <toolitem name=\"open_links\" action=\"open_links\" />\n"
+"    <separator/>\n"
 "    <toolitem name=\"insert_date_time\" action=\"insert_date_time\" />\n"
 "    <toolitem name=\"insert_separator\" action=\"insert_separator\" />\n"
 "    <separator/>\n"
@@ -1479,6 +1458,7 @@ GtkActionEntry entries_editor[] = {
   { "strike", OSMO_STOCK_EDITOR_STRIKETHROUGH, _("Strikethrough"), NULL, _("Strikethrough"), NULL },
   { "mark_color", OSMO_STOCK_EDITOR_HIGHLIGHT, _("Highlight"), NULL, _("Highlight"), NULL },
   { "clear", OSMO_STOCK_EDITOR_CLEAR, _("Clear attributes"), NULL, _("Clear attributes"), G_CALLBACK (clear_text_attributes_cb)},
+  { "open_links", OSMO_STOCK_OPEN_URL, _("Open URL links"), NULL, _("Open URL links"), G_CALLBACK (open_url_links_cb)},
   { "save", OSMO_STOCK_EDITOR_SAVE, _("Save note"), NULL, _("Save note"), G_CALLBACK (editor_save_buffer_cb)},
   { "insert_date_time", OSMO_STOCK_EDITOR_INSERT_DATE_TIME, _("Insert current date and time"), NULL, _("Insert current date and time"), G_CALLBACK(insert_current_date_and_time_cb)},
   { "insert_separator", OSMO_STOCK_EDITOR_INSERT_SEPARATOR, _("Insert separator"), NULL, _("Insert separator"), G_CALLBACK(insert_separator_cb)},
@@ -1653,7 +1633,7 @@ guint n_t_entries_editor = G_N_ELEMENTS (t_entries_editor);
 	g_signal_connect (G_OBJECT(appGUI->nte->notes_find_entry), "key_release_event",
 					  G_CALLBACK(notes_search_entry_changed_cb), appGUI);
 
-	appGUI->nte->notes_find_clear_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_CLEAR, FALSE);
+	appGUI->nte->notes_find_clear_button = utl_gui_create_button (GTK_STOCK_CLEAR, OSMO_STOCK_BUTTON_CLEAR, FALSE);
 	gtk_widget_show (appGUI->nte->notes_find_clear_button);
 	GTK_WIDGET_UNSET_FLAGS (appGUI->nte->notes_find_clear_button, GTK_CAN_FOCUS);
 	gtk_button_set_relief (GTK_BUTTON(appGUI->nte->notes_find_clear_button), GTK_RELIEF_NONE);
@@ -1714,8 +1694,8 @@ guint n_t_entries_editor = G_N_ELEMENTS (t_entries_editor);
                                                        GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_STRING,
                                                        G_TYPE_STRING, G_TYPE_UINT, G_TYPE_UINT,
                                                        G_TYPE_STRING, G_TYPE_UINT, G_TYPE_UINT,
-                                                       G_TYPE_BOOLEAN, G_TYPE_UINT, G_TYPE_BOOLEAN, 
-													   G_TYPE_STRING, G_TYPE_STRING);
+                                                       G_TYPE_BOOLEAN, G_TYPE_UINT, G_TYPE_BOOLEAN,
+                                                       G_TYPE_STRING, G_TYPE_STRING, G_TYPE_BOOLEAN);
 
     appGUI->nte->notes_filter = gtk_tree_model_filter_new(GTK_TREE_MODEL(appGUI->nte->notes_list_store), NULL);
     gtk_tree_model_filter_set_visible_func (GTK_TREE_MODEL_FILTER(appGUI->nte->notes_filter), 
@@ -1735,6 +1715,7 @@ guint n_t_entries_editor = G_N_ELEMENTS (t_entries_editor);
                      G_CALLBACK(notes_list_dbclick_cb), appGUI);
 
     appGUI->nte->notes_list_selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (appGUI->nte->notes_list));
+    gtk_tree_selection_set_mode (appGUI->nte->notes_list_selection, GTK_SELECTION_MULTIPLE);
     g_signal_connect(G_OBJECT(appGUI->nte->notes_list_selection), "changed",
                      G_CALLBACK(notes_item_selected), appGUI);
 
@@ -1868,6 +1849,13 @@ guint n_t_entries_editor = G_N_ELEMENTS (t_entries_editor);
     gtk_tree_view_column_set_visible (appGUI->nte->notes_columns[N_COLUMN_FONTNAME], FALSE);
     gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->nte->notes_list), appGUI->nte->notes_columns[N_COLUMN_FONTNAME]);
 
+    renderer = gtk_cell_renderer_text_new();
+    appGUI->nte->notes_columns[N_COLUMN_ENCRYPTED] = gtk_tree_view_column_new_with_attributes(NULL,
+            renderer,
+            "text", N_COLUMN_ENCRYPTED,
+            NULL);
+    gtk_tree_view_column_set_visible(appGUI->nte->notes_columns[N_COLUMN_ENCRYPTED], FALSE);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(appGUI->nte->notes_list), appGUI->nte->notes_columns[N_COLUMN_ENCRYPTED]);
 	/* restore columns order */
 
 	columns_order[0] = config.notes_column_idx_0;
@@ -1882,7 +1870,7 @@ guint n_t_entries_editor = G_N_ELEMENTS (t_entries_editor);
 		for (i = 0; i < MAX_VISIBLE_NOTE_COLUMNS; i++) {
 			if (n == columns_order[i]) {
 				gtk_tree_view_move_column_after(GTK_TREE_VIEW(appGUI->nte->notes_list),
-												appGUI->nte->notes_columns[nt_columns[i]], NULL);
+                                        appGUI->nte->notes_columns[nt_columns[i]], NULL);
 				n--;
 			}
 		}
@@ -1891,11 +1879,17 @@ guint n_t_entries_editor = G_N_ELEMENTS (t_entries_editor);
 	set_note_columns_width (appGUI);
 
     /* configure sorting */
+    for (i = 0; i < MAX_VISIBLE_NOTE_COLUMNS; i++) {
+        gtk_tree_view_column_set_sort_column_id(appGUI->nte->notes_columns[nt_columns[i]], nt_columns[i]);
+        gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(appGUI->nte->notes_sort), nt_columns[i],
+                notes_column_sort_function, GINT_TO_POINTER(nt_columns[i]), NULL);
+    }
 
-    gtk_tree_sortable_set_sort_func ((GtkTreeSortable *)appGUI->nte->notes_sort, N_COLUMN_NAME, 
-                                     (GtkTreeIterCompareFunc)custom_notes_sort_function, NULL, NULL);
-    gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable *)appGUI->nte->notes_sort, N_COLUMN_NAME, 
-                                          config.notes_sorting_order);
+    /* restore sorting */
+    gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(appGUI->nte->notes_sort),
+            config.notes_sorting_column, config.notes_sorting_order);
+
+    g_signal_connect(appGUI->nte->notes_sort, "sort-column-changed", G_CALLBACK(notes_sort_column_changed_cb), appGUI);
 
     /*-------------------------------------------------------------------------------------*/
     /* editor */
@@ -1978,7 +1972,7 @@ guint n_t_entries_editor = G_N_ELEMENTS (t_entries_editor);
     gtk_widget_show (appGUI->nte->ro_editor_viewport);
     gtk_viewport_set_shadow_type (GTK_VIEWPORT (appGUI->nte->ro_editor_viewport), GTK_SHADOW_IN);
     gtk_box_pack_start (GTK_BOX (appGUI->nte->vbox_editor), appGUI->nte->ro_editor_viewport, TRUE, TRUE, 0);
-  
+
     appGUI->nte->ro_editor_scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
     gtk_widget_show (appGUI->nte->ro_editor_scrolledwindow);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (appGUI->nte->ro_editor_scrolledwindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
@@ -1993,6 +1987,8 @@ guint n_t_entries_editor = G_N_ELEMENTS (t_entries_editor);
 	webkit_web_view_set_settings (appGUI->nte->html_webkitview, appGUI->nte->webkit_settings);
 	webkit_web_view_set_editable (appGUI->nte->html_webkitview, FALSE);
 
+    g_signal_connect (appGUI->nte->html_webkitview, "console-message", 
+                      G_CALLBACK (utl_webkit_console_msg), appGUI);
 	g_signal_connect (appGUI->nte->html_webkitview, "populate-popup", 
 					  G_CALLBACK (utl_webkit_on_menu), appGUI);
 	g_signal_connect (appGUI->nte->html_webkitview, "navigation-policy-decision-requested",
@@ -2089,11 +2085,7 @@ guint n_t_entries_editor = G_N_ELEMENTS (t_entries_editor);
                       G_CALLBACK (case_sensitive_toggle_cb), appGUI);
 
 
-    if (config.default_stock_icons) {
-        close_button = utl_gui_stock_button (GTK_STOCK_CLOSE, FALSE);
-    } else {
-        close_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_CLOSE, FALSE);
-    }
+    close_button = utl_gui_create_button (GTK_STOCK_CLOSE, OSMO_STOCK_BUTTON_CLOSE, FALSE);
     GTK_WIDGET_UNSET_FLAGS(close_button, GTK_CAN_FOCUS);
     gtk_button_set_relief (GTK_BUTTON(close_button), GTK_RELIEF_NONE);
 	if (config.enable_tooltips) {
@@ -2155,25 +2147,27 @@ gint i;
 gchar *filename;
 GdkPixbuf *image;
 GtkWidget *helper;
+gboolean encrypted;
 
-    helper = gtk_image_new ();
-	i = 0;
+    helper = gtk_image_new();
+    i = 0;
 
     while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter, NULL, i++)) {
 
-        gtk_tree_model_get (GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter, 
-                            N_COLUMN_FILENAME, &filename, -1);
+        gtk_tree_model_get(GTK_TREE_MODEL(appGUI->nte->notes_list_store), &iter,
+                N_COLUMN_FILENAME, &filename, -1);
 
-		if (check_if_encrypted (filename, appGUI) == TRUE) {
-			image = gtk_widget_render_icon (helper, OSMO_STOCK_TYPE_ENCRYPTED, GTK_ICON_SIZE_MENU, NULL);
-		} else {
-			image = gtk_widget_render_icon (helper, OSMO_STOCK_TYPE_NORMAL, GTK_ICON_SIZE_MENU, NULL);
-		}
+        encrypted = check_if_encrypted(filename, appGUI);
+        if (encrypted == TRUE) {
+            image = gtk_widget_render_icon(helper, OSMO_STOCK_TYPE_ENCRYPTED, GTK_ICON_SIZE_MENU, NULL);
+        } else {
+            image = gtk_widget_render_icon(helper, OSMO_STOCK_TYPE_NORMAL, GTK_ICON_SIZE_MENU, NULL);
+        }
 
-		g_free (filename);
-		gtk_list_store_set (appGUI->nte->notes_list_store, &iter, N_COLUMN_TYPE, image, -1);
-		g_object_unref (image);
-	}
+        g_free(filename);
+        gtk_list_store_set(appGUI->nte->notes_list_store, &iter, N_COLUMN_TYPE, image, N_COLUMN_ENCRYPTED, encrypted, -1);
+        g_object_unref(image);
+    }
 }
 
 /*------------------------------------------------------------------------------*/
