@@ -47,6 +47,9 @@ notes_get_active_state (GUI *appGUI) {
 gint b, c;
 
     gint a = strlen(gtk_entry_get_text(GTK_ENTRY(appGUI->nte->note_name_entry)));
+    if (appGUI->nte->encrypted == FALSE) {
+        return a;
+    }
     if (appGUI->nte->password_entry != NULL) {
         b = strlen(gtk_entry_get_text(GTK_ENTRY(appGUI->nte->password_entry)));
     } else {
@@ -58,11 +61,7 @@ gint b, c;
         c = 1;
     }
 
-	if (appGUI->nte->encrypted == TRUE) {
-	    return (a && b && c);
-	} else {
-		return a;
-	}
+    return (a && b && c);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -170,15 +169,11 @@ notes_edit_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data) {
 /*------------------------------------------------------------------------------*/
 
 gint 
-notes_add_entry_key_release_cb (GtkWidget *widget, GdkEventKey *event, gpointer data) {
+notes_add_entry_changed_cb (GtkEditable *editable, gpointer data) {
 
     GUI *appGUI = (GUI *)data;
 
-    if (notes_get_active_state (appGUI)) {
-        gtk_widget_set_sensitive(appGUI->nte->add_entry_ok_button, TRUE);
-    } else {
-        gtk_widget_set_sensitive(appGUI->nte->add_entry_ok_button, FALSE);
-    }
+    gtk_widget_set_sensitive(appGUI->nte->add_entry_ok_button, notes_get_active_state (appGUI));
 
     return FALSE;
 }
@@ -197,24 +192,12 @@ notes_edit_dialog_show (GtkWidget *list, GtkTreeModel *model, GUI *appGUI)
 	GtkWidget *table;
 	GtkWidget *alignment;
 
-	GtkTreePath *sort_path, *filter_path, *path;
 	GtkTreeIter iter;
 	gchar *c_category, *category, *name;
 	gchar tmpbuf[BUFFER_SIZE];
 	gboolean remember_cursor;
 	gint i, n;
 
-	gtk_tree_view_get_cursor (GTK_TREE_VIEW (list), &sort_path, NULL);
-	if (sort_path == NULL) return;
-
-	filter_path = gtk_tree_model_sort_convert_path_to_child_path (GTK_TREE_MODEL_SORT (appGUI->nte->notes_sort), sort_path);
-	gtk_tree_path_free (sort_path);
-	if (filter_path == NULL) return;
-
-	path = gtk_tree_model_filter_convert_path_to_child_path (GTK_TREE_MODEL_FILTER (appGUI->nte->notes_filter), filter_path);
-	gtk_tree_path_free (filter_path);
-	if (path == NULL) return;
-
 	appGUI->nte->edit_entry_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_container_set_border_width (GTK_CONTAINER (appGUI->nte->edit_entry_window), 4);
 	gtk_window_set_title (GTK_WINDOW (appGUI->nte->edit_entry_window), _("Edit entry"));
@@ -249,21 +232,8 @@ notes_edit_dialog_show (GtkWidget *list, GtkTreeModel *model, GUI *appGUI)
 	appGUI->nte->note_name_entry = gtk_entry_new ();
 	gtk_container_add (GTK_CONTAINER (alignment), appGUI->nte->note_name_entry);
 	gtk_entry_set_invisible_char (GTK_ENTRY (appGUI->nte->note_name_entry), 8226);
-	g_signal_connect (G_OBJECT (appGUI->nte->note_name_entry), "key_release_event",
-	                  G_CALLBACK (notes_add_entry_key_release_cb), appGUI);
-
-	gtk_tree_view_get_cursor (GTK_TREE_VIEW (appGUI->nte->notes_list), &sort_path, NULL);
-	filter_path = gtk_tree_model_sort_convert_path_to_child_path (GTK_TREE_MODEL_SORT (appGUI->nte->notes_sort), sort_path);
-	gtk_tree_model_get_iter (GTK_TREE_MODEL (appGUI->nte->notes_filter), &iter, filter_path);
-	gtk_tree_path_free (filter_path);
-	gtk_tree_model_get (GTK_TREE_MODEL (appGUI->nte->notes_filter), &iter,
-	                    N_COLUMN_NAME, &name,
-	                    N_COLUMN_CATEGORY, &c_category,
-	                    N_COLUMN_REMEMBER_EDITOR_LINE, &remember_cursor,
-	                    -1);
-
-	gtk_entry_set_text (GTK_ENTRY (appGUI->nte->note_name_entry), name);
-	g_free (name);
+	g_signal_connect (G_OBJECT (appGUI->nte->note_name_entry), "changed",
+	                  G_CALLBACK (notes_add_entry_changed_cb), appGUI);
 
 	sprintf (tmpbuf, "<b>%s:</b>", _("Note name"));
 	label = gtk_label_new (tmpbuf);
@@ -285,19 +255,6 @@ notes_edit_dialog_show (GtkWidget *list, GtkTreeModel *model, GUI *appGUI)
 	gtk_container_add (GTK_CONTAINER (alignment), appGUI->nte->category_combobox);
 	gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->nte->category_combobox), _("None"));
 
-	i = n = 0;
-
-	while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->opt->notes_category_store), &iter, NULL, i++)) {
-		gtk_tree_model_get (GTK_TREE_MODEL (appGUI->opt->notes_category_store), &iter, 0, &category, -1);
-		gtk_combo_box_append_text (GTK_COMBO_BOX (appGUI->nte->category_combobox), category);
-		if (!strcmp (category, c_category)) n = i;
-		g_free (category);
-	}
-
-	g_free (c_category);
-
-	gtk_combo_box_set_active (GTK_COMBO_BOX (appGUI->nte->category_combobox), n);
-
 	sprintf (tmpbuf, "<b>%s:</b>", _("Category"));
 	label = gtk_label_new (tmpbuf);
 	gtk_frame_set_label_widget (GTK_FRAME (frame), label);
@@ -315,7 +272,6 @@ notes_edit_dialog_show (GtkWidget *list, GtkTreeModel *model, GUI *appGUI)
 	appGUI->nte->remember_cursor_checkbutton = gtk_check_button_new_with_mnemonic (_("Remember cursor position"));
 	GTK_WIDGET_UNSET_FLAGS (appGUI->nte->remember_cursor_checkbutton, GTK_CAN_FOCUS);
 	gtk_container_add (GTK_CONTAINER (alignment), appGUI->nte->remember_cursor_checkbutton);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->nte->remember_cursor_checkbutton), remember_cursor);
 
 	sprintf (tmpbuf, "<b>%s:</b>", _("Options"));
 	label = gtk_label_new (tmpbuf);
@@ -330,65 +286,85 @@ notes_edit_dialog_show (GtkWidget *list, GtkTreeModel *model, GUI *appGUI)
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
 	gtk_box_set_spacing (GTK_BOX (hbuttonbox), 4);
 
-	cancel_button = utl_gui_create_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
+	cancel_button = utl_gui_create_labeled_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
 	GTK_WIDGET_UNSET_FLAGS (cancel_button, GTK_CAN_FOCUS);
 	gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
 	g_signal_connect (G_OBJECT (cancel_button), "clicked",
 	                  G_CALLBACK (button_notes_edit_close_cb), appGUI);
 
-	appGUI->nte->add_entry_ok_button = utl_gui_create_button (GTK_STOCK_OK, OSMO_STOCK_BUTTON_OK, _("OK"));
+	appGUI->nte->add_entry_ok_button = utl_gui_create_labeled_button (GTK_STOCK_OK, OSMO_STOCK_BUTTON_OK, _("OK"));
 	GTK_WIDGET_UNSET_FLAGS (appGUI->nte->add_entry_ok_button, GTK_CAN_FOCUS);
 	gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->nte->add_entry_ok_button);
 	g_signal_connect (G_OBJECT (appGUI->nte->add_entry_ok_button), "clicked",
 	                  G_CALLBACK (notes_edit_action_cb), appGUI);
 
-	gtk_widget_show_all (appGUI->nte->edit_entry_window);
-}
+	iter = utl_gui_get_first_selection_iter(appGUI->nte->notes_list_selection, &model);
+	gtk_tree_model_get(model, &iter,
+                N_COLUMN_NAME, &name,
+                N_COLUMN_CATEGORY, &c_category,
+                N_COLUMN_REMEMBER_EDITOR_LINE, &remember_cursor,
+                -1);
 
+	gtk_entry_set_text(GTK_ENTRY(appGUI->nte->note_name_entry), name);
+	i = n = 0;
+
+	while (gtk_tree_model_iter_nth_child(GTK_TREE_MODEL(appGUI->opt->notes_category_store), &iter, NULL, i++)) {
+            gtk_tree_model_get(GTK_TREE_MODEL(appGUI->opt->notes_category_store), &iter, 0, &category, -1);
+            gtk_combo_box_append_text(GTK_COMBO_BOX(appGUI->nte->category_combobox), category);
+            if (!strcmp(category, c_category)) n = i;
+            g_free(category);
+	}
+	gtk_combo_box_set_active(GTK_COMBO_BOX(appGUI->nte->category_combobox), n);
+
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(appGUI->nte->remember_cursor_checkbutton), remember_cursor);
+
+	g_free(c_category);
+	g_free(name);
+	gtk_widget_show_all(appGUI->nte->edit_entry_window);
+}
+/*------------------------------------------------------------------------------*/
+void
+notes_remove(GtkTreeRowReference *ref, GUI *appGUI) {
+    GtkTreePath *path;
+    GtkTreeIter iter, filter_iter, sort_iter;
+    gchar *filename;
+    GtkTreeModel *model;
+
+    model = gtk_tree_row_reference_get_model(ref);
+    path = gtk_tree_row_reference_get_path(ref);
+    if (path != NULL) {
+        if (gtk_tree_model_get_iter(model, &sort_iter, path)) {
+            gtk_tree_model_get(model, &sort_iter, N_COLUMN_FILENAME, &filename, -1);
+            g_unlink(notes_get_full_filename(filename, appGUI));
+            g_free(filename);
+            gtk_tree_model_sort_convert_iter_to_child_iter(GTK_TREE_MODEL_SORT(model), &filter_iter, &sort_iter);
+            gtk_tree_model_filter_convert_iter_to_child_iter(GTK_TREE_MODEL_FILTER(gtk_tree_model_sort_get_model(GTK_TREE_MODEL_SORT(model))), &iter, &filter_iter);
+            gtk_list_store_remove(appGUI->nte->notes_list_store, &iter);
+        }
+        gtk_tree_path_free(path);
+    }
+}
 /*------------------------------------------------------------------------------*/
 
 void
-notes_remove_dialog_show (GtkWidget *list, GtkListStore *list_store, GUI *appGUI) {
+notes_remove_dialog_show (GUI *appGUI) {
+    gint response;
+    gchar tmpbuf[BUFFER_SIZE];
 
-gint response;
-GtkTreePath *path, *filter_path, *sort_path;
-GtkTreeIter iter;
-gchar *filename;
-gchar tmpbuf[BUFFER_SIZE];
 
-    gtk_tree_view_get_cursor (GTK_TREE_VIEW (list), &sort_path, NULL);
+    sprintf(tmpbuf, "%s\n%s\n\n%s", _("Selected note will be removed."),
+            _("No further data recovery will be possible."), _("Are you sure?"));
 
-    if (sort_path == NULL) return;
+    response = utl_gui_create_dialog(GTK_MESSAGE_QUESTION, tmpbuf, GTK_WINDOW(appGUI->main_window));
 
-    filter_path = gtk_tree_model_sort_convert_path_to_child_path (GTK_TREE_MODEL_SORT(appGUI->nte->notes_sort), sort_path);
-    gtk_tree_path_free (sort_path);
+    if (response == GTK_RESPONSE_YES) {
+        utl_gui_foreach_selected(appGUI->nte->notes_list_selection, GTK_TREE_MODEL(appGUI->nte->notes_list_store),
+                (GFunc) notes_remove, appGUI);
+        update_notes_items(appGUI);
+        check_notes_type(appGUI);
 
-    if (filter_path != NULL) {
-
-        path = gtk_tree_model_filter_convert_path_to_child_path (GTK_TREE_MODEL_FILTER(appGUI->nte->notes_filter), filter_path);
-        gtk_tree_path_free (filter_path);
-
-        if (path != NULL) {
-
-            sprintf (tmpbuf, "%s\n%s\n\n%s", _("Selected note will be removed."), 
-                     _("No further data recovery will be possible."), _("Are you sure?"));
-
-            response = utl_gui_create_dialog(GTK_MESSAGE_QUESTION, tmpbuf, GTK_WINDOW(appGUI->main_window));
-
-            if (response == GTK_RESPONSE_YES) {   
-                gtk_tree_model_get_iter(GTK_TREE_MODEL(list_store), &iter, path);
-                gtk_tree_model_get(GTK_TREE_MODEL(list_store), &iter, N_COLUMN_FILENAME, &filename, -1);
-                g_unlink (notes_get_full_filename(filename, appGUI));
-                g_free (filename);
-                gtk_list_store_remove(list_store, &iter);
-                gtk_tree_path_free(path);
-                update_notes_items(appGUI);
-				check_notes_type (appGUI);
-
-                if (config.save_data_after_modification) {
-                    write_notes_entries (appGUI);
-                }
-            }
+        if (config.save_data_after_modification) {
+            write_notes_entries(appGUI);
         }
     }
 }
@@ -437,7 +413,7 @@ notes_add_entry_action_cb (GtkWidget *widget, gpointer data) {
 
 gchar *name;
 gchar *empty_str, *current_filename;
-gchar *category;
+gchar *category, *create_date_str;
 guint32 current_date;
 GtkTreeIter iter;
 gint current_time;
@@ -521,21 +497,25 @@ GRG_KEY keyholder;
                 category = g_strdup(_("None"));
             }
         }
+        create_date_str = g_strdup(get_date_time_str (current_date, current_time));
 
         gtk_list_store_append(appGUI->nte->notes_list_store, &iter);
         gtk_list_store_set(appGUI->nte->notes_list_store, &iter, 
                            N_COLUMN_NAME, name, 
                            N_COLUMN_CATEGORY, category, 
-                           N_COLUMN_LAST_CHANGES_DATE, get_date_time_str (current_date, current_time),
+                           N_COLUMN_LAST_CHANGES_DATE, create_date_str,
                            N_COLUMN_LAST_CHANGES_DATE_JULIAN, current_date,
                            N_COLUMN_LAST_CHANGES_TIME, current_time,
-                           N_COLUMN_CREATE_DATE, get_date_time_str (current_date, current_time),
+                           N_COLUMN_CREATE_DATE, create_date_str,
                            N_COLUMN_CREATE_DATE_JULIAN, current_date,
                            N_COLUMN_CREATE_TIME, current_time,
-						   N_COLUMN_REMEMBER_EDITOR_LINE, remember_cursor,
+                           N_COLUMN_REMEMBER_EDITOR_LINE, remember_cursor,
                            N_COLUMN_EDITOR_LINE, 0,
-                           N_COLUMN_FILENAME, current_filename, -1);
+                           N_COLUMN_FILENAME, current_filename,
+                           N_COLUMN_FONTNAME, DEFAULT_NOTE_FONT,
+                           -1);
         g_free (category);
+        g_free (create_date_str);
 
         update_notes_items(appGUI);
 		check_notes_type (appGUI);
@@ -577,7 +557,7 @@ note_type_cb (GtkWidget *widget, gpointer user_data) {
 
 	GUI *appGUI = (GUI *) user_data;
 
-    if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->nte->note_normal_radiobutton)) == TRUE) {
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->nte->note_normal_radiobutton)) == TRUE) {
 		appGUI->nte->encrypted = FALSE;
 	} else {
 		appGUI->nte->encrypted = TRUE;
@@ -585,7 +565,7 @@ note_type_cb (GtkWidget *widget, gpointer user_data) {
 
 	gtk_widget_set_sensitive (appGUI->nte->password_entry, appGUI->nte->encrypted);
 	gtk_widget_set_sensitive (appGUI->nte->spassword_entry, appGUI->nte->encrypted);
-
+    gtk_widget_set_sensitive(appGUI->nte->add_entry_ok_button, notes_get_active_state (appGUI));
 }
 
 /*------------------------------------------------------------------------------*/
@@ -654,8 +634,8 @@ GtkTreeIter iter;
     gtk_widget_show (appGUI->nte->note_name_entry);
     gtk_container_add (GTK_CONTAINER (alignment), appGUI->nte->note_name_entry);
     gtk_entry_set_invisible_char (GTK_ENTRY (appGUI->nte->note_name_entry), 8226);
-    g_signal_connect (G_OBJECT (appGUI->nte->note_name_entry), "key_release_event",
-                      G_CALLBACK (notes_add_entry_key_release_cb), appGUI);
+    g_signal_connect (G_OBJECT (appGUI->nte->note_name_entry), "changed",
+                      G_CALLBACK (notes_add_entry_changed_cb), appGUI);
 
     sprintf (tmpbuf, "<b>%s:</b>", _("Note name"));
     label = gtk_label_new (tmpbuf);
@@ -753,8 +733,8 @@ GtkTreeIter iter;
     gtk_container_add (GTK_CONTAINER (alignment), appGUI->nte->password_entry);
     gtk_entry_set_invisible_char (GTK_ENTRY (appGUI->nte->password_entry), 8226);
     gtk_entry_set_visibility (GTK_ENTRY (appGUI->nte->password_entry), FALSE);
-    g_signal_connect (G_OBJECT (appGUI->nte->password_entry), "key_release_event",
-                      G_CALLBACK (notes_add_entry_key_release_cb), appGUI);
+    g_signal_connect (G_OBJECT (appGUI->nte->password_entry), "changed",
+                      G_CALLBACK (notes_add_entry_changed_cb), appGUI);
 	gtk_widget_set_sensitive (appGUI->nte->password_entry, FALSE);
 
     sprintf (tmpbuf, "<b>%s:</b>", _("Enter password"));
@@ -779,8 +759,8 @@ GtkTreeIter iter;
     gtk_container_add (GTK_CONTAINER (alignment), appGUI->nte->spassword_entry);
     gtk_entry_set_invisible_char (GTK_ENTRY (appGUI->nte->spassword_entry), 8226);
     gtk_entry_set_visibility (GTK_ENTRY (appGUI->nte->spassword_entry), FALSE);
-    g_signal_connect (G_OBJECT (appGUI->nte->spassword_entry), "key_release_event",
-                      G_CALLBACK (notes_add_entry_key_release_cb), appGUI);
+    g_signal_connect (G_OBJECT (appGUI->nte->spassword_entry), "changed",
+                      G_CALLBACK (notes_add_entry_changed_cb), appGUI);
     g_signal_connect (G_OBJECT (appGUI->nte->spassword_entry), "key_press_event",
                       G_CALLBACK (notes_add_ok_key_press_cb), appGUI);
 	gtk_widget_set_sensitive (appGUI->nte->spassword_entry, FALSE);
@@ -825,14 +805,14 @@ GtkTreeIter iter;
     gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
     gtk_box_set_spacing (GTK_BOX (hbuttonbox), 4);
 
-	cancel_button = utl_gui_create_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
+	cancel_button = utl_gui_create_labeled_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
     GTK_WIDGET_UNSET_FLAGS(cancel_button, GTK_CAN_FOCUS);
     gtk_widget_show (cancel_button);
     gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
     g_signal_connect (G_OBJECT (cancel_button), "clicked",
                         G_CALLBACK (button_notes_add_close_cb), appGUI);
     
-    appGUI->nte->add_entry_ok_button = utl_gui_create_button (GTK_STOCK_OK, OSMO_STOCK_BUTTON_OK, _("OK"));
+    appGUI->nte->add_entry_ok_button = utl_gui_create_labeled_button (GTK_STOCK_OK, OSMO_STOCK_BUTTON_OK, _("OK"));
     GTK_WIDGET_UNSET_FLAGS(appGUI->nte->add_entry_ok_button, GTK_CAN_FOCUS);
     gtk_widget_show (appGUI->nte->add_entry_ok_button);
     gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->nte->add_entry_ok_button);
@@ -876,23 +856,20 @@ gchar *current_filename;
 GtkTreeIter iter;
 GtkTreeModel *model;
 
-    if (gtk_tree_selection_get_selected (appGUI->nte->notes_list_selection, &model, &iter)) {
+    iter = utl_gui_get_first_selection_iter(appGUI->nte->notes_list_selection, &model);
+    gtk_tree_model_get(model, &iter, N_COLUMN_FILENAME, &current_filename, -1);
 
-        gtk_tree_model_get (GTK_TREE_MODEL(model), &iter, N_COLUMN_FILENAME, &current_filename, -1);
+    appGUI->nte->filename = g_strdup(current_filename);
 
-		appGUI->nte->filename = g_strdup (current_filename);
+    g_file_get_contents(notes_get_full_filename(current_filename, appGUI), &txtnote, NULL, NULL);
 
-		g_file_get_contents (notes_get_full_filename(current_filename, appGUI), &txtnote, NULL, NULL);
-
-		buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
-		utl_gui_text_buffer_set_text_with_tags (buffer, (const gchar *)txtnote, TRUE);
-		notes_show_selector_editor (EDITOR, appGUI);
-		appGUI->nte->buffer_check_modify_enable = TRUE;
-
-		g_free (txtnote);
-		g_free (current_filename);
-	}
+    buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->nte->editor_textview));
+    utl_gui_text_buffer_set_text_with_tags(buffer, (const gchar *) txtnote, TRUE);
+    notes_show_selector_editor(EDITOR, appGUI);
+    appGUI->nte->buffer_check_modify_enable = TRUE;
 
+    g_free(txtnote);
+    g_free(current_filename);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -910,48 +887,46 @@ unsigned char *txtnote;
 long txtlen;
 gint ret;
 
-    GUI *appGUI = (GUI *)data;
+    GUI *appGUI = (GUI *) data;
 
-    pass = g_strdup(gtk_entry_get_text (GTK_ENTRY(appGUI->nte->password_entry)));
+    pass = g_strdup(gtk_entry_get_text(GTK_ENTRY(appGUI->nte->password_entry)));
 
-    notes_enter_password_close_cb (widget, NULL, data);
+    notes_enter_password_close_cb(widget, NULL, data);
 
-    if (gtk_tree_selection_get_selected (appGUI->nte->notes_list_selection, &model, &iter)) {
+    iter = utl_gui_get_first_selection_iter(appGUI->nte->notes_list_selection, &model);
 
-        gtk_tree_model_get (GTK_TREE_MODEL(model), &iter, N_COLUMN_FILENAME, &current_filename, -1);
+    gtk_tree_model_get(GTK_TREE_MODEL(model), &iter, N_COLUMN_FILENAME, &current_filename, -1);
 
-        appGUI->nte->filename = g_strdup(notes_get_full_filename(current_filename, appGUI));
-        appGUI->nte->context = grg_context_initialize_defaults ((unsigned char*) "OSM");
-        appGUI->nte->keyholder = grg_key_gen ((unsigned char*) pass, -1);
+    appGUI->nte->filename = g_strdup(notes_get_full_filename(current_filename, appGUI));
+    appGUI->nte->context = grg_context_initialize_defaults((unsigned char*) "OSM");
+    appGUI->nte->keyholder = grg_key_gen((unsigned char*) pass, -1);
 
-        grg_ctx_set_crypt_algo (appGUI->nte->context, get_enc_algorithm_value());
-        grg_ctx_set_hash_algo (appGUI->nte->context, get_enc_hashing_value());
-        grg_ctx_set_comp_algo (appGUI->nte->context, get_comp_algorithm_value());
-        grg_ctx_set_comp_ratio (appGUI->nte->context, get_comp_ratio_value());
+    grg_ctx_set_crypt_algo(appGUI->nte->context, get_enc_algorithm_value());
+    grg_ctx_set_hash_algo(appGUI->nte->context, get_enc_hashing_value());
+    grg_ctx_set_comp_algo(appGUI->nte->context, get_comp_algorithm_value());
+    grg_ctx_set_comp_ratio(appGUI->nte->context, get_comp_ratio_value());
 
-        ret = grg_decrypt_file (appGUI->nte->context, appGUI->nte->keyholder, 
-                                (unsigned char *) appGUI->nte->filename, &txtnote, &txtlen);
+    ret = grg_decrypt_file(appGUI->nte->context, appGUI->nte->keyholder,
+            (unsigned char *) appGUI->nte->filename, &txtnote, &txtlen);
 
-        if (ret != GRG_OK) {
-            utl_gui_create_dialog(GTK_MESSAGE_ERROR, _("Incorrect password!"), GTK_WINDOW(appGUI->main_window));
-            g_free(pass);
-            grg_key_free (appGUI->nte->context, appGUI->nte->keyholder);
-            appGUI->nte->keyholder = NULL;
-            grg_context_free (appGUI->nte->context);
-            appGUI->nte->context = NULL;
-            g_free(appGUI->nte->filename);
-            appGUI->nte->filename = NULL;
-            return;
-        } else {
-			buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (appGUI->nte->editor_textview));
-            utl_gui_text_buffer_set_text_with_tags (buffer, (const gchar *)txtnote, TRUE);
-            notes_show_selector_editor (EDITOR, appGUI);
-            appGUI->nte->buffer_check_modify_enable = TRUE;
-        }
-
-		g_free (current_filename);
+    if (ret != GRG_OK) {
+        utl_gui_create_dialog(GTK_MESSAGE_ERROR, _("Incorrect password!"), GTK_WINDOW(appGUI->main_window));
+        g_free(pass);
+        grg_key_free(appGUI->nte->context, appGUI->nte->keyholder);
+        appGUI->nte->keyholder = NULL;
+        grg_context_free(appGUI->nte->context);
+        appGUI->nte->context = NULL;
+        g_free(appGUI->nte->filename);
+        appGUI->nte->filename = NULL;
+        return;
+    } else {
+        buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(appGUI->nte->editor_textview));
+        utl_gui_text_buffer_set_text_with_tags(buffer, (const gchar *) txtnote, TRUE);
+        notes_show_selector_editor(EDITOR, appGUI);
+        appGUI->nte->buffer_check_modify_enable = TRUE;
     }
 
+    g_free(current_filename);
     g_free(pass);
 }
 
@@ -997,9 +972,8 @@ gchar *current_filename;
 	GtkWidget *hbuttonbox;
 #endif /* HAVE_LIBGRINGOTTS */
 
-	if (gtk_tree_selection_get_selected (appGUI->nte->notes_list_selection, &model, &iter)) {
-
-        gtk_tree_model_get (GTK_TREE_MODEL(model), &iter, N_COLUMN_FILENAME, &current_filename, -1);
+        iter = utl_gui_get_first_selection_iter(appGUI->nte->notes_list_selection, &model);
+        gtk_tree_model_get (model, &iter, N_COLUMN_FILENAME, &current_filename, -1);
 
 #ifndef HAVE_LIBGRINGOTTS
 
@@ -1073,14 +1047,14 @@ gchar *current_filename;
 			gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
 			gtk_box_set_spacing (GTK_BOX (hbuttonbox), 4);
 
-			cancel_button = utl_gui_create_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
+			cancel_button = utl_gui_create_labeled_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
 			GTK_WIDGET_UNSET_FLAGS(cancel_button, GTK_CAN_FOCUS);
 			gtk_widget_show (cancel_button);
 			gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
 			g_signal_connect (G_OBJECT (cancel_button), "clicked",
 								G_CALLBACK (button_enter_password_close_cb), appGUI);
 			
-			ok_button = utl_gui_create_button (GTK_STOCK_OK, OSMO_STOCK_BUTTON_OK, _("OK"));
+			ok_button = utl_gui_create_labeled_button (GTK_STOCK_OK, OSMO_STOCK_BUTTON_OK, _("OK"));
 			GTK_WIDGET_UNSET_FLAGS(ok_button, GTK_CAN_FOCUS);
 			gtk_widget_show (ok_button);
 			gtk_container_add (GTK_CONTAINER (hbuttonbox), ok_button);
@@ -1098,7 +1072,6 @@ gchar *current_filename;
 #endif /* HAVE_LIBGRINGOTTS */
 
 		g_free (current_filename);
-	}
 }
 
 /*------------------------------------------------------------------------------*/
@@ -1212,7 +1185,7 @@ gboolean remember_editor_line, editor_readonly;
 										create_date_str = g_strdup(get_date_time_str (create_date_julian, create_time));
 
 										if (fontname == NULL) {
-											fontname = g_strdup("Sans 12");
+											fontname = g_strdup(DEFAULT_NOTE_FONT);
 										}
 
 										gtk_list_store_set (appGUI->nte->notes_list_store, &iter, 
