@@ -26,10 +26,11 @@
 
 void        notes_add_entry             (GUI *appGUI);
 void        notes_edit_dialog_show      (GtkWidget *list, GtkTreeModel *model, GUI *appGUI);
-void        notes_remove_dialog_show    (GtkWidget *list, GtkListStore *list_store, GUI *appGUI);
+void        notes_remove_dialog_show    (GUI *appGUI);
 void        notes_enter_password        (GUI *appGUI);
 void        notes_cleanup_files         (GUI *appGUI);
-gchar *     notes_get_filename          (GUI *appGUI);
+gchar *     notes_get_new_filename      (GUI *appGUI);
+gchar *     notes_get_full_filename     (gchar *filename, GUI *appGUI);  
 
 void        read_notes_entries          (GUI *appGUI);
 void        write_notes_entries         (GUI *appGUI);
