@@ -120,9 +120,13 @@ gint i;
     config.sound_alarm_repeat = 1;
 	g_strlcpy (config.link_color, "blue", MAXCOLORNAME);
     g_strlcpy (config.spell_lang, g_getenv("LANG"), MAXNAME);
-	g_strlcpy (config.web_browser, "xdg-open %s", MAXHELPERCMD);
+    /* FIXME: DO NOT USE xdg-open AS IT CANNOT OPEN MULTIPLE LINKS AT ONCE */
+	/*g_strlcpy (config.web_browser, "xdg-open %s", MAXHELPERCMD);*/
+	g_strlcpy (config.web_browser, "firefox %s", MAXHELPERCMD);
 	g_strlcpy (config.email_client, "xdg-email %s", MAXHELPERCMD);
-	g_strlcpy (config.sound_player, "play %s", MAXHELPERCMD);
+	/* play command requires SoX */
+	/*g_strlcpy (config.sound_player, "play %s", MAXHELPERCMD);*/
+	g_strlcpy (config.sound_player, "aplay %s", MAXHELPERCMD);
 
     /* calendar */
     config.fy_window_size_x = 750;
@@ -194,9 +198,9 @@ gint i;
     config.add_edit = FALSE;
     config.remember_category_in_tasks = FALSE;
     config.current_category_in_tasks = 0;
-    config.tasks_pane_pos = 275;
+    config.tasks_pane_pos = DEFAULT_PANED_SPLIT_POSITION;
     config.tasks_sorting_order = GTK_SORT_ASCENDING;
-    config.tasks_sorting_mode = 0;
+    config.tasks_sorting_column = TA_COLUMN_DUE_DATE;
     config.tsk_visible_due_date_column = TRUE;
     config.tsk_visible_type_column = TRUE;
     config.tsk_visible_priority_column = FALSE;
@@ -226,16 +230,15 @@ gint i;
 
     /* contacts */
     config.find_mode = CONTACTS_FF_FIRST_NAME;
-    config.show_after_search = TRUE;
     config.hide_group_column = FALSE;
     config.maps_provider = 0;
-    config.contacts_pane_pos = 275;
+    config.contacts_pane_pos = DEFAULT_PANED_SPLIT_POSITION;
     config.photo_width = 80;
     config.cnt_visible_age_column = TRUE;
     config.cnt_visible_birthday_date_column = TRUE;
     config.cnt_visible_zodiac_sign_column = TRUE;
     config.contacts_sorting_order = GTK_SORT_ASCENDING;
-    config.contacts_sorting_mode = 0;
+    config.contacts_sorting_column = COLUMN_GROUP;
     config.contacts_addedit_win_w = 500;
     config.contacts_addedit_win_h = 600;
     config.contacts_addedit_win_x = config.window_x+config.window_size_x/2-config.contacts_addedit_win_w/2;
@@ -274,7 +277,6 @@ gint i;
     for(i=0; i < CONTACTS_NUM_COLUMNS; i++) {
         config.export_fields[i] = '-';
     }
-    config.export_fields[0] = '\0';
     config.export_fields[COLUMN_GROUP] = '+';
     config.export_fields[COLUMN_FIRST_NAME] = '+';
     config.export_fields[COLUMN_LAST_NAME] = '+';
@@ -286,7 +288,7 @@ gint i;
     config.notes_comp_algorithm = 0;        /* ZLib */
     config.notes_comp_ratio = 3;            /* BEST */
     config.notes_sorting_order = GTK_SORT_ASCENDING;
-    config.notes_sorting_mode = 0;
+    config.notes_sorting_column = N_COLUMN_NAME;
     config.nte_visible_type_column = TRUE;
     config.nte_visible_category_column = TRUE;
     config.nte_visible_last_changes_column = TRUE;
@@ -474,7 +476,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 					utl_xml_get_int ("current_category", &config.current_category_in_tasks, tasks_node);
 					utl_xml_get_int ("pane_pos", &config.tasks_pane_pos, tasks_node);
 					utl_xml_get_int ("tasks_sorting_order", &config.tasks_sorting_order, tasks_node);
-					utl_xml_get_int ("tasks_sorting_mode", &config.tasks_sorting_mode, tasks_node);
+					utl_xml_get_int ("tasks_sorting_column", &config.tasks_sorting_column, tasks_node);
 					utl_xml_get_int ("visible_due_date_column", &config.tsk_visible_due_date_column, tasks_node);
 					utl_xml_get_int ("visible_type_column", &config.tsk_visible_type_column, tasks_node);
 					utl_xml_get_int ("visible_priority_column", &config.tsk_visible_priority_column, tasks_node);
@@ -514,7 +516,6 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 
 				while (contacts_node != NULL) {
 					utl_xml_get_int ("find_mode", &config.find_mode, contacts_node);
-					utl_xml_get_int ("show_after_search", &config.show_after_search, contacts_node);
 					utl_xml_get_int ("hide_group_column", &config.hide_group_column, contacts_node);
 					utl_xml_get_int ("maps_provider", &config.maps_provider, contacts_node);
 					utl_xml_get_int ("pane_pos", &config.contacts_pane_pos, contacts_node);
@@ -529,7 +530,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 					utl_xml_get_int ("export_format", &config.export_format, contacts_node);
 					utl_xml_get_strn ("export_fields", config.export_fields, MAXCONTACTFIELDS, contacts_node);
 					utl_xml_get_int ("contacts_sorting_order", &config.contacts_sorting_order, contacts_node);
-					utl_xml_get_int ("contacts_sorting_mode", &config.contacts_sorting_mode, contacts_node);
+					utl_xml_get_int ("contacts_sorting_column", &config.contacts_sorting_column, contacts_node);
 					utl_xml_get_int ("contacts_addedit_win_x", &config.contacts_addedit_win_x, contacts_node);
 					utl_xml_get_int ("contacts_addedit_win_y", &config.contacts_addedit_win_y, contacts_node);
 					utl_xml_get_int ("contacts_addedit_win_w", &config.contacts_addedit_win_w, contacts_node);
@@ -575,7 +576,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 					utl_xml_get_int ("comp_algorithm", &config.notes_comp_algorithm, notes_node);
 					utl_xml_get_int ("comp_ratio", &config.notes_comp_ratio, notes_node);
 					utl_xml_get_int ("sorting_order", &config.notes_sorting_order, notes_node);
-					utl_xml_get_int ("sorting_mode", &config.notes_sorting_mode, notes_node);
+					utl_xml_get_int ("sorting_column", &config.notes_sorting_column, notes_node);
 					utl_xml_get_int ("visible_type_column", &config.nte_visible_type_column, notes_node);
 					utl_xml_get_int ("visible_category_column", &config.nte_visible_category_column, notes_node);
 					utl_xml_get_int ("visible_last_changes_column", &config.nte_visible_last_changes_column, notes_node);
@@ -610,7 +611,6 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 		}
 
 		xmlFreeDoc (doc);
-
 	} else {
 		prefs_set_default_values ();
 		prefs_write_config (appGUI);
@@ -753,7 +753,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	utl_xml_put_int ("current_category", config.current_category_in_tasks, tasks_node);
 	utl_xml_put_int ("pane_pos", config.tasks_pane_pos, tasks_node);
 	utl_xml_put_int ("tasks_sorting_order", config.tasks_sorting_order, tasks_node);
-	utl_xml_put_int ("tasks_sorting_mode", config.tasks_sorting_mode, tasks_node);
+	utl_xml_put_int ("tasks_sorting_column", config.tasks_sorting_column, tasks_node);
 	utl_xml_put_int ("visible_due_date_column", config.tsk_visible_due_date_column, tasks_node);
 	utl_xml_put_int ("visible_type_column", config.tsk_visible_type_column, tasks_node);
 	utl_xml_put_int ("visible_priority_column", config.tsk_visible_priority_column, tasks_node);
@@ -788,7 +788,6 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	xmlAddChild (node, contacts_node);
 
 	utl_xml_put_int ("find_mode", config.find_mode, contacts_node);
-	utl_xml_put_int ("show_after_search", config.show_after_search, contacts_node);
 	utl_xml_put_int ("hide_group_column", config.hide_group_column, contacts_node);
 	utl_xml_put_int ("maps_provider", config.maps_provider, contacts_node);
 	utl_xml_put_int ("pane_pos", config.contacts_pane_pos, contacts_node);
@@ -803,7 +802,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	utl_xml_put_int ("export_format", config.export_format, contacts_node);
 	utl_xml_put_strn ("export_fields", config.export_fields, MAXCONTACTFIELDS, contacts_node, doc);
 	utl_xml_put_int ("contacts_sorting_order", config.contacts_sorting_order, contacts_node);
-	utl_xml_put_int ("contacts_sorting_mode", config.contacts_sorting_mode, contacts_node);
+	utl_xml_put_int ("contacts_sorting_column", config.contacts_sorting_column, contacts_node);
 	utl_xml_put_int ("contacts_addedit_win_x", config.contacts_addedit_win_x, contacts_node);
 	utl_xml_put_int ("contacts_addedit_win_y", config.contacts_addedit_win_y, contacts_node);
 	utl_xml_put_int ("contacts_addedit_win_w", config.contacts_addedit_win_w, contacts_node);
@@ -844,7 +843,7 @@ xmlNodePtr node, general_node, calendar_node, tasks_node, contacts_node, notes_n
 	utl_xml_put_int ("comp_algorithm", config.notes_comp_algorithm, notes_node);
 	utl_xml_put_int ("comp_ratio", config.notes_comp_ratio, notes_node);
 	utl_xml_put_int ("sorting_order", config.notes_sorting_order, notes_node);
-	utl_xml_put_int ("sorting_mode", config.notes_sorting_mode, notes_node);
+	utl_xml_put_int ("sorting_column", config.notes_sorting_column, notes_node);
 	utl_xml_put_int ("visible_type_column", config.nte_visible_type_column, notes_node);
 	utl_xml_put_int ("visible_category_column", config.nte_visible_category_column, notes_node);
 	utl_xml_put_int ("visible_last_changes_column", config.nte_visible_last_changes_column, notes_node);
