@@ -544,6 +544,8 @@ create_general_section (GtkWidget *general_vbox, GUI *appGUI)
 	i++;
 
 #endif /* HAVE_GTKSPELL */
+	/* update the button enablement */
+	override_locale_changed_cb(GTK_TOGGLE_BUTTON (appGUI->opt->override_locale_checkbutton), appGUI);
 
 	checkbutton = gtk_check_button_new_with_mnemonic (_("Enable tooltips"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton), config.enable_tooltips);
@@ -825,7 +827,7 @@ opt_create_preferences_window (GUI *appGUI)
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
 	gtk_box_set_spacing (GTK_BOX (hbuttonbox), HBOX_SPACING);
 
-	close_button = utl_gui_create_button (GTK_STOCK_CLOSE, OSMO_STOCK_BUTTON_CLOSE, _("Close"));
+	close_button = utl_gui_create_labeled_button (GTK_STOCK_CLOSE, OSMO_STOCK_BUTTON_CLOSE, _("Close"));
 	gtk_container_add (GTK_CONTAINER (hbuttonbox), close_button);
 	GTK_WIDGET_SET_FLAGS (close_button, GTK_CAN_DEFAULT);
 	g_signal_connect (G_OBJECT (close_button), "clicked", G_CALLBACK (close_window), window);
