@@ -64,6 +64,8 @@ GtkStockItem osmo_stock_items[] = {
     { (gchar*) OSMO_STOCK_BACKUP,                  (gchar*) N_("Backup data"),                  0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_RESTORE,                 (gchar*) N_("Restore data"),                 0, 0, TRANSLATION_DOMAIN },
 
+	{ (gchar*) OSMO_STOCK_OPEN_URL,                (gchar*) N_("Open URL"),                     0, 0, TRANSLATION_DOMAIN },
+
 	{ (gchar*) OSMO_STOCK_ABOUT,                   (gchar*) N_("About"),                        0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CALENDAR,                (gchar*) N_("Calendar"),                     0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CLOSE,                   (gchar*) N_("Close"),                        0, 0, TRANSLATION_DOMAIN },
@@ -76,7 +78,6 @@ GtkStockItem osmo_stock_items[] = {
     { (gchar*) OSMO_STOCK_CONTACTS_EDIT,           (gchar*) N_("Edit contact"),                 0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CONTACTS_EXPORT,         (gchar*) N_("Export contacts"),              0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CONTACTS_IMPORT,         (gchar*) N_("Import contacts"),              0, 0, TRANSLATION_DOMAIN },
-    { (gchar*) OSMO_STOCK_CONTACTS_MAP_LOCATION,   (gchar*) N_("Contact map location"),         0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CONTACTS_REMOVE,         (gchar*) N_("Remove contact"),               0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_BUTTON_CONTACTS_EXPORT,  (gchar*) N_("Export"),                       0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_BUTTON_CONTACTS_IMPORT,  (gchar*) N_("Import"),                       0, 0, TRANSLATION_DOMAIN },
@@ -181,6 +182,8 @@ const guint8* osmo_stock_item_data[] = {
     (const guint8*) osmo_stock_backup,
     (const guint8*) osmo_stock_restore,
 
+	(const guint8*) osmo_stock_open_url,
+
 	(const guint8*) osmo_stock_about,
     (const guint8*) osmo_stock_calendar,
     (const guint8*) osmo_stock_close,
@@ -193,7 +196,6 @@ const guint8* osmo_stock_item_data[] = {
     (const guint8*) osmo_stock_contacts_edit,
     (const guint8*) osmo_stock_contacts_export,
     (const guint8*) osmo_stock_contacts_import,
-    (const guint8*) osmo_stock_contacts_map_location,
     (const guint8*) osmo_stock_contacts_remove,
     (const guint8*) osmo_stock_button_contacts_export,
     (const guint8*) osmo_stock_button_contacts_import,
