@@ -59,6 +59,8 @@
 #define     OSMO_STOCK_BACKUP                   "osmo-backup"
 #define     OSMO_STOCK_RESTORE                  "osmo-restore"
 
+#define     OSMO_STOCK_OPEN_URL                 "osmo-open-url"
+
 #define     OSMO_STOCK_ABOUT                    "osmo-about"
 #define     OSMO_STOCK_CALENDAR                 "osmo-calendar"
 #define     OSMO_STOCK_CLOSE                    "osmo-close"
@@ -68,7 +70,6 @@
 #define     OSMO_STOCK_CONTACTS_EDIT            "osmo-contacts-edit"
 #define     OSMO_STOCK_CONTACTS_EXPORT          "osmo-contacts-export"
 #define     OSMO_STOCK_CONTACTS_IMPORT          "osmo-contacts-import"
-#define     OSMO_STOCK_CONTACTS_MAP_LOCATION    "osmo-contacts-map_location"
 #define     OSMO_STOCK_CONTACTS_REMOVE          "osmo-contacts-remove"
 #define     OSMO_STOCK_CONTACTS                 "osmo-contacts"
 #define     OSMO_STOCK_EDIT_NOTE                "osmo-edit_note"
