@@ -36,6 +36,7 @@
 #include "tasks_utils.h"
 #include "utils.h"
 #include "utils_gui.h"
+#include "check_events.h"
 
 #ifdef TASKS_ENABLED
 
@@ -199,55 +200,14 @@ tasks_repeat_done (GtkTreeIter *iter, TASK_ITEM *item, GUI *appGUI)
 
 /*------------------------------------------------------------------------------*/
 
-void
-show_tasks_desc_panel (gboolean enable, GUI *appGUI)
-{
-	GtkTreeIter  iter;
-	GdkRectangle rect, visible_rect;
-	GtkTreePath  *visible_path;
-	GtkTreeModel *model;
-
-	if (enable == TRUE)
-	{
-		if (gtk_tree_selection_get_selected (appGUI->tsk->tasks_list_selection, &model, &iter))
-		{
-			gtk_paned_set_position (GTK_PANED (appGUI->tsk->tasks_paned), config.tasks_pane_pos);
-
-			while (g_main_context_iteration (NULL, FALSE));
-
-			visible_path = gtk_tree_model_get_path (model, &iter);
-
-			if (visible_path)
-			{
-				gtk_tree_view_get_cell_area (GTK_TREE_VIEW (appGUI->tsk->tasks_list), visible_path, NULL, &rect);
-				gtk_tree_view_get_visible_rect (GTK_TREE_VIEW (appGUI->tsk->tasks_list), &visible_rect);
-
-				if (rect.y < visible_rect.y || rect.y > visible_rect.y + visible_rect.height)
-					gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (appGUI->tsk->tasks_list), visible_path, NULL, TRUE, 0.5, 0.0);
-
-				gtk_tree_path_free (visible_path);
-			}
-		}
-		else
-			enable = FALSE;
-	}
-	else
-	{
-		config.tasks_pane_pos = gtk_paned_get_position (GTK_PANED (appGUI->tsk->tasks_paned));
-		if (!config.gui_layout)
-			gtk_paned_set_position (GTK_PANED (appGUI->tsk->tasks_paned), 99999);
-	}
-
-	appGUI->tsk->tasks_panel_status = enable;
-}
-
-/*------------------------------------------------------------------------------*/
-
 void
 panel_close_desc_cb (GtkWidget *widget, gpointer data)
 {
-	GUI *appGUI = (GUI *) data;
-	show_tasks_desc_panel (FALSE, appGUI);
+    GtkPaned *paned;
+    GUI *appGUI = (GUI *)data;
+
+    paned = GTK_PANED (appGUI->tsk->tasks_paned);
+    gtk_paned_set_position(paned, paned->max_position);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -256,6 +216,7 @@ void
 tasks_item_selected (GtkTreeSelection *selection, gpointer data)
 {
 	GtkTreeIter iter;
+	gint selection_size;
 	GtkTreeModel *model;
 	gchar *text;
 	guint32 start_date_julian, done_date_julian, due_date_julian;
@@ -280,11 +241,24 @@ tasks_item_selected (GtkTreeSelection *selection, gpointer data)
 	utl_gui_clear_text_buffer (text_buffer, &titer);
 #endif  /* HAVE_LIBWEBKIT */
 
-	if (gtk_tree_selection_get_selected (selection, &model, &iter))
+	selection_size = gtk_tree_selection_count_selected_rows(selection);
+	if (selection_size > 1)
+        {
+		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/edit"), FALSE);
+		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/delete"), TRUE);
+		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/prev_date"), FALSE);
+		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/next_date"), FALSE);
+
+#ifdef HAVE_LIBWEBKIT                
+		webkit_web_view_load_string (WEBKIT_WEB_VIEW (appGUI->tsk->html_webkitview), "", "text/html", "UTF-8", "file://");
+#endif  /* HAVE_LIBWEBKIT */
+        }
+        else if (selection_size == 1)
 	{
 		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/edit"), TRUE);
 		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/delete"), TRUE);
 
+                iter = utl_gui_get_first_selection_iter(selection, &model);
 		gtk_tree_model_get (model, &iter,
 		                    TA_COLUMN_DESCRIPTION, &text,
 		                    TA_COLUMN_DUE_DATE_JULIAN, &due_date_julian,
@@ -373,6 +347,10 @@ tasks_item_selected (GtkTreeSelection *selection, gpointer data)
 		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/delete"), FALSE);
 		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/prev_date"), FALSE);
 		gtk_widget_set_sensitive (gtk_ui_manager_get_widget (appGUI->tsk->tasks_uim_widget, "/toolbar/next_date"), FALSE);
+
+#ifdef HAVE_LIBWEBKIT                
+                webkit_web_view_load_string (WEBKIT_WEB_VIEW (appGUI->tsk->html_webkitview), "", "text/html", "UTF-8", "file://");
+#endif  /* HAVE_LIBWEBKIT */
 	}
 }
 
@@ -392,7 +370,7 @@ tasks_edit_item_cb (GtkWidget *widget, gpointer data)
 {
 	GUI *appGUI = (GUI *) data;
 
-	if (gtk_tree_selection_get_selected (appGUI->tsk->tasks_list_selection, NULL, NULL))
+	if (gtk_tree_selection_count_selected_rows(appGUI->tsk->tasks_list_selection) == 1)
 		tasks_add_edit_dialog_show (TRUE, appGUI->tsk->tasks_due_julian_day, appGUI->tsk->tasks_due_time, appGUI);
 }
 
@@ -402,44 +380,69 @@ void
 tasks_remove_item_cb (GtkWidget *widget, gpointer data)
 {
 	GUI *appGUI = (GUI *) data;
-	tasks_remove_dialog_show (appGUI->tsk->tasks_list, appGUI->tsk->tasks_list_store, appGUI);
+	tasks_remove_dialog_show (appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
 
 void
-task_modify_due_date (gint value, GUI *appGUI)
+task_modify_due_date (GtkTreeRowReference *ref, gint value, GUI *appGUI) {
+    GtkTreeIter iter, *e_iter;
+    guint32 due_date;
+    gint due_time;
+    guint id;
+    TASK_ITEM *item;
+    GtkTreePath *path;
+    GtkTreeModel *model;
+
+    model = gtk_tree_row_reference_get_model(ref);
+    path = gtk_tree_row_reference_get_path(ref);
+    if (path != NULL) {
+        if (gtk_tree_model_get_iter(model, &iter, path)) {
+            gtk_tree_model_get(model, &iter, TA_COLUMN_DUE_DATE_JULIAN, &due_date,
+                    TA_COLUMN_DUE_TIME, &due_time, TA_COLUMN_ID, &id, -1);
+
+            e_iter = tsk_get_iter(id, appGUI);
+            g_return_if_fail(e_iter != NULL);
+
+            item = tsk_get_item(e_iter, appGUI);
+            g_return_if_fail(item != NULL);
+
+            if (item->repeat == TRUE)
+                tasks_repeat_done(e_iter, item, appGUI);
+            else if (due_date != 0) {
+                due_date += value;
+                gtk_list_store_set(appGUI->tsk->tasks_list_store, e_iter,
+                        TA_COLUMN_COLOR, get_date_color(due_date, due_time, FALSE, appGUI),
+                        TA_COLUMN_DUE_DATE_JULIAN, due_date,
+                        TA_COLUMN_DUE_DATE, get_date_time_full_str(due_date, due_time), -1);
+            }
+            tsk_item_free(item);
+        }
+        gtk_tree_path_free(path);
+    }
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+tasks_increment_due_date (GtkTreeRowReference *ref, GUI *appGUI) {
+    task_modify_due_date(ref, 1, appGUI);
+}
+
+/*------------------------------------------------------------------------------*/
+void
+tasks_decrement_due_date (GtkTreeRowReference *ref, GUI *appGUI) {
+    task_modify_due_date(ref, -1, appGUI);
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+tasks_modify_due_date (GFunc modify_function, GUI *appGUI)
 {
-	GtkTreeIter iter, *e_iter;
-	GtkTreeModel *model;
-	guint32 due_date;
-	gint due_time, id;
-	TASK_ITEM *item;
-
-	if (gtk_tree_selection_get_selected (appGUI->tsk->tasks_list_selection, &model, &iter))
-	{
-		gtk_tree_model_get (model, &iter, TA_COLUMN_DUE_DATE_JULIAN, &due_date,
-		                    TA_COLUMN_DUE_TIME, &due_time, TA_COLUMN_ID, &id, -1);
-
-		e_iter = tsk_get_iter (id, appGUI);
-		g_return_if_fail (e_iter != NULL);
-
-		item = tsk_get_item (e_iter, appGUI);
-		g_return_if_fail (item != NULL);
-
-		if (item->repeat == TRUE)
-			tasks_repeat_done (e_iter, item, appGUI);
-		else
-		{
-			due_date += value;
-			gtk_list_store_set (appGUI->tsk->tasks_list_store, e_iter,
-			                    TA_COLUMN_COLOR, get_date_color (due_date, due_time, FALSE, appGUI),
-			                    TA_COLUMN_DUE_DATE_JULIAN, due_date,
-			                    TA_COLUMN_DUE_DATE, get_date_time_full_str (due_date, due_time), -1);
-		}
-
-		tsk_item_free (item);
-	}
+    utl_gui_foreach_selected(appGUI->tsk->tasks_list_selection, GTK_TREE_MODEL(appGUI->tsk->tasks_list_store),
+                modify_function, appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -448,7 +451,7 @@ void
 tasks_change_due_date_to_prev_date_cb (GtkWidget *widget, gpointer data)
 {
 	GUI *appGUI = (GUI *) data;
-	task_modify_due_date (-1, appGUI);
+	tasks_modify_due_date ((GFunc)tasks_decrement_due_date, appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -457,7 +460,7 @@ void
 tasks_change_due_date_to_next_date_cb (GtkWidget *widget, gpointer data)
 {
 	GUI *appGUI = (GUI *) data;
-	task_modify_due_date (1, appGUI);
+	tasks_modify_due_date ((GFunc)tasks_increment_due_date, appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -492,6 +495,7 @@ done_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer user_data)
 	gboolean done_status;
 	guint32 done_date, category;
 	GtkTreeModel *model;
+	guint id;
 
 	GUI *appGUI = (GUI *) user_data;
 	model = GTK_TREE_MODEL (appGUI->tsk->tasks_list_store);
@@ -511,7 +515,8 @@ done_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer user_data)
 			if (path != NULL)
 			{
 				gtk_tree_model_get_iter (model, &iter, path);   /* get toggled iter */
-				gtk_tree_model_get (model, &iter, TA_COLUMN_DONE, &done_status, -1);
+				gtk_tree_model_get (model, &iter, TA_COLUMN_DONE, &done_status,
+                                        TA_COLUMN_ID, &id, -1);
 
 				if (done_status == FALSE)
 					done_date = utl_date_get_current_julian ();
@@ -659,15 +664,10 @@ refresh_tasks (GUI *appGUI)
 void
 update_tasks_number (GUI *appGUI)
 {
-	GtkTreeIter iter;
 	gint i;
 	gchar tmpbuf[BUFFER_SIZE];
 
-	i = 0;
-
-	while (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (appGUI->tsk->tasks_filter), &iter, NULL, i++));
-
-	i--;
+	i = gtk_tree_model_iter_n_children (GTK_TREE_MODEL (appGUI->tsk->tasks_filter), NULL);
 
 	if (i > 0)
 	{
@@ -694,6 +694,26 @@ update_tasks_number (GUI *appGUI)
 
 }
 
+void
+task_list_row_changed_cb (GtkTreeModel *tree_model, GtkTreePath  *path, GtkTreeIter  *iter, GUI *appGUI)
+{
+    TASK_ITEM *item = tsk_get_item(iter, appGUI);
+    notify_task(item, appGUI);
+    tsk_item_free(item);
+}
+
+void
+task_filter_row_inserted_cb (GtkTreeModel *tree_model, GtkTreePath *path, GtkTreeIter *iter, gpointer user_data)
+{
+    update_tasks_number ((GUI *) user_data);
+}
+
+void
+task_filter_row_deleted_cb (GtkTreeModel *tree_model, GtkTreePath *path, gpointer user_data)
+{
+    update_tasks_number ((GUI *) user_data);
+}
+
 /*------------------------------------------------------------------------------*/
 
 guint
@@ -760,6 +780,7 @@ add_item_to_list (TASK_ITEM *item, GUI *appGUI)
 	                    TA_COLUMN_SUMMARY, item->summary,
 	                    TA_COLUMN_DESCRIPTION, item->desc,
 	                    TA_COLUMN_SOUND_ENABLE, item->sound_enable,
+	                    TA_COLUMN_NDIALOG_ENABLE, item->ndialog_enable,
 	                    TA_COLUMN_COLOR, get_date_color (item->due_date_julian, item->due_time, item->done, appGUI),
 	                    TA_COLUMN_ACTIVE, item->active,
 	                    TA_COLUMN_OFFLINE_IGNORE, item->offline_ignore,
@@ -799,17 +820,12 @@ list_dbclick_cb (GtkWidget * widget, GdkEventButton * event, gpointer data)
 
 	if ((event->type == GDK_2BUTTON_PRESS) && (event->button == 1))
 	{
-		if (appGUI->tsk->tasks_panel_status == TRUE)
-		{
-			if (config.add_edit == FALSE)
-				tasks_edit_item_cb (NULL, appGUI);
-			else
-				tasks_add_edit_dialog_show (FALSE, 0, utl_time_get_current_seconds (), appGUI);
-		}
-		else
-			show_tasks_desc_panel (TRUE, appGUI);
+                if (config.add_edit == FALSE)
+                        tasks_edit_item_cb (NULL, appGUI);
+                else
+                        tasks_add_edit_dialog_show (FALSE, 0, utl_time_get_current_seconds (), appGUI);
 
-		return TRUE;
+                return TRUE;
 	}
 
 	return FALSE;
@@ -820,114 +836,41 @@ list_dbclick_cb (GtkWidget * widget, GdkEventButton * event, gpointer data)
 gboolean
 tasks_list_filter_cb (GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
 {
-	gint done, idx;
-	gchar *category, *category_cf;
-	const gchar *text;
+	gchar *category;
 	gchar *value;
-	gint text_len, len, j;
+	gboolean done, result;
 
 	GUI *appGUI = (GUI *) data;
 
-	text = gtk_entry_get_text (GTK_ENTRY (appGUI->tsk->tasks_find_entry));
-
-	if (text == NULL)
-		return TRUE;
-
-	text_len = g_utf8_strlen (text, -1);
-
-	if (appGUI->tsk->tasks_filter_disabled == TRUE)
-		return TRUE;
-
 	gtk_tree_model_get (model, iter,
 	                    TA_COLUMN_DONE, &done,
 	                    TA_COLUMN_CATEGORY, &category,
 	                    TA_COLUMN_SUMMARY, &value, -1);
 
-	if (tsk_get_category_state (category, STATE_TASKS, appGUI) == FALSE)
-	{
-		g_free (category);
-		g_free (value);
-		return FALSE;
-	}
+    if (tsk_get_category_state(category, STATE_TASKS, appGUI) == FALSE) {
+        result = FALSE;
+    } else if (config.hide_completed && done == TRUE) {
+        result = FALSE;
+    } else if (appGUI->tsk->filter_index && (utl_gui_list_store_get_text_index(appGUI->opt->tasks_category_store, category) != appGUI->tsk->filter_index)) {
+        result = FALSE;
+    } else if (value == NULL) {
+        result = FALSE;
+    } else {
+        const gchar *text = gtk_entry_get_text(GTK_ENTRY(appGUI->tsk->tasks_find_entry));
 
-	category_cf = gtk_combo_box_get_active_text (GTK_COMBO_BOX (appGUI->tsk->cf_combobox));
-	idx = utl_gui_list_store_get_text_index (appGUI->opt->tasks_category_store, category_cf);
-	g_free (category_cf);
+        if (text == NULL) {
+            result = TRUE;
+        } else if (!g_utf8_strlen(text, -1)) {
+            result = TRUE;
+        } else {
+            result = utl_text_strcasestr(value, text);
+        }
+    }
+    
 
-	if (idx)
-	{
-		if (utl_gui_list_store_get_text_index (appGUI->opt->tasks_category_store, category) == idx)
-		{
-			if (config.hide_completed && done == TRUE)
-			{
-				g_free (category);
-				g_free (value);
-				return FALSE;
-			}
-
-			if (value != NULL)
-			{
-				len = g_utf8_strlen (value, -1) - text_len;
-
-				if (len >= 0)
-				{
-					for (j = 0; j <= len; j++)
-					{
-						if (!g_ascii_strncasecmp (g_utf8_casefold (text, -1), g_utf8_casefold (value + j, -1), text_len))
-						{
-							g_free (value);
-							g_free (category);
-							return TRUE;
-						}
-					}
-				}
-
-				g_free (value);
-			}
-
-			g_free (category);
-			return FALSE;
-
-		}
-		else
-		{
-			g_free (category);
-			g_free (value);
-			return FALSE;
-		}
-	}
-	else
-	{
-		if (config.hide_completed && done == TRUE)
-		{
-			g_free (category);
-			g_free (value);
-			return FALSE;
-		}
-
-		if (value != NULL)
-		{
-			len = g_utf8_strlen (value, -1) - text_len;
-
-			if (len >= 0)
-			{
-				for (j = 0; j <= len; j++)
-				{
-					if (!g_ascii_strncasecmp (g_utf8_casefold (text, -1), g_utf8_casefold (value + j, -1), text_len))
-					{
-						g_free (value);
-						g_free (category);
-						return TRUE;
-					}
-				}
-			}
-
-			g_free (value);
-		}
-	}
-
-	g_free (category);
-	return FALSE;
+    g_free(category);
+    g_free(value);
+    return result;
 }
 
 /*------------------------------------------------------------------------------*/
@@ -942,129 +885,103 @@ category_filter_cb (GtkComboBox *widget, gpointer data)
 	if (appGUI->tsk->filter_index != -1)
 	{
 		gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER (appGUI->tsk->tasks_filter));
-		update_tasks_number (appGUI);
 	}
 }
 
 /*------------------------------------------------------------------------------*/
-
 gint
-custom_tasks_sort_function (GtkTreeModel *model, GtkTreeIter *iter_a, GtkTreeIter *iter_b, gpointer user_data)
+tasks_column_sort_function (GtkTreeModel *model, GtkTreeIter *iter_a, GtkTreeIter *iter_b, gpointer user_data)
 {
-	gint done_a, done_b, done_s;
-	gchar *priority_a, *priority_b;
-	gint priority_s;
-	guint32 due_date_a, due_date_b, due_date_s;
-	gint due_time_a, due_time_b, due_time_s;
+    gboolean done_a, done_b;
+    gchar *priority_a, *priority_b;
+    guint32 due_date_a, due_date_b;
+    gint due_time_a, due_time_b;
+    gboolean repeat_a, repeat_b;
+    gchar *summary_a, *summary_b;
+    gchar *category_a, *category_b;
+    gint diff;
+    gint sort_column = GPOINTER_TO_INT(user_data);
 
-	if (iter_a == NULL || iter_b == NULL)
-		return 0;
+    if (iter_a == NULL || iter_b == NULL) {
+        return 0;
+    }
 
-	gtk_tree_model_get (model, iter_a,
-	                    TA_COLUMN_DONE, &done_a,
+    switch(sort_column) {
+        case TA_COLUMN_DUE_DATE:
+            gtk_tree_model_get (model, iter_a,
 	                    TA_COLUMN_DUE_TIME, &due_time_a,
-	                    TA_COLUMN_DUE_DATE_JULIAN, &due_date_a,
-	                    TA_COLUMN_PRIORITY, &priority_a, -1);
+	                    TA_COLUMN_DUE_DATE_JULIAN, &due_date_a, -1);
 
-	gtk_tree_model_get (model, iter_b,
-	                    TA_COLUMN_DONE, &done_b,
+            gtk_tree_model_get (model, iter_b,
 	                    TA_COLUMN_DUE_TIME, &due_time_b,
-	                    TA_COLUMN_DUE_DATE_JULIAN, &due_date_b,
-	                    TA_COLUMN_PRIORITY, &priority_b, -1);
-
-	done_s = done_b - done_a;
-
-	if (!due_date_a)
+	                    TA_COLUMN_DUE_DATE_JULIAN, &due_date_b, -1);
+            if (!due_date_a)
 		due_date_a = 1 << 31;
 
-	if (!due_date_b)
+            if (!due_date_b)
 		due_date_b = 1 << 31;
+            diff = utl_date_time_compare_js(due_date_a, due_time_a, due_date_b, due_time_b);
+            break;
+        case TA_COLUMN_PRIORITY:
+            gtk_tree_model_get (model, iter_a,
+	                    TA_COLUMN_PRIORITY, &priority_a, -1);
 
-	due_date_s = due_date_b - due_date_a;
-	due_time_s = due_time_b - due_time_a;
-	priority_s = tsk_get_priority_index (priority_a) - tsk_get_priority_index (priority_b);
-	g_free (priority_a);
-	g_free (priority_b);
+            gtk_tree_model_get (model, iter_b,
+	                    TA_COLUMN_PRIORITY, &priority_b, -1);
+            diff = tsk_get_priority_index (priority_a) - tsk_get_priority_index (priority_b);
+            g_free (priority_a);
+            g_free (priority_b);
+            break;
+        case TA_COLUMN_DONE:
+            gtk_tree_model_get (model, iter_a,
+	                    TA_COLUMN_DONE, &done_a, -1);
 
-	switch (config.tasks_sorting_mode)
-	{
-		/* Done, Due Date, Priority */
-		case 0:
-			if (done_s !=0)
-				return done_s;
-			if (due_date_s == 0 && due_time_s != 0)
-				return due_time_s;
-			if (due_date_s != 0)
-				return due_date_s;
-			if (priority_s != 0)
-				return priority_s;
-			break;
+            gtk_tree_model_get (model, iter_b,
+	                    TA_COLUMN_DONE, &done_b, -1);
+            diff = done_a - done_b;
+            break;
+        case TA_COLUMN_TYPE:
+            gtk_tree_model_get (model, iter_a,
+	                    TA_COLUMN_REPEAT, &repeat_a, -1);
 
-		/* Done, Priority, Due Date */
-		case 1:
-			if (done_s !=0)
-				return done_s;
-			if (priority_s != 0)
-				return priority_s;
-			if (due_date_s == 0 && due_time_s != 0)
-				return due_time_s;
-			if (due_date_s != 0)
-				return due_date_s;
-			break;
+            gtk_tree_model_get (model, iter_b,
+	                    TA_COLUMN_REPEAT, &repeat_b, -1);
+            diff = repeat_a - repeat_b;
+            break;
+        case TA_COLUMN_SUMMARY:
+            gtk_tree_model_get (model, iter_a,
+	                    TA_COLUMN_SUMMARY, &summary_a, -1);
 
-		/* Priority, Due Date, Done */
-		case 2:
-			if (priority_s != 0)
-				return priority_s;
-			if (due_date_s == 0 && due_time_s != 0)
-				return due_time_s;
-			if (due_date_s != 0)
-				return due_date_s;
-			if (done_s !=0)
-				return done_s;
-			break;
+            gtk_tree_model_get (model, iter_b,
+	                    TA_COLUMN_SUMMARY, &summary_b, -1);
+            diff = utl_text_strcmp(summary_a, summary_b);
+            g_free (summary_a);
+            g_free (summary_b);
+            break;
+        case TA_COLUMN_CATEGORY:
+            gtk_tree_model_get (model, iter_a,
+	                    TA_COLUMN_CATEGORY, &category_a, -1);
 
-		/* Priority, Done, Due Date */
-		case 3:
-			if (priority_s != 0)
-				return priority_s;
-			if (done_s !=0)
-				return done_s;
-			if (due_date_s == 0 && due_time_s != 0)
-				return due_time_s;
-			if (due_date_s != 0)
-				return due_date_s;
-			break;
+            gtk_tree_model_get (model, iter_b,
+	                    TA_COLUMN_CATEGORY, &category_b, -1);
+            diff = utl_text_strcmp(category_a, category_b);
+            g_free (category_a);
+            g_free (category_b);
+            break;
+        default:
+            diff = 0;
+    }
+    return diff;
+}
 
-		/* Due Date, Priority, Done */
-		case 4:
-			if (due_date_s == 0 && due_time_s != 0)
-				return due_time_s;
-			if (due_date_s != 0)
-				return due_date_s;
-			if (priority_s != 0)
-				return priority_s;
-			if (done_s !=0)
-				return done_s;
-			break;
+/*------------------------------------------------------------------------------*/
 
-		/* Due Date, Done, Priority */
-		case 5:
-			if (due_date_s == 0 && due_time_s != 0)
-				return due_time_s;
-			if (due_date_s != 0)
-				return due_date_s;
-			if (done_s !=0)
-				return done_s;
-			if (priority_s != 0)
-				return priority_s;
-			break;
+void tasks_sort_column_changed_cb (GtkTreeSortable *sortable, gpointer user_data)
+{
+    GtkSortType sort_order;
 
-		default:
-			break;
-	}
-
-	return 0;
+    gtk_tree_sortable_get_sort_column_id(sortable, &config.tasks_sorting_column, &sort_order);
+    config.tasks_sorting_order = sort_order;
 }
 
 /*------------------------------------------------------------------------------*/
@@ -1213,7 +1130,7 @@ set_tasks_columns_width (GUI *appGUI)
 /*------------------------------------------------------------------------------*/
 
 gboolean
-tasks_search_entry_changed_cb (GtkWidget *widget, GdkEventKey *event, gpointer user_data)
+tasks_search_entry_changed_cb (GtkEditable *editable, gpointer user_data)
 {
 	GtkTreePath *path;
 	GtkTreeIter iter;
@@ -1238,8 +1155,6 @@ tasks_search_entry_changed_cb (GtkWidget *widget, GdkEventKey *event, gpointer u
 			}
 		}
 	}
-		
-	update_tasks_number (appGUI);
 
 	return FALSE;
 }
@@ -1280,6 +1195,13 @@ button_restore_backup_cb (GtkWidget *widget, GUI *appGUI)
 
 /*------------------------------------------------------------------------------*/
 
+void
+tasks_paned_position_change_cb (GObject *gobject, GParamSpec *pspec, GUI *appGUI)
+{
+    config.tasks_pane_pos = gtk_paned_get_position (GTK_PANED (appGUI->tsk->tasks_paned));
+}
+/*------------------------------------------------------------------------------*/
+
 void
 gui_create_tasks (GUI *appGUI)
 {
@@ -1417,13 +1339,11 @@ gui_create_tasks (GUI *appGUI)
 
 	/*-------------------------------------------------------------------------------------*/
 
-	if (!config.gui_layout)
-	{
-		appGUI->tsk->tasks_paned = gtk_vpaned_new ();
-		gtk_paned_set_position (GTK_PANED (appGUI->tsk->tasks_paned), 99999);
-	}
-	else
+	if (!config.gui_layout) {
+	    appGUI->tsk->tasks_paned = gtk_vpaned_new ();
+	} else {
 	    appGUI->tsk->tasks_paned = gtk_hpaned_new ();
+        }
 
 	gtk_widget_show (appGUI->tsk->tasks_paned);
 	gtk_box_pack_start (GTK_BOX (vbox1), appGUI->tsk->tasks_paned, TRUE, TRUE, 0);
@@ -1499,13 +1419,13 @@ gui_create_tasks (GUI *appGUI)
 	appGUI->tsk->tasks_find_entry = gtk_entry_new ();
 	gtk_entry_set_max_length (GTK_ENTRY (appGUI->tsk->tasks_find_entry), 128);
 	gtk_widget_show (appGUI->tsk->tasks_find_entry);
-	g_signal_connect (G_OBJECT (appGUI->tsk->tasks_find_entry), "key_release_event",
+	g_signal_connect (G_OBJECT (appGUI->tsk->tasks_find_entry), "changed",
 	                  G_CALLBACK (tasks_search_entry_changed_cb), appGUI);
 	gtk_table_attach (GTK_TABLE (table), appGUI->tsk->tasks_find_entry, 1, 4, 1, 2,
 	                  (GtkAttachOptions) (GTK_FILL),
 	                  (GtkAttachOptions) (0), 0, 0);
 
-	appGUI->tsk->tasks_find_clear_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_CLEAR, FALSE);
+	appGUI->tsk->tasks_find_clear_button = utl_gui_create_button (GTK_STOCK_CLEAR, OSMO_STOCK_BUTTON_CLEAR, FALSE);
 	gtk_widget_show (appGUI->tsk->tasks_find_clear_button);
 	GTK_WIDGET_UNSET_FLAGS (appGUI->tsk->tasks_find_clear_button, GTK_CAN_FOCUS);
 	gtk_button_set_relief (GTK_BUTTON(appGUI->tsk->tasks_find_clear_button), GTK_RELIEF_NONE);
@@ -1530,18 +1450,51 @@ gui_create_tasks (GUI *appGUI)
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (appGUI->tsk->scrolled_win), GTK_SHADOW_IN);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (appGUI->tsk->scrolled_win), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
-	appGUI->tsk->tasks_list_store = gtk_list_store_new (TASKS_NUM_COLUMNS,
-	                                    G_TYPE_BOOLEAN, GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_INT,
-	                                    G_TYPE_UINT, G_TYPE_UINT, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
-	                                    G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_BOOLEAN,
-	                                    G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_INT,
-	                                    G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT,
-	                                    G_TYPE_INT, G_TYPE_STRING, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT);
+	appGUI->tsk->tasks_list_store = gtk_list_store_new (TASKS_NUM_COLUMNS,          /* columns are defined in gui.h */
+	                                    G_TYPE_BOOLEAN,     /* TA_COLUMN_DONE */
+										GDK_TYPE_PIXBUF,    /* TA_COLUMN_TYPE */
+										G_TYPE_STRING,      /* TA_COLUMN_DUE_DATE */
+										G_TYPE_UINT,        /* TA_COLUMN_DUE_DATE_JULIAN */
+										G_TYPE_INT,         /* TA_COLUMN_DUE_TIME */
+	                                    G_TYPE_UINT,        /* TA_COLUMN_START_DATE_JULIAN */
+										G_TYPE_UINT,        /* TA_COLUMN_DONE_DATE_JULIAN */
+										G_TYPE_STRING,      /* TA_COLUMN_PRIORITY */
+										G_TYPE_STRING,      /* TA_COLUMN_CATEGORY */
+										G_TYPE_STRING,      /* TA_COLUMN_SUMMARY */
+	                                    G_TYPE_STRING,      /* TA_COLUMN_DESCRIPTION */
+										G_TYPE_STRING,      /* TA_COLUMN_COLOR */
+										G_TYPE_UINT,        /* TA_COLUMN_BOLD */
+										G_TYPE_BOOLEAN,     /* TA_COLUMN_ACTIVE */
+	                                    G_TYPE_BOOLEAN,     /* TA_COLUMN_OFFLINE_IGNORE */
+	                                    G_TYPE_BOOLEAN,     /* TA_COLUMN_SOUND_ENABLE */
+										G_TYPE_BOOLEAN,     /* TA_COLUMN_NDIALOG_ENABLE */
+										G_TYPE_BOOLEAN,     /* TA_COLUMN_REPEAT */
+										G_TYPE_INT,         /* TA_COLUMN_REPEAT_DAY */
+	                                    G_TYPE_INT,         /* TA_COLUMN_REPEAT_MONTH_INTERVAL */
+										G_TYPE_INT,         /* TA_COLUMN_REPEAT_DAY_INTERVAL */
+										G_TYPE_INT,         /* TA_COLUMN_REPEAT_START_DAY */
+										G_TYPE_INT,         /* TA_COLUMN_REPEAT_TIME_START */
+										G_TYPE_INT,         /* TA_COLUMN_REPEAT_TIME_END */
+										G_TYPE_INT,         /* TA_COLUMN_REPEAT_TIME_INTERVAL */
+	                                    G_TYPE_INT,         /* TA_COLUMN_REPEAT_COUNTER */
+										G_TYPE_STRING,      /* TA_COLUMN_ALARM_COMMAND */
+										G_TYPE_INT,         /* TA_COLUMN_WARNING_DAYS */
+										G_TYPE_INT,         /* TA_COLUMN_WARNING_TIME */
+										G_TYPE_INT,         /* TA_COLUMN_POSTPONE_TIME */
+										G_TYPE_INT          /* TA_COLUMN_ID */
+									);
+
+	g_signal_connect (G_OBJECT (appGUI->tsk->tasks_list_store), "row-changed",
+	                  G_CALLBACK (task_list_row_changed_cb), appGUI);
 
 	appGUI->tsk->tasks_filter = gtk_tree_model_filter_new (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), NULL);
 	gtk_tree_model_filter_set_visible_func (GTK_TREE_MODEL_FILTER (appGUI->tsk->tasks_filter),
 	                                        (GtkTreeModelFilterVisibleFunc) tasks_list_filter_cb,
 	                                        appGUI, NULL);
+	g_signal_connect (G_OBJECT (appGUI->tsk->tasks_filter), "row-inserted",
+	                  G_CALLBACK (task_filter_row_inserted_cb), appGUI);
+	g_signal_connect (G_OBJECT (appGUI->tsk->tasks_filter), "row-deleted",
+	                  G_CALLBACK (task_filter_row_deleted_cb), appGUI);
 
 	appGUI->tsk->tasks_sort = gtk_tree_model_sort_new_with_model (GTK_TREE_MODEL (appGUI->tsk->tasks_filter));
 
@@ -1557,6 +1510,7 @@ gui_create_tasks (GUI *appGUI)
 	                  G_CALLBACK (list_dbclick_cb), appGUI);
 
 	appGUI->tsk->tasks_list_selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (appGUI->tsk->tasks_list));
+	gtk_tree_selection_set_mode (appGUI->tsk->tasks_list_selection, GTK_SELECTION_MULTIPLE);
 	tasks_selection_activate (TRUE, appGUI);
 
 	/* create columns */
@@ -1732,6 +1686,14 @@ gui_create_tasks (GUI *appGUI)
 	gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_SOUND_ENABLE], FALSE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_SOUND_ENABLE]);
 
+	renderer = gtk_cell_renderer_toggle_new ();
+	appGUI->tsk->tasks_columns[TA_COLUMN_NDIALOG_ENABLE] = gtk_tree_view_column_new_with_attributes (NULL,
+	                         renderer,
+	                         "active", TA_COLUMN_NDIALOG_ENABLE,
+	                         NULL);
+	gtk_tree_view_column_set_visible (appGUI->tsk->tasks_columns[TA_COLUMN_NDIALOG_ENABLE], FALSE);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[TA_COLUMN_NDIALOG_ENABLE]);
+
 	renderer = gtk_cell_renderer_toggle_new ();
 	appGUI->tsk->tasks_columns[TA_COLUMN_REPEAT] = gtk_tree_view_column_new_with_attributes (NULL,
 	                         renderer,
@@ -1874,15 +1836,17 @@ gui_create_tasks (GUI *appGUI)
 	gtk_tree_view_set_enable_search (GTK_TREE_VIEW (appGUI->tsk->tasks_list), FALSE);
 
 	/* configure sorting */
-	gtk_tree_sortable_set_sort_func ((GtkTreeSortable *) appGUI->tsk->tasks_sort, 0,
-	                                 (GtkTreeIterCompareFunc) custom_tasks_sort_function, NULL, NULL);
+        for (i = 0; i < MAX_VISIBLE_TASK_COLUMNS; i++) {
+            gtk_tree_view_column_set_sort_column_id (appGUI->tsk->tasks_columns[ta_columns[i]], ta_columns[i]);
+            gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (appGUI->tsk->tasks_sort), ta_columns[i],
+                    tasks_column_sort_function, GINT_TO_POINTER(ta_columns[i]), NULL);
+        }
 
-	gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable * )appGUI->tsk->tasks_sort,
-	                                      TA_COLUMN_DUE_DATE, config.tasks_sorting_order);
-	gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable *) appGUI->tsk->tasks_sort,
-	                                      TA_COLUMN_PRIORITY, config.tasks_sorting_order);
-	gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable * )appGUI->tsk->tasks_sort,
-	                                      TA_COLUMN_DONE, config.tasks_sorting_order);
+        /* restore sorting */
+        gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE (appGUI->tsk->tasks_sort),
+                config.tasks_sorting_column, config.tasks_sorting_order);
+
+        g_signal_connect (appGUI->tsk->tasks_sort, "sort-column-changed", G_CALLBACK (tasks_sort_column_changed_cb), appGUI);
 
 	/*----------------------------------------------------------------------------*/
 
@@ -1906,11 +1870,7 @@ gui_create_tasks (GUI *appGUI)
 	gtk_box_pack_start (GTK_BOX (appGUI->tsk->panel_hbox), label, FALSE, FALSE, 0);
 
 	if (!config.gui_layout) {
-		if (config.default_stock_icons) {
-			close_button = utl_gui_stock_button(GTK_STOCK_CLOSE, FALSE);
-		} else {
-			close_button = utl_gui_stock_button(OSMO_STOCK_BUTTON_CLOSE, FALSE);
-		}
+		close_button = utl_gui_create_button(GTK_STOCK_CLOSE, OSMO_STOCK_BUTTON_CLOSE, FALSE);
 		GTK_WIDGET_UNSET_FLAGS(close_button, GTK_CAN_FOCUS);
 		gtk_button_set_relief (GTK_BUTTON(close_button), GTK_RELIEF_NONE);
 		if (config.enable_tooltips) {
@@ -1936,6 +1896,7 @@ gui_create_tasks (GUI *appGUI)
 	webkit_web_view_set_settings (appGUI->tsk->html_webkitview, appGUI->tsk->webkit_settings);
 	webkit_web_view_set_editable (appGUI->tsk->html_webkitview, FALSE);
 
+    g_signal_connect (appGUI->tsk->html_webkitview, "console-message", G_CALLBACK (utl_webkit_console_msg), appGUI);
 	g_signal_connect (appGUI->tsk->html_webkitview, "populate-popup", G_CALLBACK (utl_webkit_on_menu), appGUI);
 	g_signal_connect (appGUI->tsk->html_webkitview, "navigation-policy-decision-requested", G_CALLBACK (utl_webkit_link_clicked), appGUI);
 
@@ -1957,12 +1918,12 @@ gui_create_tasks (GUI *appGUI)
 	appGUI->tsk->font_tag_object = gtk_text_buffer_create_tag (text_buffer, "info_font", "font", (gchar *) config.task_info_font, NULL);
 #endif  /* HAVE_LIBWEBKIT */
 
-	if (config.gui_layout)
-	    gtk_paned_set_position (GTK_PANED (appGUI->tsk->tasks_paned), config.tasks_pane_pos);
+	g_signal_connect(G_OBJECT(appGUI->tsk->tasks_paned), "notify::position", G_CALLBACK(tasks_paned_position_change_cb), appGUI);
+	gtk_paned_set_position (GTK_PANED (appGUI->tsk->tasks_paned), config.tasks_pane_pos);
 
 	gtk_widget_grab_focus (appGUI->tsk->tasks_find_entry);
 }
 
-/*------------------------------------------------------------------------------*/
 
+/*------------------------------------------------------------------------------*/
 #endif  /* TASKS_ENABLED */
