@@ -38,27 +38,6 @@
 
 /*------------------------------------------------------------------------------*/
 
-void
-tsk_delete_notify (guint id, GUI *appGUI)
-{
-#ifdef HAVE_LIBNOTIFY
-	GSList *node;
-	TASK_NTF *a;
-
-	for (node = appGUI->tsk->notifications; node != NULL; node = node->next) {
-		a = (TASK_NTF *) node->data;
-		if (a->id == id) {
-			notify_notification_close (a->notify, NULL);
-			appGUI->tsk->notifications = g_slist_remove (appGUI->tsk->notifications, a);
-			g_free (a);
-			break;
-		}
-	}
-#endif /* HAVE_LIBNOTIFY */
-}
-
-/*------------------------------------------------------------------------------*/
-
 void
 tasks_item_entered_cb (GtkWidget *widget, gpointer data) {
 
@@ -123,6 +102,7 @@ gchar tmpbuf[BUFFER_SIZE];
 
 	item->active = TRUE;
 	item->sound_enable = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->tsk->checkb_sound_enable));
+	item->ndialog_enable = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->tsk->checkb_ndialog_enable));
 
     item->repeat = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->tsk->rt_enable_checkbutton));
     item->offline_ignore = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (appGUI->tsk->ignore_alarm_checkbutton));
@@ -177,13 +157,12 @@ gchar tmpbuf[BUFFER_SIZE];
 
 #ifdef HAVE_LIBNOTIFY
 	if (appGUI->tsk->tasks_edit_state)
-		tsk_delete_notify (id, appGUI);
+		notify_task_delete (id, appGUI);
 #endif /* HAVE_LIBNOTIFY */
     add_item_to_list (item, appGUI);
     gui_systray_tooltip_update(appGUI);
 
     gtk_widget_destroy (appGUI->tsk->tasks_add_window);
-    update_tasks_number (appGUI);
     tasks_select_first_position_in_list (appGUI);
     g_signal_emit_by_name (G_OBJECT(appGUI->cal->calendar), "day-selected");
 	refresh_tasks (appGUI);
@@ -203,6 +182,7 @@ static void
 tasks_date_related_set_state (gboolean state, GUI *appGUI)
 {
 	gtk_widget_set_sensitive (appGUI->tsk->checkb_sound_enable, state);
+	gtk_widget_set_sensitive (appGUI->tsk->checkb_ndialog_enable, state);
 	gtk_widget_set_sensitive (appGUI->tsk->aw_days_spinbutton, state);
 	gtk_widget_set_sensitive (appGUI->tsk->aw_hours_spinbutton, state);
 	gtk_widget_set_sensitive (appGUI->tsk->aw_minutes_spinbutton, state);
@@ -500,22 +480,14 @@ TIME *tm;
     g_signal_connect (G_OBJECT (nodate_button), "clicked",
                         G_CALLBACK (nodate_calendar_cb), appGUI);
 
-    if (config.default_stock_icons) {
-        ok_button = utl_gui_stock_button (GTK_STOCK_OK, FALSE);
-    } else {
-        ok_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_OK, FALSE);
-    }
+    ok_button = utl_gui_create_button (GTK_STOCK_OK, OSMO_STOCK_BUTTON_OK, FALSE);
     gtk_button_set_relief (GTK_BUTTON (ok_button), GTK_RELIEF_NONE);
     gtk_widget_show (ok_button);
     gtk_box_pack_end (GTK_BOX (hbox1), ok_button, FALSE, FALSE, 0);
     g_signal_connect (G_OBJECT (ok_button), "clicked",
                         G_CALLBACK (button_ok_calendar_cb), appGUI);
 
-    if (config.default_stock_icons) {
-        close_button = utl_gui_stock_button (GTK_STOCK_CANCEL, FALSE);
-    } else {
-        close_button = utl_gui_stock_button (OSMO_STOCK_BUTTON_CANCEL, FALSE);
-    }
+    close_button = utl_gui_create_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, FALSE);
     GTK_WIDGET_UNSET_FLAGS (close_button, GTK_CAN_FOCUS);
     gtk_button_set_relief (GTK_BUTTON (close_button), GTK_RELIEF_NONE);
     gtk_widget_show (close_button);
@@ -589,58 +561,60 @@ tasks_add_edit_summary_changed_cb (GtkEditable *editable, gpointer data) {
     }
     gtk_widget_set_sensitive (appGUI->tsk->tasks_ok_button, appGUI->tsk->tasks_accept_state);
 }
+
 /*------------------------------------------------------------------------------*/
 
 void
-tasks_remove_dialog_show (GtkWidget *list, GtkListStore *list_store, GUI *appGUI) {
+tasks_remove(GtkTreeRowReference *ref, GUI *appGUI) {
+    GtkTreePath *path;
+    GtkTreeIter iter, filter_iter, sort_iter;
+    guint id;
+    GtkTreeModel *model;
 
-gint response;
-GtkTreePath *sort_path, *filter_path, *path;
-GtkTreeIter iter;
-gchar tmpbuf[BUFFER_SIZE];
-guint id;
+    model = gtk_tree_row_reference_get_model(ref);
+    path = gtk_tree_row_reference_get_path(ref);
+    if (path != NULL) {
+        if (gtk_tree_model_get_iter(model, &sort_iter, path)) {
+            gtk_tree_model_get(model, &sort_iter,
+                    TA_COLUMN_ID, &id, -1);
 
-    gtk_tree_view_get_cursor (GTK_TREE_VIEW (list), &sort_path, NULL);
-
-    if (sort_path != NULL) {
-
-        filter_path = gtk_tree_model_sort_convert_path_to_child_path (GTK_TREE_MODEL_SORT(appGUI->tsk->tasks_sort), sort_path);
-
-        if (filter_path != NULL) {
-
-            path = gtk_tree_model_filter_convert_path_to_child_path (GTK_TREE_MODEL_FILTER(appGUI->tsk->tasks_filter), filter_path);
-
-            if (path != NULL) {
-
-                sprintf (tmpbuf, "%s\n\n%s", _("Selected task will be removed."), _("Are you sure?"));
-
-                response = utl_gui_create_dialog (GTK_MESSAGE_QUESTION, tmpbuf, GTK_WINDOW(appGUI->main_window));
-
-                if (response == GTK_RESPONSE_YES) {
-                    gtk_tree_model_get_iter (GTK_TREE_MODEL(list_store), &iter, path);
-                    gtk_tree_model_get (GTK_TREE_MODEL (appGUI->tsk->tasks_list_store), &iter,
-                                        TA_COLUMN_ID, &id, -1);
 #ifdef HAVE_LIBNOTIFY
-                    tsk_delete_notify (id, appGUI);
+            notify_task_delete(id, appGUI);
 #endif /* HAVE_LIBNOTIFY */
-                    gtk_list_store_remove (list_store, &iter);
-                    gtk_tree_path_free (path);
-                    tasks_select_first_position_in_list (appGUI);
-                    update_tasks_number (appGUI);
-                    g_signal_emit_by_name (G_OBJECT(appGUI->cal->calendar), "day-selected");
-                    gui_systray_tooltip_update (appGUI);
-                    if (config.save_data_after_modification) {
-                        write_tasks_entries (appGUI);
-                    }
-                }
-            }
+            gtk_tree_model_sort_convert_iter_to_child_iter(GTK_TREE_MODEL_SORT(model), &filter_iter, &sort_iter);
+            gtk_tree_model_filter_convert_iter_to_child_iter(GTK_TREE_MODEL_FILTER(gtk_tree_model_sort_get_model(GTK_TREE_MODEL_SORT(model))), &iter, &filter_iter);
 
-            gtk_tree_path_free (filter_path);
+            gtk_list_store_remove(appGUI->tsk->tasks_list_store, &iter);
         }
-
-        gtk_tree_path_free (sort_path);
+        gtk_tree_path_free(path);
     }
+}
 
+/*------------------------------------------------------------------------------*/
+
+void
+tasks_remove_dialog_show (GUI *appGUI) {
+
+    gint response;
+    gchar tmpbuf[BUFFER_SIZE];
+ 
+    sprintf(tmpbuf, "%s\n\n%s", _("Selected task will be removed."), _("Are you sure?"));
+
+    response = utl_gui_create_dialog(GTK_MESSAGE_QUESTION, tmpbuf, GTK_WINDOW(appGUI->main_window));
+
+    if (response == GTK_RESPONSE_YES) {
+        tasks_selection_activate (FALSE, appGUI);
+        utl_gui_foreach_selected(appGUI->tsk->tasks_list_selection, GTK_TREE_MODEL(appGUI->tsk->tasks_list_store),
+                (GFunc)tasks_remove, appGUI);
+        tasks_selection_activate (TRUE, appGUI);
+
+        tasks_select_first_position_in_list(appGUI);
+        g_signal_emit_by_name(G_OBJECT(appGUI->cal->calendar), "day-selected");
+        gui_systray_tooltip_update(appGUI);
+        if (config.save_data_after_modification) {
+            write_tasks_entries(appGUI);
+        }
+    }
 }
 
 /*------------------------------------------------------------------------------*/
@@ -657,10 +631,10 @@ recurrent_task_enable_cb (GtkToggleButton *togglebutton, gpointer user_data) {
 /*------------------------------------------------------------------------------*/
 
 gint
-alarm_cmd_entry_key_release_cb (GtkWidget *widget, GdkEventKey *event, gpointer user_data)
+alarm_cmd_entry_changed_cb (GtkEditable *editable, gpointer user_data)
 {
 	GUI *appGUI = (GUI *) user_data;
-    utl_gui_update_command_status (appGUI->tsk->alarm_cmd_entry, appGUI->tsk->alarm_cmd_valid_image, appGUI);
+    utl_gui_update_command_status (GTK_EDITABLE(appGUI->tsk->alarm_cmd_entry), appGUI->tsk->alarm_cmd_valid_image, appGUI);
 
 	return FALSE;
 }
@@ -670,7 +644,7 @@ alarm_cmd_entry_key_release_cb (GtkWidget *widget, GdkEventKey *event, gpointer
 void
 tasks_add_edit_dialog_show (gboolean tasks_edit_mode, guint32 julian_date, gint time, GUI *appGUI) {
 
-GtkWidget *hbox1, *hbox2;
+GtkWidget *hbox1, *hbox2, *hbox3;
 GtkWidget *vbox0, *vbox1, *vbox2, *vbox3, *vbox4;
 GtkWidget *vbox5, *vbox6;
 GtkWidget *label;
@@ -698,9 +672,9 @@ GtkObject *rt_dp_day_spinbutton_adj;
 GtkObject *rt_dp_month_spinbutton_adj;
 GtkObject *repeat_counter_spinbutton_adj;
 GtkObject *spinbutton_adjustment;
-GtkTreeIter iter;
+GtkTreeIter iter, filter_iter, sort_iter;
+GtkTreeModel *model;
 GtkTextIter titer;
-GtkTreePath *sort_path, *filter_path, *path;
 GtkTextBuffer *text_buffer;
 TASK_ITEM *item;
 gchar tmpbuf[BUFFER_SIZE];
@@ -896,12 +870,22 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_container_add (GTK_CONTAINER (frame), alignment);
     gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 12, 0);
 
+    hbox3 = gtk_hbox_new (FALSE, 0);
+    gtk_widget_show (hbox3);
+    gtk_container_add (GTK_CONTAINER (alignment), hbox3);
+
     appGUI->tsk->checkb_sound_enable = gtk_check_button_new_with_mnemonic (_("Enable sound notification"));
     gtk_widget_show (appGUI->tsk->checkb_sound_enable);
-    gtk_container_add (GTK_CONTAINER (alignment), appGUI->tsk->checkb_sound_enable);
+    gtk_box_pack_start (GTK_BOX (hbox3), appGUI->tsk->checkb_sound_enable, TRUE, TRUE, 0);
     gtk_widget_set_sensitive (appGUI->tsk->checkb_sound_enable, FALSE);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->checkb_sound_enable), TRUE);
 
+	appGUI->tsk->checkb_ndialog_enable = gtk_check_button_new_with_mnemonic (_("Enable notification dialog"));
+    gtk_widget_show (appGUI->tsk->checkb_ndialog_enable);
+    gtk_box_pack_start (GTK_BOX (hbox3), appGUI->tsk->checkb_ndialog_enable, TRUE, TRUE, 0);
+    gtk_widget_set_sensitive (appGUI->tsk->checkb_ndialog_enable, FALSE);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->checkb_ndialog_enable), TRUE);
+
     g_snprintf (tmpbuf, BUFFER_SIZE, "<b>%s:</b>", _("Options"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
@@ -1059,8 +1043,8 @@ gchar tmpbuf[BUFFER_SIZE];
     appGUI->tsk->alarm_cmd_entry = gtk_entry_new ();
     gtk_widget_show (appGUI->tsk->alarm_cmd_entry);
     gtk_box_pack_start (GTK_BOX (hbox1), appGUI->tsk->alarm_cmd_entry, TRUE, TRUE, 0);
-    g_signal_connect (G_OBJECT (appGUI->tsk->alarm_cmd_entry), "key_release_event",
-                      G_CALLBACK (alarm_cmd_entry_key_release_cb), appGUI);
+    g_signal_connect (G_OBJECT (appGUI->tsk->alarm_cmd_entry), "changed",
+                      G_CALLBACK (alarm_cmd_entry_changed_cb), appGUI);
     appGUI->tsk->alarm_cmd_valid_image = gtk_image_new();
     gtk_widget_show (appGUI->tsk->alarm_cmd_valid_image);
     gtk_box_pack_start (GTK_BOX (hbox1), appGUI->tsk->alarm_cmd_valid_image, FALSE, FALSE, 0);
@@ -1430,13 +1414,13 @@ gchar tmpbuf[BUFFER_SIZE];
     gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox), GTK_BUTTONBOX_END);
     gtk_box_set_spacing (GTK_BOX (hbuttonbox), 16);
 
-	cancel_button = utl_gui_create_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
+	cancel_button = utl_gui_create_labeled_button (GTK_STOCK_CANCEL, OSMO_STOCK_BUTTON_CANCEL, _("Cancel"));
     gtk_widget_show (cancel_button);
     gtk_container_add (GTK_CONTAINER (hbuttonbox), cancel_button);
 	g_signal_connect (cancel_button, "clicked",
 	                  G_CALLBACK (button_tasks_add_edit_window_close_cb), appGUI);
 
-	appGUI->tsk->tasks_ok_button = utl_gui_create_button (GTK_STOCK_OK, OSMO_STOCK_BUTTON_OK, _("OK"));
+	appGUI->tsk->tasks_ok_button = utl_gui_create_labeled_button (GTK_STOCK_OK, OSMO_STOCK_BUTTON_OK, _("OK"));
     gtk_widget_show (appGUI->tsk->tasks_ok_button);
     gtk_container_add (GTK_CONTAINER (hbuttonbox), appGUI->tsk->tasks_ok_button);
 	g_signal_connect (appGUI->tsk->tasks_ok_button, "clicked",
@@ -1460,132 +1444,113 @@ gchar tmpbuf[BUFFER_SIZE];
 
         /* fill gui fields */
 
-        gtk_tree_view_get_cursor (GTK_TREE_VIEW (appGUI->tsk->tasks_list), &sort_path, NULL);
-
         text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW(appGUI->tsk->desc_textview));
         utl_gui_clear_text_buffer (GTK_TEXT_BUFFER(text_buffer), &titer);
 
-        if (sort_path != NULL) {
+        sort_iter = utl_gui_get_first_selection_iter(appGUI->tsk->tasks_list_selection, &model);
+        gtk_tree_model_sort_convert_iter_to_child_iter(GTK_TREE_MODEL_SORT(appGUI->tsk->tasks_sort), &filter_iter, &sort_iter);
+        gtk_tree_model_filter_convert_iter_to_child_iter(GTK_TREE_MODEL_FILTER(appGUI->tsk->tasks_filter), &iter, &filter_iter);
 
-            filter_path = gtk_tree_model_sort_convert_path_to_child_path (GTK_TREE_MODEL_SORT(appGUI->tsk->tasks_sort), sort_path);
+  
+        item = tsk_get_item (&iter, appGUI);
 
-            if (filter_path != NULL) {
+        if (item != NULL) {
 
-                path = gtk_tree_model_filter_convert_path_to_child_path (GTK_TREE_MODEL_FILTER(appGUI->tsk->tasks_filter), filter_path);
-
-                if (path != NULL) {
-
-                    gtk_tree_model_get_iter(GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, path);
-
-                    item = tsk_get_item (&iter, appGUI);
-
-                    if (item != NULL) {
-
-                        appGUI->tsk->tasks_due_julian_day = item->due_date_julian;
-                        appGUI->tsk->tasks_due_time = item->due_time;
+            appGUI->tsk->tasks_due_julian_day = item->due_date_julian;
+            appGUI->tsk->tasks_due_time = item->due_time;
 
 
-                        gtk_entry_set_text (GTK_ENTRY (appGUI->tsk->due_date_entry),
-						                               get_date_time_full_str (item->due_date_julian, item->due_time));
-                        gtk_entry_set_text(GTK_ENTRY(appGUI->tsk->summary_entry), item->summary);
+            gtk_entry_set_text (GTK_ENTRY (appGUI->tsk->due_date_entry),
+                                                                   get_date_time_full_str (item->due_date_julian, item->due_time));
+            gtk_entry_set_text(GTK_ENTRY(appGUI->tsk->summary_entry), item->summary);
 
-						gtk_combo_box_set_active (GTK_COMBO_BOX (appGUI->tsk->category_combobox),
-						                          utl_gui_list_store_get_text_index (appGUI->opt->tasks_category_store, 
-																					 item->category));
-						gtk_combo_box_set_active (GTK_COMBO_BOX (appGUI->tsk->priority_combobox),
-						                          tsk_get_priority_index (item->priority));
+                                    gtk_combo_box_set_active (GTK_COMBO_BOX (appGUI->tsk->category_combobox),
+                                                              utl_gui_list_store_get_text_index (appGUI->opt->tasks_category_store, 
+                                                                                                                                                             item->category));
+                                    gtk_combo_box_set_active (GTK_COMBO_BOX (appGUI->tsk->priority_combobox),
+                                                              tsk_get_priority_index (item->priority));
 
-                        gtk_text_buffer_get_iter_at_offset(GTK_TEXT_BUFFER(text_buffer), &titer, 0);
+            gtk_text_buffer_get_iter_at_offset(GTK_TEXT_BUFFER(text_buffer), &titer, 0);
 
-                        if (item->desc != NULL) {
-                            gtk_text_buffer_insert(text_buffer, &titer, item->desc, -1);
-                            gtk_text_view_set_buffer(GTK_TEXT_VIEW(appGUI->tsk->desc_textview), text_buffer);
-                        }
-
-                        if (item->due_date_julian != 0) {
-
-                            tasks_date_related_set_state (TRUE, appGUI);
-
-                            if (item->due_time != -1) {
-                                tasks_time_related_set_state (TRUE, appGUI);
-                            } else {
-                                tasks_time_related_set_state (FALSE, appGUI);
-                            }
-
-							gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->aw_days_spinbutton),
-							                           item->warning_days);
-							gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->aw_hours_spinbutton),
-							                           item->warning_time / 60);
-							gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->aw_minutes_spinbutton),
-							                           item->warning_time % 60);
-							gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->postpone_spinbutton),
-							                           item->postpone_time);
-							gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->rt_start_hour_spinbutton),
-							                           item->repeat_time_start / 60);
-							gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->rt_start_minute_spinbutton),
-							                           item->repeat_time_start % 60);
-
-							gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->rt_end_hour_spinbutton),
-							                           item->repeat_time_end / 60);
-							gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->rt_end_minute_spinbutton),
-							                           item->repeat_time_end % 60);
-
-							gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->rt_interval_hour_spinbutton),
-							                           item->repeat_time_interval / 60);
-							gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->rt_interval_minute_spinbutton),
-							                           item->repeat_time_interval % 60);
-
-							gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->rt_enable_checkbutton),
-							                              item->repeat);
-							gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->ignore_alarm_checkbutton),
-							                              item->offline_ignore);
-							gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->checkb_sound_enable),
-							                              item->sound_enable);
-
-                            if (item->alarm_command) {
-                                gtk_entry_set_text(GTK_ENTRY(appGUI->tsk->alarm_cmd_entry), item->alarm_command);
-                                utl_gui_update_command_status (appGUI->tsk->alarm_cmd_entry, 
-															   appGUI->tsk->alarm_cmd_valid_image, appGUI);
-                            }
-
-                            gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->rt_dp_day_spinbutton), 
-													   item->repeat_day_interval);
-                            gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->rt_dp_month_spinbutton), 
-													   item->repeat_month_interval);
-                            gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->repeat_counter_spinbutton), 
-													   item->repeat_counter);
-
-                            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->dp_1_checkbutton), 
-														  item->repeat_day & 1);
-                            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->dp_2_checkbutton), 
-														  item->repeat_day & 2);
-                            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->dp_3_checkbutton), 
-														  item->repeat_day & 4);
-                            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->dp_4_checkbutton), 
-														  item->repeat_day & 8);
-                            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->dp_5_checkbutton), 
-														  item->repeat_day & 16);
-                            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->dp_6_checkbutton), 
-														  item->repeat_day & 32);
-                            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->dp_7_checkbutton), 
-														  item->repeat_day & 64);
-
-                        }
-
-                        tsk_item_free (item);
-
-                    }
-
-                    gtk_tree_path_free(path);
-
-                }
-
-                gtk_tree_path_free(filter_path);
+            if (item->desc != NULL) {
+                gtk_text_buffer_insert(text_buffer, &titer, item->desc, -1);
+                gtk_text_view_set_buffer(GTK_TEXT_VIEW(appGUI->tsk->desc_textview), text_buffer);
             }
 
-            gtk_tree_path_free(sort_path);
-        }
+            if (item->due_date_julian != 0) {
 
+                tasks_date_related_set_state (TRUE, appGUI);
+
+                if (item->due_time != -1) {
+                    tasks_time_related_set_state (TRUE, appGUI);
+                } else {
+                    tasks_time_related_set_state (FALSE, appGUI);
+                }
+
+                                            gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->aw_days_spinbutton),
+                                                                       item->warning_days);
+                                            gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->aw_hours_spinbutton),
+                                                                       item->warning_time / 60);
+                                            gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->aw_minutes_spinbutton),
+                                                                       item->warning_time % 60);
+                                            gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->postpone_spinbutton),
+                                                                       item->postpone_time);
+                                            gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->rt_start_hour_spinbutton),
+                                                                       item->repeat_time_start / 60);
+                                            gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->rt_start_minute_spinbutton),
+                                                                       item->repeat_time_start % 60);
+
+                                            gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->rt_end_hour_spinbutton),
+                                                                       item->repeat_time_end / 60);
+                                            gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->rt_end_minute_spinbutton),
+                                                                       item->repeat_time_end % 60);
+
+                                            gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->rt_interval_hour_spinbutton),
+                                                                       item->repeat_time_interval / 60);
+                                            gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->rt_interval_minute_spinbutton),
+                                                                       item->repeat_time_interval % 60);
+
+                                            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->rt_enable_checkbutton),
+                                                                          item->repeat);
+                                            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->ignore_alarm_checkbutton),
+                                                                          item->offline_ignore);
+                                            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->checkb_sound_enable),
+                                                                          item->sound_enable);
+                                            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->checkb_ndialog_enable),
+                                                                          item->ndialog_enable);
+
+                if (item->alarm_command) {
+                    gtk_entry_set_text(GTK_ENTRY(appGUI->tsk->alarm_cmd_entry), item->alarm_command);
+                    utl_gui_update_command_status (GTK_EDITABLE(appGUI->tsk->alarm_cmd_entry), 
+                                                                                                               appGUI->tsk->alarm_cmd_valid_image, appGUI);
+                }
+
+                gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->rt_dp_day_spinbutton), 
+                                                                                               item->repeat_day_interval);
+                gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->rt_dp_month_spinbutton), 
+                                                                                               item->repeat_month_interval);
+                gtk_spin_button_set_value (GTK_SPIN_BUTTON (appGUI->tsk->repeat_counter_spinbutton), 
+                                                                                               item->repeat_counter);
+
+                gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->dp_1_checkbutton), 
+                                                                                                      item->repeat_day & 1);
+                gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->dp_2_checkbutton), 
+                                                                                                      item->repeat_day & 2);
+                gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->dp_3_checkbutton), 
+                                                                                                      item->repeat_day & 4);
+                gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->dp_4_checkbutton), 
+                                                                                                      item->repeat_day & 8);
+                gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->dp_5_checkbutton), 
+                                                                                                      item->repeat_day & 16);
+                gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->dp_6_checkbutton), 
+                                                                                                      item->repeat_day & 32);
+                gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (appGUI->tsk->dp_7_checkbutton), 
+                                                                                                      item->repeat_day & 64);
+
+            }
+
+            tsk_item_free (item);
+        }
     }
 
     gtk_widget_set_sensitive(appGUI->tsk->tasks_ok_button, appGUI->tsk->tasks_accept_state);
@@ -1710,6 +1675,7 @@ gint tasks_version;
 						item->summary = NULL;
 						item->desc = NULL;
 						item->sound_enable = TRUE;
+						item->ndialog_enable = TRUE;
 						priority_n = MEDIUM_PRIORITY;
 
 						while (cnode != NULL) {
@@ -1734,6 +1700,7 @@ gint tasks_version;
 							utl_xml_get_int ("warning_time", &(item->warning_time), cnode);
 							utl_xml_get_int ("postpone_time", &(item->postpone_time), cnode);
 							utl_xml_get_int ("sound_enable", &(item->sound_enable), cnode);
+							utl_xml_get_int ("notification_dialog_enable", &(item->ndialog_enable), cnode);
 							utl_xml_get_int ("priority", &priority_n, cnode);
 							utl_xml_get_str ("alarm_command", &(item->alarm_command), cnode);
 							utl_xml_get_str ("category", &(item->category), cnode);
@@ -1871,6 +1838,7 @@ xmlChar *escaped;
 			utl_xml_put_int ("warning_time", item->warning_time, note_node);
 			utl_xml_put_int ("postpone_time", item->postpone_time, note_node);
 			utl_xml_put_int ("sound_enable", item->sound_enable, note_node);
+			utl_xml_put_int ("notification_dialog_enable", item->ndialog_enable, note_node);
 			utl_xml_put_int ("priority", tsk_get_priority_index (gettext (item->priority)), note_node);
 			utl_xml_put_str ("alarm_command", item->alarm_command, note_node, doc);
 			utl_xml_put_str ("category", item->category, note_node, doc);
