@@ -70,7 +70,7 @@ gint count, i;
 
     g_strfreev (tokens);
 
-    o_links_1_text = utl_text_replace (output, REGEX_HTML, "<a href=\"\\0\">\\0</a>");
+    o_links_1_text = utl_text_replace (output, REGEX_URL, "<a href=\"\\0\">\\0</a>");
     g_free (output);
 
     o_links_2_text = utl_text_replace (o_links_1_text, REGEX_EMAIL, "<a href=\"mailto:\\0\">\\0</a>");
@@ -154,6 +154,15 @@ utl_text_match (const gchar *text, const gchar *regex) {
 
 #ifdef HAVE_LIBWEBKIT
 
+gboolean
+utl_webkit_console_msg (WebKitWebView *web_view,
+						gchar         *message,
+						gint           line,
+						gchar         *source_id,
+						gpointer       user_data) {
+	return TRUE; /* stop other handlers */
+}
+
 void
 utl_webkit_on_menu (WebKitWebView *view, GtkMenu *menu) {
     /* don't show popup menus */
@@ -274,7 +283,7 @@ guint n_pairs = G_N_ELEMENTS (html_tags) / 2;
                           
     output = utl_strconcat (output, "</body></html>", NULL);
 
-    o_links_1_text = utl_text_replace (output, REGEX_HTML, "<a href=\"\\0\">\\0</a>");
+    o_links_1_text = utl_text_replace (output, REGEX_URL, "<a href=\"\\0\">\\0</a>");
     g_free (output);
 
     o_links_2_text = utl_text_replace (o_links_1_text, REGEX_EMAIL, "<a href=\"mailto:\\0\">\\0</a>");
@@ -612,20 +621,15 @@ utl_xml_get_char (gchar *name, gchar *cname, xmlNodePtr node)
 void
 utl_xml_get_str (gchar *name, gchar **sname, xmlNodePtr node)
 {
-    xmlParserCtxtPtr context;
-    xmlChar *key, *out;
+    xmlChar *key;
 
     if ((xmlStrcmp (node->name, (const xmlChar *) name)) == 0) {
 
         key = xmlNodeGetContent (node->xmlChildrenNode);
-        context = xmlCreateDocParserCtxt (key);
-        out = (xmlChar*) xmlStringDecodeEntities (context, key, XML_SUBSTITUTE_REF, 0, 0, 0);
-        xmlFreeParserCtxt (context);
-        xmlFree (key);
 
-        if (out != NULL) {
-            *sname = g_strdup ((gchar *) out);
-            xmlFree (out);
+        if (key != NULL) {
+            *sname = g_strdup ((gchar *) key);
+            xmlFree (key);
         }
     }
 }
@@ -635,20 +639,15 @@ utl_xml_get_str (gchar *name, gchar **sname, xmlNodePtr node)
 void
 utl_xml_get_strn (gchar *name, gchar *sname, gint buffer_size, xmlNodePtr node)
 {
-    xmlParserCtxtPtr context;
-    xmlChar *key, *out;
+    xmlChar *key;
 
     if ((xmlStrcmp (node->name, (const xmlChar *) name)) == 0) {
 
         key = xmlNodeGetContent (node->xmlChildrenNode);
-        context = xmlCreateDocParserCtxt (key);
-        out = (xmlChar*) xmlStringDecodeEntities (context, key, XML_SUBSTITUTE_REF, 0, 0, 0);
-        xmlFreeParserCtxt (context);
-        xmlFree (key);
 
-        if (out != NULL) {
-            g_strlcpy (sname, (gchar *) out, buffer_size);
-            xmlFree (out);
+        if (key != NULL) {
+            g_strlcpy (sname, (gchar *) key, buffer_size);
+            xmlFree (key);
         }
     }
 }
@@ -681,12 +680,9 @@ void
 utl_xml_put_char (gchar *name, gchar character, xmlNodePtr node, xmlDocPtr doc)
 {
     gchar buffer[32];
-    xmlChar *escaped;
 
     g_snprintf (buffer, 32, "%c", character);
-    escaped = xmlEncodeSpecialChars(doc, (const xmlChar *) buffer);
-    xmlNewTextChild (node, NULL, (const xmlChar *) name, (xmlChar *) escaped);
-    xmlFree (escaped);
+    xmlNewTextChild (node, NULL, (const xmlChar *) name, (xmlChar *) buffer);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -694,11 +690,7 @@ utl_xml_put_char (gchar *name, gchar character, xmlNodePtr node, xmlDocPtr doc)
 void
 utl_xml_put_str (gchar *name, gchar *string, xmlNodePtr node, xmlDocPtr doc)
 {
-    xmlChar *escaped;
-
-    escaped = xmlEncodeSpecialChars(doc, (const xmlChar *) string);
-    xmlNewTextChild (node, NULL, (const xmlChar *) name, (xmlChar *) escaped);
-    xmlFree (escaped);
+    xmlNewTextChild (node, NULL, (const xmlChar *) name, (xmlChar *) string);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -707,13 +699,10 @@ void
 utl_xml_put_strn (gchar *name, gchar *string, gint buffer_size, xmlNodePtr node, xmlDocPtr doc)
 {
     gchar buffer[BUFFER_SIZE];
-    xmlChar *escaped;
 
     if (buffer_size > BUFFER_SIZE) buffer_size = BUFFER_SIZE;
     g_snprintf (buffer, buffer_size, "%s", string);
-    escaped = xmlEncodeSpecialChars(doc, (const xmlChar *) buffer);
-    xmlNewTextChild (node, NULL, (const xmlChar *) name, (xmlChar *) escaped);
-    xmlFree (escaped);
+    xmlNewTextChild (node, NULL, (const xmlChar *) name, (xmlChar *) buffer);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -927,3 +916,148 @@ va_list arguments;
 
 /*------------------------------------------------------------------------------*/
 
+gint
+utl_text_strcmp (const gchar *string1, const gchar *string2) {
+    if (string1 == NULL && string2 == NULL) {
+        return 0;
+    } if (string1 == NULL) {
+        return -1;
+    } else if (string2 == NULL) {
+        return 1;
+    } else {
+        return g_utf8_collate(string1, string2);
+    }
+}
+
+/*------------------------------------------------------------------------------*/
+
+static gboolean
+find_substring(const gchar *haystack, const gchar *needle, gboolean case_sensitive) {
+    gint window_len, text_len, i, diff;
+    gchar *window_start, *window_end, *casefold1, *casefold2;
+
+    window_len = g_utf8_strlen(needle, -1);
+    if (window_len == 0) {
+        return TRUE;
+    }
+    text_len = g_utf8_strlen(haystack, -1);
+    if (text_len == 0) {
+        return FALSE;
+    }
+    if(case_sensitive == TRUE) {
+        casefold1 = g_strdup(needle);
+    } else {
+        casefold1 = g_utf8_casefold(needle, -1);
+    }
+    for (i = 0; i <= text_len - window_len; i++) {
+        window_start = g_utf8_offset_to_pointer(haystack, i);
+        window_end = g_utf8_offset_to_pointer(haystack, i + window_len);
+        if(case_sensitive == TRUE) {
+            casefold2 = g_strndup(window_start, window_end - window_start);
+        } else {
+            casefold2 = g_utf8_casefold(window_start, window_end - window_start);
+        }
+        diff = g_utf8_collate(casefold1, casefold2);
+        g_free(casefold2);
+        if (!diff) {
+            g_free(casefold1);
+            return TRUE;
+        }
+    }
+    g_free(casefold1);
+    return FALSE;
+}
+
+/*------------------------------------------------------------------------------*/
+
+gboolean
+utl_text_strcasestr(const gchar *haystack, const gchar *needle) {
+    return find_substring(haystack, needle, FALSE);
+}
+
+/*------------------------------------------------------------------------------*/
+
+gboolean
+utl_text_strstr(const gchar *haystack, const gchar *needle) {
+    return find_substring(haystack, needle, TRUE);
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+utl_free_list (GList *list, GDestroyNotify free_func) {
+#if GLIB_CHECK_VERSION(2, 28, 0)
+    g_list_free_full(list, free_func);
+#else
+    GList *l;
+    for (l = list; l; l = l->next) {
+        free_func(l->data);
+    }
+    g_list_free(list);
+#endif
+}
+
+/*------------------------------------------------------------------------------*/
+
+#ifdef HAVE_LIBWEBKIT
+void
+utl_webkit_load_cb(WebKitWebView *view, GParamSpec *pspec, GUI *appGUI) {
+    WebKitLoadStatus load_status;
+    GtkAdjustment *scroll_adjustment;
+    g_object_get(view, "load-status", &load_status, NULL);
+    if (load_status == WEBKIT_LOAD_PROVISIONAL) {
+        scroll_adjustment = gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(appGUI->cal->day_info_scrolledwindow));
+        appGUI->cal->html_scroll_position = gtk_adjustment_get_value(scroll_adjustment);
+    } else if (load_status == WEBKIT_LOAD_FINISHED) {
+        /* process pending events, wait till the end of drawing of the webview */
+        while (gtk_events_pending()) {
+            gtk_main_iteration();
+        }
+        scroll_adjustment = gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(appGUI->cal->day_info_scrolledwindow));
+        gtk_adjustment_set_value(scroll_adjustment, appGUI->cal->html_scroll_position);
+    }
+}
+#endif  /* HAVE_LIBWEBKIT */
+
+/*------------------------------------------------------------------------------*/
+
+gint
+utl_open_count_url_links (gchar *text, gboolean url_count) {
+
+GRegex *regex;
+GMatchInfo *match_info;
+gchar url_path[PATH_MAX], command[PATH_MAX];
+gchar *URL;
+gint k = 0;
+
+	regex = g_regex_new (REGEX_URL, 0, 0, NULL);
+	g_regex_match (regex, text, 0, &match_info);
+
+    url_path[0] = '\0';
+
+	while (g_match_info_matches (match_info)) {
+
+		if (url_count == FALSE) {
+	  		URL = g_match_info_fetch (match_info, 0);
+            strcat (url_path, "\"");
+            strcat (url_path, URL);
+            strcat (url_path, "\" ");
+			g_free (URL);
+		} 
+		k++;
+		g_match_info_next (match_info, NULL);
+	}
+	
+	if (url_count == FALSE) {
+        sprintf (command, config.web_browser, url_path);
+        utl_run_command (command, FALSE);
+    }
+
+	g_match_info_free (match_info);
+	g_regex_unref (regex);
+
+	return k;
+}
+
+/*------------------------------------------------------------------------------*/
+
