@@ -32,7 +32,7 @@ enum helpers {
     SOUND
 };
 
-#define     REGEX_HTML      "(http|ftp|https):\\/\\/[\\w\\-_]+(\\.[\\w\\-_]+)+([\\w\\-\\.,@?^=\%&amp;:/~\\+#]*[\\w\\-\\@?^=\%&amp;/~\\+#])?"
+#define     REGEX_URL       "(http|ftp|https):\\/\\/[\\w\\-_]+(\\.[\\w\\-_]+)+([\\w\\-\\.,@?^=\%&amp;:/~\\+#]*[\\w\\-\\@?^=\%&amp;/~\\+#])?"
 #define     REGEX_URI_PROTO "\\b((http|ftp|https):\\/\\/|(mailto|javascript):)"
 #define     REGEX_EMAIL     "(\\w[-._\\w]*\\w@\\w[-._\\w]*\\w\\.\\w{2,3})"
 
@@ -41,6 +41,9 @@ gboolean    utl_text_match                      (const gchar *text, const gchar
 gchar *     utl_text_to_html_page               (const gchar *text, const gchar *font_family, 
                                                  const gchar *background_color, const gchar *text_color,
                                                  const gchar *header_html, const gchar *top_html, const gchar *bottom_html);
+gint        utl_text_strcmp                     (const gchar *string1, const gchar *string2);
+gboolean    utl_text_strcasestr                 (const gchar *haystack, const gchar *needle);
+gboolean    utl_text_strstr                     (const gchar *haystack, const gchar *needle);
 gchar *     utl_text_to_html                    (const gchar *text, gboolean ignoreBR, gboolean ignoreSP);
 gchar *     utl_get_day_name                    (guint day, gboolean short_name);
 gchar *     utl_get_julian_day_name             (guint32 julian);
@@ -82,14 +85,23 @@ gchar *     utl_text_with_tags_to_html          (gchar *input_text);
 void        utl_play_alarm_sound                (guint repetitions);
 gchar *     utl_add_timestamp_to_filename       (gchar *filename, gchar *extension);
 gchar *     utl_strconcat                       (gchar *string, ...);
+void        utl_free_list                       (GList *list, GDestroyNotify free_func);
 
 #ifdef HAVE_LIBWEBKIT
+gboolean    utl_webkit_console_msg              (WebKitWebView *web_view,
+												 gchar         *message,
+												 gint           line,
+												 gchar         *source_id,
+												 gpointer       user_data);
 void        utl_webkit_on_menu                  (WebKitWebView *view, GtkMenu *menu);
 gboolean    utl_webkit_link_clicked             (WebKitWebView *view, WebKitWebFrame *frame,
                                                  WebKitNetworkRequest *request, 
                                                  WebKitWebNavigationAction *navigation_action,
                                                  WebKitWebPolicyDecision *policy_decision);
+void        utl_webkit_load_cb                  (WebKitWebView *view, GParamSpec *pspec, GUI *appGUI);
 #endif  /* HAVE_LIBWEBKIT */
 
+gint        utl_open_count_url_links            (gchar *text, gboolean url_count);
+
 #endif /* _UTILS_H */
 
