@@ -62,15 +62,25 @@ utl_gui_create_window (const gchar *name, gint width, gint height, GUI *appGUI)
 /* ========================================================================= */
 
 GtkWidget *
-utl_gui_create_button (const gchar *gtk_name, const gchar *osmo_name, gchar *label)
+utl_gui_create_labeled_button(const gchar *gtk_name, const gchar *osmo_name, gchar *label)
 {
-	if (config.default_stock_icons) {
-        return gtk_button_new_from_stock (gtk_name);
-	} else {
-		return utl_gui_stock_name_button (osmo_name, label);
-	}
+    if (config.default_stock_icons) {
+        return gtk_button_new_from_stock(gtk_name);
+    } else {
+        return utl_gui_stock_name_button(osmo_name, label);
+    }
+}
 
-	/*return utl_gui_stock_name_button (config.default_stock_icons ? gtk_name : osmo_name, label);*/
+/* ========================================================================= */
+
+GtkWidget *
+utl_gui_create_button (const gchar *gtk_name, const gchar *osmo_name, gboolean toggle)
+{
+    if (config.default_stock_icons) {
+        return utl_gui_stock_button (gtk_name, toggle);
+    } else {
+        return utl_gui_stock_button (osmo_name, toggle);
+    }
 }
 
 /* ========================================================================= */
@@ -670,15 +680,15 @@ gint response = -1;
 /*------------------------------------------------------------------------------*/
 
 void
-utl_gui_update_command_status (GtkWidget *entry_widget, GtkWidget *icon_widget, GUI *appGUI) {
+utl_gui_update_command_status (GtkEditable *editable, GtkWidget *icon_widget, GUI *appGUI) {
 
 GdkPixbuf *image;
 gchar *cmd;
 gint i;
 
-    if (strlen(gtk_entry_get_text(GTK_ENTRY(entry_widget)))) {
+    if (strlen(gtk_editable_get_chars(editable, 0, -1))) {
 
-        cmd = g_strdup(gtk_entry_get_text(GTK_ENTRY(entry_widget)));
+        cmd = g_strdup(gtk_editable_get_chars(editable, 0, -1));
 
         for (i=0; i < strlen(cmd); i++) {
             if (cmd[i] == ' ') cmd[i] = 0;
@@ -842,7 +852,7 @@ GtkWidget *label;
     if (image)
         gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, TRUE, 0);
 
-	label = gtk_label_new (blabel);
+    label = gtk_label_new (blabel);
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, TRUE, 0);
 
     gtk_widget_show_all (alignment);
@@ -1108,3 +1118,30 @@ utl_gui_url_setup (GSList **links_list, gint *link_index, GtkWidget *textview, G
 
 /*------------------------------------------------------------------------------*/
 
+void
+utl_gui_foreach_selected(GtkTreeSelection *selection, GtkTreeModel *model, GFunc foreach_function, gpointer user_data) {
+    GList *selected_rows, *selected_refs, *l;
+
+    selected_rows = gtk_tree_selection_get_selected_rows(selection, &model);
+    for (l = selected_rows, selected_refs = NULL; l; l = l->next) {
+        selected_refs = g_list_prepend(selected_refs, gtk_tree_row_reference_new(model, (GtkTreePath *) l->data));
+    }
+    g_list_foreach(selected_refs, foreach_function, user_data);
+
+    utl_free_list(selected_rows, (GDestroyNotify) gtk_tree_path_free);
+    utl_free_list(selected_refs, (GDestroyNotify) gtk_tree_row_reference_free);
+}
+/*------------------------------------------------------------------------------*/
+GtkTreeIter
+utl_gui_get_first_selection_iter(GtkTreeSelection *selection, GtkTreeModel **model) {
+    GtkTreeIter iter;
+    GList *selected_rows;
+
+    selected_rows = gtk_tree_selection_get_selected_rows(selection, model);
+    gtk_tree_model_get_iter(*model, &iter, selected_rows->data);
+
+    utl_free_list(selected_rows, (GDestroyNotify) gtk_tree_path_free);
+    return iter;
+}
+/*------------------------------------------------------------------------------*/
+
