@@ -39,9 +39,32 @@ enum {
     SW_MOVE_DOWN
 };
 
+#define     VBOX_SPACING              8
+#define     HBOX_SPACING              8
+#define     ALIGNMENT_PADDING_TOP     4
+#define     ALIGNMENT_PADDING_RIGHT   4
+#define     ALIGNMENT_PADDING_BOTTOM  4
+#define     ALIGNMENT_PADDING_LEFT   12
+#define     CHECKBOX_PADDING          0
+#define     WINDOW_BORDER             8
+#define     BORDER_WIDTH              8
+
 #define     COLOR_BG_OK     "#fff77a"
 #define     COLOR_BG_FAIL   "#ff7770"
 
+#define     TAG                       (0xe000)
+
+GtkWidget * utl_gui_create_label                    (const gchar *format, const gchar *name);
+GtkWidget * utl_gui_create_window                   (const gchar *name, gint width, gint height, GUI *appGUI);
+GtkWidget * utl_gui_create_labeled_button           (const gchar *gtk_name, const gchar *osmo_name, gchar *label);
+GtkWidget * utl_gui_create_button                   (const gchar *gtk_name, const gchar *osmo_name, gboolean toggle);
+GtkWidget * utl_gui_create_frame                    (GtkWidget *container, const gchar *name);
+GtkWidget * utl_gui_create_vbox_in_frame            (GtkWidget *container, const gchar *name);
+GtkWidget * utl_gui_create_hbox_in_frame            (GtkWidget *container, const gchar *name);
+GtkWidget * utl_gui_create_table_in_frame           (GtkWidget *container, const gchar *name, guint rows, guint columns);
+GtkWidget * utl_gui_create_icon_with_label          (const gchar *stock_id, const gchar *label_str);
+GtkWidget * utl_gui_insert_in_scrolled_window       (GtkWidget *widget, GtkShadowType type);
+
 void        utl_gui_font_select_cb                  (GtkWidget *widget, gpointer user_data);
 gint        utl_gui_get_sw_vscrollbar_width         (GtkWidget *scrolled_window);
 void        utl_gui_sw_vscrollbar_move_position     (GtkWidget *scrolled_window, gint direction);
@@ -62,7 +85,7 @@ void        utl_gui_change_bg_widget_state          (GtkWidget *widget, gchar *c
 GdkPixbuf*  utl_gui_create_color_swatch             (gchar *color);
 
 void        utl_gui_fill_iconlabel                  (GtkWidget *dialog, gchar *stock_icon, gchar *message);
-void        utl_gui_update_command_status           (GtkWidget *entry_widget, GtkWidget *icon_widget, GUI *appGUI);
+void        utl_gui_update_command_status           (GtkEditable *editable, GtkWidget *icon_widget, GUI *appGUI);
 
 gint        utl_gui_create_dialog                   (gint dialog_type, gchar *message, GtkWindow *parent);
 gint        utl_gui_check_overwrite_file            (gchar *filename, GtkWidget *window, GUI *appGUI);
@@ -75,12 +98,15 @@ GtkWidget*  utl_gui_stock_label_radio_button        (gchar *label, const gchar *
 GtkWidget*  utl_gui_image_label_radio_button        (gchar *label, const guint8 *pix);
 
 void        utl_gui_url_initialize                  (GUI *appGUI);
-void        utl_gui_url_setup                       (GSList *links_list, gint *link_index, GtkWidget *textview,
+void        utl_gui_url_setup                       (GSList **links_list, gint *link_index, GtkWidget *textview,
                                                      GUI *appGUI);
-void        utl_gui_url_insert_link                 (GSList *links_list, gint *link_index, GtkWidget *textview,
+void        utl_gui_url_insert_link                 (GSList **links_list, gint *link_index, GtkWidget *textview,
                                                      GtkTextIter *iter, gchar *color, gchar *font, gchar *text,
                                                      gboolean center, GUI *appGUI);
-void        utl_gui_url_remove_links                (GSList *links_list, gint *link_index);
+void        utl_gui_url_remove_links                (GSList **links_list, gint *link_index);
+
+void        utl_gui_foreach_selected                (GtkTreeSelection *selection, GtkTreeModel *model, GFunc foreach_function, gpointer user_data);
+GtkTreeIter utl_gui_get_first_selection_iter        (GtkTreeSelection *selection, GtkTreeModel **model);
 
 #endif /* _UTILS_GUI_H */
 
